import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxVerticalAnchoredCategorySeriesComponent } from "./igx-vertical-anchored-category-series-component";
import { IgxAnchoredCategorySeriesComponent } from "./igx-anchored-category-series-component";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { BarSeries } from "./BarSeries";
import { toPoint, fromRect } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a IgxDataChartComponent bar series.
*/
export const IgxBarSeriesComponent_PROVIDERS = [{ provide: IgxVerticalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }];
export class IgxBarSeriesComponent extends IgxVerticalAnchoredCategorySeriesComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new BarSeries();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
        */
    get radiusX() {
        return this.i.p2;
    }
    set radiusX(v) {
        this.i.p2 = +v;
    }
    /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
        */
    get radiusY() {
        return this.i.p3;
    }
    set radiusY(v) {
        this.i.p3 = +v;
    }
    /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    getSeriesValueBoundingBox(world) {
        let iv = this.i.lm(toPoint(world));
        return fromRect(iv);
    }
    /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    scrollIntoView(item) {
        let iv = this.i.c8(item);
        return (iv);
    }
    /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
    getItemSpan() {
        let iv = this.i.ed();
        return (iv);
    }
}
IgxBarSeriesComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-bar-series',
                template: ``,
                providers: [{ provide: IgxVerticalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBarSeriesComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxBarSeriesComponent.ctorParameters = () => [];
IgxBarSeriesComponent.propDecorators = {
    "radiusX": [{ type: Input },],
    "radiusY": [{ type: Input },],
};
//# sourceMappingURL=igx-bar-series-component.js.map