import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxFinancialOverlayComponent } from "./igx-financial-overlay-component";
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { BollingerBandsOverlay } from "./BollingerBandsOverlay";
import { toPoint } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a IgxDataChartComponent Bollinger Bands financial overlay series.
 * Default required members: High, Low, Close
*/
export const IgxBollingerBandsOverlayComponent_PROVIDERS = [{ provide: IgxFinancialOverlayComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent) }];
export class IgxBollingerBandsOverlayComponent extends IgxFinancialOverlayComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new BollingerBandsOverlay();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the moving average period for the current BollingerBandOverlay object.
         * The typical, and initial, value for Bollinger band periods is 14.
        */
    get period() {
        return this.i.pl;
    }
    set period(v) {
        this.i.pl = +v;
    }
    /**
         * Gets or sets the moving average period for the current BollingerBandOverlay object.
         * The typical, and initial, value for Bollinger band multipliers is 2.
        */
    get multiplier() {
        return this.i.pk;
    }
    set multiplier(v) {
        this.i.pk = +v;
    }
    getSeriesValue(world, useInterpolation, skipUnknowns) {
        let iv = this.i.ek(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    }
    getPreviousOrExactIndex(world, skipUnknowns) {
        let iv = this.i.fb(toPoint(world), skipUnknowns);
        return (iv);
    }
    getNextOrExactIndex(world, skipUnknowns) {
        let iv = this.i.e9(toPoint(world), skipUnknowns);
        return (iv);
    }
}
IgxBollingerBandsOverlayComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-bollinger-bands-overlay',
                template: ``,
                providers: [{ provide: IgxFinancialOverlayComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBollingerBandsOverlayComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxBollingerBandsOverlayComponent.ctorParameters = () => [];
IgxBollingerBandsOverlayComponent.propDecorators = {
    "period": [{ type: Input },],
    "multiplier": [{ type: Input },],
};
//# sourceMappingURL=igx-bollinger-bands-overlay-component.js.map