import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSizeScaleComponent } from "./igx-size-scale-component";
import { IgxBrushScaleComponent } from "./igx-brush-scale-component";
import { IgxScatterBaseComponent } from "./igx-scatter-base-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { BubbleSeries } from "./BubbleSeries";
/**
 * Represents a IgxDataChartComponent bubble series.
*/
export const IgxBubbleSeriesComponent_PROVIDERS = [{ provide: IgxScatterBaseComponent, useExisting: forwardRef(() => IgxBubbleSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxBubbleSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBubbleSeriesComponent) }];
export class IgxBubbleSeriesComponent extends IgxScatterBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new BubbleSeries();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the radius mapping property for the current series object.
        */
    get radiusMemberPath() {
        return this.i.pa;
    }
    set radiusMemberPath(v) {
        this.i.pa = v;
    }
    /**
         * Gets or sets the radius size scale for the bubbles.
        */
    get radiusScale() {
        if (this.i.or == null) {
            return null;
        }
        if (!this.i.or.externalObject) {
            let e = new IgxSizeScaleComponent();
            e._implementation = this.i.or;
            this.i.or.externalObject = e;
        }
        return this.i.or.externalObject;
    }
    set radiusScale(v) {
        v == null ? this.i.or = null : this.i.or = v.i;
    }
    /**
         * Gets or sets the Label mapping property for the current series object.
        */
    get labelMemberPath() {
        return this.i.o7;
    }
    set labelMemberPath(v) {
        this.i.o7 = v;
    }
    /**
         * Gets or sets the fill mapping property for the current series object.
        */
    get fillMemberPath() {
        return this.i.o3;
    }
    set fillMemberPath(v) {
        this.i.o3 = v;
    }
    /**
         * Gets or sets the brush scale for the marker brush.
        */
    get fillScale() {
        if (this.i.op == null) {
            return null;
        }
        if (!this.i.op.externalObject) {
            let e = new IgxBrushScaleComponent();
            e._implementation = this.i.op;
            this.i.op.externalObject = e;
        }
        return this.i.op.externalObject;
    }
    set fillScale(v) {
        v == null ? this.i.op = null : this.i.op = v.i;
    }
    /**
         * Overridden by derived series classes to indicate when markerless display is preferred or not.
        */
    get isMarkerlessDisplayPreferred() {
        return this.i.cy;
    }
}
IgxBubbleSeriesComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-bubble-series',
                template: ``,
                providers: [{ provide: IgxScatterBaseComponent, useExisting: forwardRef(() => IgxBubbleSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxBubbleSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxBubbleSeriesComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxBubbleSeriesComponent.ctorParameters = () => [];
IgxBubbleSeriesComponent.propDecorators = {
    "radiusMemberPath": [{ type: Input },],
    "radiusScale": [{ type: Input },],
    "labelMemberPath": [{ type: Input },],
    "fillMemberPath": [{ type: Input },],
    "fillScale": [{ type: Input },],
};
//# sourceMappingURL=igx-bubble-series-component.js.map