import { EventEmitter, Output, Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES2015/type";
import { IgxSeriesComponent } from "./igx-series-component";
import { CalloutCollisionMode, CalloutCollisionMode_$type } from "./CalloutCollisionMode";
import { CalloutStyleUpdatingEventArgs } from "./igx-callout-style-updating-event-args";
import { CalloutContentUpdatingEventArgs } from "./igx-callout-content-updating-event-args";
import { CalloutLabelUpdatingEventArgs } from "./igx-callout-label-updating-event-args";
import { CalloutSeriesSelectingEventArgs } from "./igx-callout-series-selecting-event-args";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { CalloutLayer } from "./CalloutLayer";
import { ensureBool, brushToString, stringToBrush, ensureEnum } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export const IgxCalloutLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCalloutLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCalloutLayerComponent) }];
export class IgxCalloutLayerComponent extends IgxAnnotationLayerComponent {
    constructor() {
        super();
        this._calloutStyleUpdating = null;
        this._calloutContentUpdating = null;
        this._calloutLabelUpdating = null;
        this._calloutSeriesSelecting = null;
    }
    createImplementation() {
        return new CalloutLayer();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the label mapping property for the callouts.
        */
    get labelMemberPath() {
        return this.i.o2;
    }
    set labelMemberPath(v) {
        this.i.o2 = v;
    }
    /**
         * Gets or sets the label mapping property for the callouts.
        */
    get xMemberPath() {
        return this.i.o9;
    }
    set xMemberPath(v) {
        this.i.o9 = v;
    }
    /**
         * Gets or sets the label mapping property for the callouts.
        */
    get yMemberPath() {
        return this.i.pc;
    }
    set yMemberPath(v) {
        this.i.pc = v;
    }
    /**
         * Gets or sets the key mapping property for the callouts.
        */
    get keyMemberPath() {
        return this.i.oz;
    }
    set keyMemberPath(v) {
        this.i.oz = v;
    }
    /**
         * Gets or sets whether to allow the callouts to be variable distances from the target points, for suppporting collision modes.
        */
    get isCalloutOffsettingEnabled() {
        return this.i.no;
    }
    set isCalloutOffsettingEnabled(v) {
        this.i.no = ensureBool(v);
    }
    /**
         * Gets or sets the content mapping property for the callouts.
        */
    get contentMemberPath() {
        return this.i.ot;
    }
    set contentMemberPath(v) {
        this.i.ot = v;
    }
    /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
    get targetSeries() {
        if (this.i.m0 == null) {
            return null;
        }
        return this.i.m0.externalObject;
    }
    set targetSeries(v) {
        v == null ? this.i.m0 = null : this.i.m0 = v.i;
    }
    /**
         * Gets or sets a channel name to identify other callout layers within the chart to share collision information with.
        */
    get collisionChannel() {
        return this.i.oq;
    }
    set collisionChannel(v) {
        this.i.oq = v;
    }
    /**
         * Gets or sets how to select the final value to annotate.
        */
    get isAutoCalloutBehaviorEnabled() {
        return this.i.nn;
    }
    set isAutoCalloutBehaviorEnabled(v) {
        this.i.nn = ensureBool(v);
    }
    /**
         * Gets or sets whether to use values, rather than labels for auto callout labels.
        */
    get useValueForAutoCalloutLabels() {
        return this.i.nq;
    }
    set useValueForAutoCalloutLabels(v) {
        this.i.nq = ensureBool(v);
    }
    /**
         * Gets or sets whether to allow for custom callout styles.
        */
    get isCustomCalloutStyleEnabled() {
        return this.i.np;
    }
    set isCustomCalloutStyleEnabled(v) {
        this.i.np = ensureBool(v);
    }
    /**
         * Gets or sets the precision to use when values are used for the auto callout labels.
        */
    get autoCalloutLabelPrecision() {
        return this.i.n8;
    }
    set autoCalloutLabelPrecision(v) {
        this.i.n8 = +v;
    }
    /**
         * Gets or sets the color to use for the callout text. Leave unset for an automatic value.
        */
    get calloutTextColor() {
        return brushToString(this.i.qk);
    }
    set calloutTextColor(v) {
        this.i.qk = stringToBrush(v);
    }
    /**
         * Gets or sets the brush that specifies how the backgrounds for the callouts of the layer are painted. Leave unset for an automatic value.
        */
    get calloutBackground() {
        return brushToString(this.i.qh);
    }
    set calloutBackground(v) {
        this.i.qh = stringToBrush(v);
    }
    /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
    get calloutInterpolatedValuePrecision() {
        return this.i.n9;
    }
    set calloutInterpolatedValuePrecision(v) {
        this.i.n9 = +v;
    }
    /**
         * Gets or sets the brush that specifies how the outlines for the callouts of the layer are painted.
        */
    get calloutOutline() {
        return brushToString(this.i.qj);
    }
    set calloutOutline(v) {
        this.i.qj = stringToBrush(v);
    }
    /**
         * Gets or sets the brush that specifies how the leader lines for the callouts of the layer are painted.
        */
    get calloutLeaderBrush() {
        return brushToString(this.i.qi);
    }
    set calloutLeaderBrush(v) {
        this.i.qi = stringToBrush(v);
    }
    /**
         * Gets or sets the left padding to use withing the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get calloutPaddingLeft() {
        return this.i.n1;
    }
    set calloutPaddingLeft(v) {
        this.i.n1 = +v;
    }
    /**
         * Gets or sets the top padding to use within the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get calloutPaddingTop() {
        return this.i.n3;
    }
    set calloutPaddingTop(v) {
        this.i.n3 = +v;
    }
    /**
         * Gets or sets the right padding to use within the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get calloutPaddingRight() {
        return this.i.n2;
    }
    set calloutPaddingRight(v) {
        this.i.n2 = +v;
    }
    /**
         * Gets or sets the bottom padding to use within the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get calloutPaddingBottom() {
        return this.i.n0;
    }
    set calloutPaddingBottom(v) {
        this.i.n0 = +v;
    }
    /**
         * Gets or sets the strategy to use for avoiding collisions between the callouts in this layer. Leave unset for an automatic value.
        */
    get calloutCollisionMode() {
        return this.i.mu;
    }
    set calloutCollisionMode(v) {
        this.i.mu = ensureEnum(CalloutCollisionMode_$type, v);
    }
    /**
         * Gets or sets the padding to add to the callout positioning. Leave unset for an automatic value.
        */
    get calloutPositionPadding() {
        return this.i.n4;
    }
    set calloutPositionPadding(v) {
        this.i.n4 = +v;
    }
    /**
         * Gets or sets the stroke thickness for the callout backing. Leave unset for an automatic value.
        */
    get calloutStrokeThickness() {
        return this.i.n5;
    }
    set calloutStrokeThickness(v) {
        this.i.n5 = +v;
    }
    /**
         * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
        */
    get textStyle() {
        return this.i.o5;
    }
    set textStyle(v) {
        this.i.o5 = v;
    }
    /**
         * Invalidates content of callout layer
        
        */
    invalidateCalloutContent() {
        this.i.pl();
    }
    /**
         * Event raised when updating style of callout layer
        */
    get calloutStyleUpdating() {
        if (this._calloutStyleUpdating == null) {
            this._calloutStyleUpdating = new EventEmitter();
            this.i.calloutStyleUpdating = delegateCombine(this.i.calloutStyleUpdating, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new CalloutStyleUpdatingEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeCalloutStyleUpdating) {
                        this.beforeCalloutStyleUpdating(this, outerArgs);
                    }
                    this._calloutStyleUpdating.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._calloutStyleUpdating;
    }
    /**
         * Raised to allow you to decide on the content for an automatically created callout.
        */
    get calloutContentUpdating() {
        if (this._calloutContentUpdating == null) {
            this._calloutContentUpdating = new EventEmitter();
            this.i.calloutContentUpdating = delegateCombine(this.i.calloutContentUpdating, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new CalloutContentUpdatingEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeCalloutContentUpdating) {
                        this.beforeCalloutContentUpdating(this, outerArgs);
                    }
                    this._calloutContentUpdating.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._calloutContentUpdating;
    }
    /**
         * Raised to allow you to decide on the label for an automatically created callout.
        */
    get calloutLabelUpdating() {
        if (this._calloutLabelUpdating == null) {
            this._calloutLabelUpdating = new EventEmitter();
            this.i.calloutLabelUpdating = delegateCombine(this.i.calloutLabelUpdating, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new CalloutLabelUpdatingEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeCalloutLabelUpdating) {
                        this.beforeCalloutLabelUpdating(this, outerArgs);
                    }
                    this._calloutLabelUpdating.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._calloutLabelUpdating;
    }
    /**
         * Raised to allow you to select a target series for a data bound callout.
        */
    get calloutSeriesSelecting() {
        if (this._calloutSeriesSelecting == null) {
            this._calloutSeriesSelecting = new EventEmitter();
            this.i.calloutSeriesSelecting = delegateCombine(this.i.calloutSeriesSelecting, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new CalloutSeriesSelectingEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeCalloutSeriesSelecting) {
                        this.beforeCalloutSeriesSelecting(this, outerArgs);
                    }
                    this._calloutSeriesSelecting.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._calloutSeriesSelecting;
    }
}
IgxCalloutLayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-callout-layer',
                template: ``,
                providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCalloutLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCalloutLayerComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCalloutLayerComponent.ctorParameters = () => [];
IgxCalloutLayerComponent.propDecorators = {
    "labelMemberPath": [{ type: Input },],
    "xMemberPath": [{ type: Input },],
    "yMemberPath": [{ type: Input },],
    "keyMemberPath": [{ type: Input },],
    "isCalloutOffsettingEnabled": [{ type: Input },],
    "contentMemberPath": [{ type: Input },],
    "targetSeries": [{ type: Input },],
    "collisionChannel": [{ type: Input },],
    "isAutoCalloutBehaviorEnabled": [{ type: Input },],
    "useValueForAutoCalloutLabels": [{ type: Input },],
    "isCustomCalloutStyleEnabled": [{ type: Input },],
    "autoCalloutLabelPrecision": [{ type: Input },],
    "calloutTextColor": [{ type: Input },],
    "calloutBackground": [{ type: Input },],
    "calloutInterpolatedValuePrecision": [{ type: Input },],
    "calloutOutline": [{ type: Input },],
    "calloutLeaderBrush": [{ type: Input },],
    "calloutPaddingLeft": [{ type: Input },],
    "calloutPaddingTop": [{ type: Input },],
    "calloutPaddingRight": [{ type: Input },],
    "calloutPaddingBottom": [{ type: Input },],
    "calloutCollisionMode": [{ type: Input },],
    "calloutPositionPadding": [{ type: Input },],
    "calloutStrokeThickness": [{ type: Input },],
    "textStyle": [{ type: Input },],
    "calloutStyleUpdating": [{ type: Output },],
    "calloutContentUpdating": [{ type: Output },],
    "calloutLabelUpdating": [{ type: Output },],
    "calloutSeriesSelecting": [{ type: Output },],
};
//# sourceMappingURL=igx-callout-layer-component.js.map