import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { TimeAxisDisplayType, TimeAxisDisplayType_$type } from "./TimeAxisDisplayType";
import { IgxTimeAxisBaseComponent } from "./igx-time-axis-base-component";
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { CategoryDateTimeXAxis } from "./CategoryDateTimeXAxis";
import { ensureEnum } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a category-based horizontal X axis that uses a DateTime scale.
*/
export const IgxCategoryDateTimeXAxisComponent_PROVIDERS = [{ provide: IgxTimeAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryDateTimeXAxisComponent) }, { provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryDateTimeXAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxCategoryDateTimeXAxisComponent) }];
export class IgxCategoryDateTimeXAxisComponent extends IgxTimeAxisBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CategoryDateTimeXAxis();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets if the current axis is a continuous rather than a discrete scale
        */
    get isContinuous() {
        return this.i.b4;
    }
    /**
         * Gets or sets the axis display type.
         * Continuous display type divides the axis into even intervals, where labels will not necessarily be aligned with data points.
         * Discrete display type will not use a constant interval, but will align each label with its data point.
        */
    get displayType() {
        return this.i.lx;
    }
    set displayType(v) {
        this.i.lx = ensureEnum(TimeAxisDisplayType_$type, v);
    }
    /**
         * Gets or sets the X axis time interval.
        */
    get interval() {
        return this.i.l7;
    }
    set interval(v) {
        this.i.l7 = +v;
    }
    /**
         * Gets the effective value for the current Interval.
        */
    get actualInterval() {
        return this.i.l4;
    }
    set actualInterval(v) {
        this.i.l4 = +v;
    }
    /**
         * Gets or sets the frequency of displayed minor lines.
         * The set value is a factor that determines how the minor lines will be displayed.
        */
    get minorInterval() {
        return this.i.l8;
    }
    set minorInterval(v) {
        this.i.l8 = +v;
    }
    /**
         * Gets the effective value for the current MinorInterval.
        */
    get actualMinorInterval() {
        return this.i.l5;
    }
    set actualMinorInterval(v) {
        this.i.l5 = +v;
    }
    /**
         * Gets if the current axis is of category date time axis type
        */
    get isCategoryDateTime() {
        return this.i.b3;
    }
    scrollIntoView(minimum, maximum) {
        this.i.me(minimum, maximum);
    }
}
IgxCategoryDateTimeXAxisComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-category-date-time-x-axis',
                template: ``,
                providers: [{ provide: IgxTimeAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryDateTimeXAxisComponent) }, { provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryDateTimeXAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxCategoryDateTimeXAxisComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCategoryDateTimeXAxisComponent.ctorParameters = () => [];
IgxCategoryDateTimeXAxisComponent.propDecorators = {
    "displayType": [{ type: Input },],
    "interval": [{ type: Input },],
    "actualInterval": [{ type: Input },],
    "minorInterval": [{ type: Input },],
    "actualMinorInterval": [{ type: Input },],
};
//# sourceMappingURL=igx-category-date-time-x-axis-component.js.map