import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSeriesComponent } from "./igx-series-component";
import { CategoryItemHighlightType, CategoryItemHighlightType_$type } from "./CategoryItemHighlightType";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { CategoryItemHighlightLayer } from "./CategoryItemHighlightLayer";
import { ensureBool, ensureEnum } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that highlights items in a series that use a category axis
 * either by drawing a banded shape at their position, or by rendering a marker at their position.
 * Depending on the type of series, the default highlight will be affected. To override
 * the type of highlight used, you can set the HighlightType property.
*/
export const IgxCategoryItemHighlightLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCategoryItemHighlightLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCategoryItemHighlightLayerComponent) }];
export class IgxCategoryItemHighlightLayerComponent extends IgxAnnotationLayerComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CategoryItemHighlightLayer();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
    get targetSeries() {
        if (this.i.mx == null) {
            return null;
        }
        return this.i.mx.externalObject;
    }
    set targetSeries(v) {
        v == null ? this.i.mx = null : this.i.mx = v.i;
    }
    /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the pointer position.
        */
    get useInterpolation() {
        return this.i.m1;
    }
    set useInterpolation(v) {
        this.i.m1 = ensureBool(v);
    }
    /**
         * Gets or sets which type of highlight shape to use when highlighting items.
        */
    get highlightType() {
        return this.i.mv;
    }
    set highlightType(v) {
        this.i.mv = ensureEnum(CategoryItemHighlightType_$type, v);
    }
    /**
         * Gets or sets the template to use for marker visuals for the current series object.
        */
    get markerTemplate() {
        return this.i.nf;
    }
    set markerTemplate(v) {
        this.i.nf = v;
    }
    /**
         * Gets or sets the width to use for the highlight region if highlighting items in a grid aligned series (line, spline, etc), with a banded shape.
        */
    get bandHighlightWidth() {
        return this.i.m3;
    }
    set bandHighlightWidth(v) {
        this.i.m3 = +v;
    }
    /**
         * Gets or sets whether to skip unknown values when searching for series values.
        */
    get skipUnknownValues() {
        return this.i.m0;
    }
    set skipUnknownValues(v) {
        this.i.m0 = ensureBool(v);
    }
}
IgxCategoryItemHighlightLayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-category-item-highlight-layer',
                template: ``,
                providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCategoryItemHighlightLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCategoryItemHighlightLayerComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCategoryItemHighlightLayerComponent.ctorParameters = () => [];
IgxCategoryItemHighlightLayerComponent.propDecorators = {
    "targetSeries": [{ type: Input },],
    "useInterpolation": [{ type: Input },],
    "highlightType": [{ type: Input },],
    "markerTemplate": [{ type: Input },],
    "bandHighlightWidth": [{ type: Input },],
    "skipUnknownValues": [{ type: Input },],
};
//# sourceMappingURL=igx-category-item-highlight-layer-component.js.map