import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { CategoryYAxis } from "./CategoryYAxis";
import { toPoint, fromRect } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a IgxDataChartComponent category Y axis.
*/
export const IgxCategoryYAxisComponent_PROVIDERS = [{ provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryYAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxCategoryYAxisComponent) }];
export class IgxCategoryYAxisComponent extends IgxCategoryAxisBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CategoryYAxis();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets if the current axis is a vertical axis.
        */
    get isVertical() {
        return this.i.ce;
    }
    /**
         * Gets or sets the frequency of displayed labels.
         * The set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        */
    get interval() {
        return this.i.kw;
    }
    set interval(v) {
        this.i.kw = +v;
    }
    /**
         * Gets the effective value for the current Interval.
        */
    get actualInterval() {
        return this.i.ks;
    }
    set actualInterval(v) {
        this.i.ks = +v;
    }
    /**
         * Gets or sets the frequency of displayed minor lines.
         * The set value is a factor that determines how the minor lines will be displayed.
        */
    get minorInterval() {
        return this.i.kx;
    }
    set minorInterval(v) {
        this.i.kx = +v;
    }
    /**
         * Gets the effective value for the current MinorInterval.
        */
    get actualMinorInterval() {
        return this.i.ku;
    }
    set actualMinorInterval(v) {
        this.i.ku = +v;
    }
    getCategoryBoundingBox(point, useInterpolation, singularWidth) {
        let iv = this.i.kn(toPoint(point), useInterpolation, singularWidth);
        return fromRect(iv);
    }
    scrollRangeIntoView(minimum, maximum) {
        this.i.k7(minimum, maximum);
    }
    /**
         * Scrolls the specified item into view.
        
        * @param item  * Data item to scroll into view
        */
    scrollIntoView(item) {
        this.i.k6(item);
    }
}
IgxCategoryYAxisComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-category-y-axis',
                template: ``,
                providers: [{ provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxCategoryYAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxCategoryYAxisComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCategoryYAxisComponent.ctorParameters = () => [];
IgxCategoryYAxisComponent.propDecorators = {
    "interval": [{ type: Input },],
    "actualInterval": [{ type: Input },],
    "minorInterval": [{ type: Input },],
    "actualMinorInterval": [{ type: Input },],
};
//# sourceMappingURL=igx-category-y-axis-component.js.map