import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxFragmentBaseComponent } from "./igx-fragment-base-component";
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { IgxAnchoredCategorySeriesComponent } from "./igx-anchored-category-series-component";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ColumnFragment } from "./ColumnFragment";
import { toPoint, fromRect } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents one part of a StackedColumnSeries.
*/
export const IgxColumnFragmentComponent_PROVIDERS = [{ provide: IgxFragmentBaseComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }];
export class IgxColumnFragmentComponent extends IgxFragmentBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new ColumnFragment();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
    get radiusX() {
        return this.i.ql;
    }
    set radiusX(v) {
        this.i.ql = +v;
    }
    /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
    get radiusY() {
        return this.i.qm;
    }
    set radiusY(v) {
        this.i.qm = +v;
    }
    /**
         * Gets or sets the effective x-axis for this series.
        */
    get fragmentXAxis() {
        if (this.i.fragmentXAxis == null) {
            return null;
        }
        return this.i.fragmentXAxis.externalObject;
    }
    /**
         * Gets or sets the effective y-axis for this series.
        */
    get fragmentYAxis() {
        if (this.i.fragmentYAxis == null) {
            return null;
        }
        return this.i.fragmentYAxis.externalObject;
    }
    /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    getSeriesValueBoundingBox(world) {
        let iv = this.i.lm(toPoint(world));
        return fromRect(iv);
    }
    /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    getItem(world) {
        let iv = this.i.fm(toPoint(world));
        return (iv);
    }
    /**
         * Gets the index of the item that resides at the provided world coordinates.
        
        * @param world  * The world coordinates of the requested item.
        */
    getItemIndex(world) {
        let iv = this.i.e5(toPoint(world));
        return (iv);
    }
}
IgxColumnFragmentComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-column-fragment',
                template: ``,
                providers: [{ provide: IgxFragmentBaseComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxColumnFragmentComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxColumnFragmentComponent.ctorParameters = () => [];
IgxColumnFragmentComponent.propDecorators = {
    "radiusX": [{ type: Input },],
    "radiusY": [{ type: Input },],
};
//# sourceMappingURL=igx-column-fragment-component.js.map