import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSeriesComponent } from "./igx-series-component";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES2015/Visibility";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { CrosshairLayer } from "./CrosshairLayer";
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export const IgxCrosshairLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCrosshairLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCrosshairLayerComponent) }];
export class IgxCrosshairLayerComponent extends IgxAnnotationLayerComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CrosshairLayer();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the color to use for the horizontal line. Leave null for an automatic value.
        */
    get horizontalLineStroke() {
        return brushToString(this.i.o0);
    }
    set horizontalLineStroke(v) {
        this.i.o0 = stringToBrush(v);
    }
    /**
         * Gets or sets the color to use for vertical line. Leave null for an automatic value.
        */
    get verticalLineStroke() {
        return brushToString(this.i.o1);
    }
    set verticalLineStroke(v) {
        this.i.o1 = stringToBrush(v);
    }
    /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
    get targetSeries() {
        if (this.i.mx == null) {
            return null;
        }
        return this.i.mx.externalObject;
    }
    set targetSeries(v) {
        v == null ? this.i.mx = null : this.i.mx = v.i;
    }
    /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
        */
    get useInterpolation() {
        return this.i.m2;
    }
    set useInterpolation(v) {
        this.i.m2 = ensureBool(v);
    }
    /**
         * Gets or sets whether to draw annotations over the axes where the crosshair meets with them.
        */
    get isAxisAnnotationEnabled() {
        return this.i.m0;
    }
    set isAxisAnnotationEnabled(v) {
        this.i.m0 = ensureBool(v);
    }
    /**
         * Gets or sets the color to use for the x axis annotation text. Leave unset for an automatic value.
        */
    get xAxisAnnotationTextColor() {
        return brushToString(this.i.o4);
    }
    set xAxisAnnotationTextColor(v) {
        this.i.o4 = stringToBrush(v);
    }
    /**
         * Gets or sets the color to use for the x axis annotation backing. Leave unset for an automatic value.
        */
    get xAxisAnnotationBackground() {
        return brushToString(this.i.o2);
    }
    set xAxisAnnotationBackground(v) {
        this.i.o2 = stringToBrush(v);
    }
    /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
    get xAxisAnnotationInterpolatedValuePrecision() {
        return this.i.nf;
    }
    set xAxisAnnotationInterpolatedValuePrecision(v) {
        this.i.nf = +v;
    }
    /**
         * Gets or sets the color to use for the x axis annotation outline. Leave unset for an automatic value.
        */
    get xAxisAnnotationOutline() {
        return brushToString(this.i.o3);
    }
    set xAxisAnnotationOutline(v) {
        this.i.o3 = stringToBrush(v);
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get xAxisAnnotationPaddingLeft() {
        return this.i.m6;
    }
    set xAxisAnnotationPaddingLeft(v) {
        this.i.m6 = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get xAxisAnnotationPaddingTop() {
        return this.i.m8;
    }
    set xAxisAnnotationPaddingTop(v) {
        this.i.m8 = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get xAxisAnnotationPaddingRight() {
        return this.i.m7;
    }
    set xAxisAnnotationPaddingRight(v) {
        this.i.m7 = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get xAxisAnnotationPaddingBottom() {
        return this.i.m5;
    }
    set xAxisAnnotationPaddingBottom(v) {
        this.i.m5 = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get yAxisAnnotationPaddingLeft() {
        return this.i.nb;
    }
    set yAxisAnnotationPaddingLeft(v) {
        this.i.nb = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get yAxisAnnotationPaddingTop() {
        return this.i.nd;
    }
    set yAxisAnnotationPaddingTop(v) {
        this.i.nd = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get yAxisAnnotationPaddingRight() {
        return this.i.nc;
    }
    set yAxisAnnotationPaddingRight(v) {
        this.i.nc = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get yAxisAnnotationPaddingBottom() {
        return this.i.na;
    }
    set yAxisAnnotationPaddingBottom(v) {
        this.i.na = +v;
    }
    /**
         * Gets or sets the stroke thickness for the x axis annotation backing. Leave unset for an automatic value.
        */
    get xAxisAnnotationStrokeThickness() {
        return this.i.m9;
    }
    set xAxisAnnotationStrokeThickness(v) {
        this.i.m9 = +v;
    }
    /**
         * Gets or sets the color to use for the y axis annotation text. Leave unset for an automatic value.
        */
    get yAxisAnnotationTextColor() {
        return brushToString(this.i.o7);
    }
    set yAxisAnnotationTextColor(v) {
        this.i.o7 = stringToBrush(v);
    }
    /**
         * Gets or sets the color to use for the y axis annotation backing. Leave unset for an automatic value.
        */
    get yAxisAnnotationBackground() {
        return brushToString(this.i.o5);
    }
    set yAxisAnnotationBackground(v) {
        this.i.o5 = stringToBrush(v);
    }
    /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
    get yAxisAnnotationInterpolatedValuePrecision() {
        return this.i.ng;
    }
    set yAxisAnnotationInterpolatedValuePrecision(v) {
        this.i.ng = +v;
    }
    /**
         * Gets or sets the color to use for the y axis annotation outline. Leave unset for an automatic value.
        */
    get yAxisAnnotationOutline() {
        return brushToString(this.i.o6);
    }
    set yAxisAnnotationOutline(v) {
        this.i.o6 = stringToBrush(v);
    }
    /**
         * Gets or sets the stroke thickness for the y axis annotation backing. Leave unset for an automatic value.
        */
    get yAxisAnnotationStrokeThickness() {
        return this.i.ne;
    }
    set yAxisAnnotationStrokeThickness(v) {
        this.i.ne = +v;
    }
    /**
         * Gets or sets whether to display the vertical line.
        */
    get verticalLineVisibility() {
        return this.i.pb;
    }
    set verticalLineVisibility(v) {
        this.i.pb = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets whether to display the horizontal line.
        */
    get horizontalLineVisibility() {
        return this.i.pa;
    }
    set horizontalLineVisibility(v) {
        this.i.pa = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets whether to skip unknown values when searching for series values.
        */
    get skipUnknownValues() {
        return this.i.m1;
    }
    set skipUnknownValues(v) {
        this.i.m1 = ensureBool(v);
    }
}
IgxCrosshairLayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-crosshair-layer',
                template: ``,
                providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCrosshairLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCrosshairLayerComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCrosshairLayerComponent.ctorParameters = () => [];
IgxCrosshairLayerComponent.propDecorators = {
    "horizontalLineStroke": [{ type: Input },],
    "verticalLineStroke": [{ type: Input },],
    "targetSeries": [{ type: Input },],
    "useInterpolation": [{ type: Input },],
    "isAxisAnnotationEnabled": [{ type: Input },],
    "xAxisAnnotationTextColor": [{ type: Input },],
    "xAxisAnnotationBackground": [{ type: Input },],
    "xAxisAnnotationInterpolatedValuePrecision": [{ type: Input },],
    "xAxisAnnotationOutline": [{ type: Input },],
    "xAxisAnnotationPaddingLeft": [{ type: Input },],
    "xAxisAnnotationPaddingTop": [{ type: Input },],
    "xAxisAnnotationPaddingRight": [{ type: Input },],
    "xAxisAnnotationPaddingBottom": [{ type: Input },],
    "yAxisAnnotationPaddingLeft": [{ type: Input },],
    "yAxisAnnotationPaddingTop": [{ type: Input },],
    "yAxisAnnotationPaddingRight": [{ type: Input },],
    "yAxisAnnotationPaddingBottom": [{ type: Input },],
    "xAxisAnnotationStrokeThickness": [{ type: Input },],
    "yAxisAnnotationTextColor": [{ type: Input },],
    "yAxisAnnotationBackground": [{ type: Input },],
    "yAxisAnnotationInterpolatedValuePrecision": [{ type: Input },],
    "yAxisAnnotationOutline": [{ type: Input },],
    "yAxisAnnotationStrokeThickness": [{ type: Input },],
    "verticalLineVisibility": [{ type: Input },],
    "horizontalLineVisibility": [{ type: Input },],
    "skipUnknownValues": [{ type: Input },],
};
//# sourceMappingURL=igx-crosshair-layer-component.js.map