import { EventEmitter, Output, Component, forwardRef, ChangeDetectionStrategy } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES2015/type";
import { CustomContourValueResolverEventArgs } from "./igx-custom-contour-value-resolver-event-args";
import { IgxContourValueResolverComponent } from "./igx-contour-value-resolver-component";
import { CustomContourValueResolver } from "./CustomContourValueResolver";
/**
 * ContourValueResolver class which fires an event to resolve the contour values.
*/
export const IgxCustomContourValueResolverComponent_PROVIDERS = [{ provide: IgxContourValueResolverComponent, useExisting: forwardRef(() => IgxCustomContourValueResolverComponent) }];
export class IgxCustomContourValueResolverComponent extends IgxContourValueResolverComponent {
    constructor() {
        super();
        this._getCustomContourValues = null;
    }
    createImplementation() {
        return new CustomContourValueResolver();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Event raised when retrieving the contour values.
        */
    get getCustomContourValues() {
        if (this._getCustomContourValues == null) {
            this._getCustomContourValues = new EventEmitter();
            this.i.getCustomContourValues = delegateCombine(this.i.getCustomContourValues, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new CustomContourValueResolverEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeGetCustomContourValues) {
                        this.beforeGetCustomContourValues(this, outerArgs);
                    }
                    this._getCustomContourValues.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._getCustomContourValues;
    }
}
IgxCustomContourValueResolverComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-custom-contour-value-resolver',
                template: ``,
                providers: [{ provide: IgxContourValueResolverComponent, useExisting: forwardRef(() => IgxCustomContourValueResolverComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCustomContourValueResolverComponent.ctorParameters = () => [];
IgxCustomContourValueResolverComponent.propDecorators = {
    "getCustomContourValues": [{ type: Output },],
};
//# sourceMappingURL=igx-custom-contour-value-resolver-component.js.map