import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { BrushSelectionMode, BrushSelectionMode_$type } from "./BrushSelectionMode";
import { IgxBrushScaleComponent } from "./igx-brush-scale-component";
import { CustomPaletteBrushScale } from "./CustomPaletteBrushScale";
import { ensureEnum, brushToString } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a brush scale that uses index-based brush selection mode.
*/
export const IgxCustomPaletteBrushScaleComponent_PROVIDERS = [{ provide: IgxBrushScaleComponent, useExisting: forwardRef(() => IgxCustomPaletteBrushScaleComponent) }];
export class IgxCustomPaletteBrushScaleComponent extends IgxBrushScaleComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CustomPaletteBrushScale();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the brush selection mode.
        */
    get brushSelectionMode() {
        return this.i.brushSelectionMode;
    }
    set brushSelectionMode(v) {
        this.i.brushSelectionMode = ensureEnum(BrushSelectionMode_$type, v);
    }
    /**
         * Checks if this scale is ready for useage with a series
        */
    get isReady() {
        return this.i.isReady;
    }
    getBrush1(index, total) {
        let iv = this.i.getBrush1(index, total);
        return brushToString(iv);
    }
}
IgxCustomPaletteBrushScaleComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-custom-palette-brush-scale',
                template: ``,
                providers: [{ provide: IgxBrushScaleComponent, useExisting: forwardRef(() => IgxCustomPaletteBrushScaleComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCustomPaletteBrushScaleComponent.ctorParameters = () => [];
IgxCustomPaletteBrushScaleComponent.propDecorators = {
    "brushSelectionMode": [{ type: Input },],
};
//# sourceMappingURL=igx-custom-palette-brush-scale-component.js.map