import { TemplateRef, EventEmitter, Output, Input } from '@angular/core';
import { HorizontalAlignment, HorizontalAlignment_$type } from "igniteui-angular-core/ES2015/HorizontalAlignment";
import { UnknownValuePlotting, UnknownValuePlotting_$type } from "igniteui-angular-core/ES2015/UnknownValuePlotting";
import { TrendLineType, TrendLineType_$type } from "igniteui-angular-core/ES2015/TrendLineType";
import { ChartSeriesEventArgs } from './igx-chart-series-event-args';
import { brushToString, stringToBrush, toBrushCollection, fromBrushCollection, fromRect, toRect, ensureBool, ensureEnum } from "igniteui-angular-core/ES2015/componentUtil";
import { MarkerType_$type } from "./MarkerType";
import { delegateCombine } from "igniteui-angular-core/ES2015/type";
import { DomainChartSeriesPointerEventArgs } from './igx-domain-chart-series-pointer-event-args';
import { MarkerTypeCollection as MarkerTypeCollection_internal } from './MarkerTypeCollection';
import { MarkerTypeCollection } from './igx-marker-type-collection';
import { SyncableObservableCollection$1 } from "igniteui-angular-core/ES2015/SyncableObservableCollection$1";
import { ToolTipType, ToolTipType_$type } from "igniteui-angular-charts/ES2015/ToolTipType";
import { CrosshairsDisplayMode, CrosshairsDisplayMode_$type } from "igniteui-angular-charts/ES2015/CrosshairsDisplayMode";
import { CalloutStyleUpdatingEventArgs } from "igniteui-angular-charts/ES2015/igx-callout-style-updating-event-args";
export const IgxDomainChartComponent_PROVIDERS = [];
export class IgxDomainChartComponent {
    constructor() {
        this._calloutsDataSource = null;
        this._markerTypes = null;
        this._seriesAdded = null;
        this._seriesRemoved = null;
        this._seriesPointerEnter = null;
        this._seriesPointerLeave = null;
        this._seriesPointerMove = null;
        this._seriesPointerDown = null;
        this._seriesPointerUp = null;
        this._calloutStyleUpdating = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return null;
    }
    ngOnInit() {
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    /**
        * Sets or gets the template reference to use for tooltips for all the series.
        *
        *
        */
    get tooltipTemplate() {
        return this.i.tooltipTemplate;
    }
    set tooltipTemplate(v) {
        this.i.tooltipTemplate = v;
    }
    /**
        * Sets or gets the template references to use for tooltips for all the series, in order.
        *
        *
        */
    get tooltipTemplates() {
        let ret = [];
        if (this.i.tooltipTemplates) {
            for (let ii = 0; ii < this.i.tooltipTemplates.count; ii++) {
                ret.push(this.i.tooltipTemplates.item(ii));
            }
        }
        return ret;
    }
    set tooltipTemplates(v) {
        this.i.tooltipTemplates.clear();
        if (v) {
            for (let ii = 0; ii < v.length; ii++) {
                this.i.tooltipTemplates.add(v[ii]);
            }
        }
    }
    get legend() {
        if (this.i.legend != null)
            return this.i.legend.externalObject;
    }
    set legend(v) {
        if (v != undefined && v != null)
            this.i.legend = v.i;
    }
    set calloutsDataSource(value) {
        this._calloutsDataSource = value;
        this.bindCalloutsData();
    }
    get calloutsDataSource() {
        return this._calloutsDataSource;
    }
    bindCalloutsData() {
        if (this.i != null && this.i !== undefined) {
            this.i.calloutsItemsSource = this._calloutsDataSource;
        }
    }
    /**
         * Gets or sets the scaling value used to affect the pixel density of the control.
         * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
         * to appear blurry.
        */
    get pixelScalingRatio() {
        return this.i.ct;
    }
    set pixelScalingRatio(v) {
        this.i.ct = +v;
    }
    /**
         * Gets or sets the left margin of chart title
        */
    get titleLeftMargin() {
        return this.i.c2;
    }
    set titleLeftMargin(v) {
        this.i.c2 = +v;
    }
    /**
         * Gets or sets the right margin of chart title
        */
    get titleRightMargin() {
        return this.i.c3;
    }
    set titleRightMargin(v) {
        this.i.c3 = +v;
    }
    /**
         * Gets or sets the top margin of chart title
        */
    get titleTopMargin() {
        return this.i.c4;
    }
    set titleTopMargin(v) {
        this.i.c4 = +v;
    }
    /**
         * Gets or sets the bottom margin of chart title
        */
    get titleBottomMargin() {
        return this.i.c1;
    }
    set titleBottomMargin(v) {
        this.i.c1 = +v;
    }
    /**
         * Gets or sets the left margin of chart subtitle
        */
    get subtitleLeftMargin() {
        return this.i.cx;
    }
    set subtitleLeftMargin(v) {
        this.i.cx = +v;
    }
    /**
         * Gets or sets the top margin of chart subtitle
        */
    get subtitleTopMargin() {
        return this.i.cz;
    }
    set subtitleTopMargin(v) {
        this.i.cz = +v;
    }
    /**
         * Gets or sets the right margin of chart subtitle
        */
    get subtitleRightMargin() {
        return this.i.cy;
    }
    set subtitleRightMargin(v) {
        this.i.cy = +v;
    }
    /**
         * Gets or sets the bottom margin of chart subtitle
        */
    get subtitleBottomMargin() {
        return this.i.cw;
    }
    set subtitleBottomMargin(v) {
        this.i.cw = +v;
    }
    /**
         * Gets or sets color of chart subtitle
        */
    get subtitleTextColor() {
        return brushToString(this.i.h1);
    }
    set subtitleTextColor(v) {
        this.i.h1 = stringToBrush(v);
    }
    /**
         * Gets or sets color of chart title
        */
    get titleTextColor() {
        return brushToString(this.i.h2);
    }
    set titleTextColor(v) {
        this.i.h2 = stringToBrush(v);
    }
    /**
         * Gets or sets the left margin of the chart content.
        */
    get leftMargin() {
        return this.i.cs;
    }
    set leftMargin(v) {
        this.i.cs = +v;
    }
    /**
         * Gets or sets the top margin of the chart content.
        */
    get topMargin() {
        return this.i.c5;
    }
    set topMargin(v) {
        this.i.c5 = +v;
    }
    /**
         * Gets or sets the right margin of the chart content.
        */
    get rightMargin() {
        return this.i.cv;
    }
    set rightMargin(v) {
        this.i.cv = +v;
    }
    /**
         * Gets or sets the bottom margin around the chart content.
        */
    get bottomMargin() {
        return this.i.cr;
    }
    set bottomMargin(v) {
        this.i.cr = +v;
    }
    /**
         * Gets or sets the duration used for animating series plots when the data is changing
        */
    get transitionDuration() {
        return this.i.de;
    }
    set transitionDuration(v) {
        this.i.de = +v;
    }
    /**
         * Gets or sets the easing function used for animating series plots when the data is changing.
         * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
        */
    get transitionEasingFunction() {
        return this.i.a1;
    }
    set transitionEasingFunction(v) {
        this.i.a1 = v;
    }
    /**
         * Gets or sets CSS font property for the chart subtitle
        */
    get subtitleTextStyle() {
        return this.i.e9;
    }
    set subtitleTextStyle(v) {
        this.i.e9 = v;
    }
    /**
         * Gets or sets CSS font property for the chart title
        */
    get titleTextStyle() {
        return this.i.fk;
    }
    set titleTextStyle(v) {
        this.i.fk = v;
    }
    /**
         * Gets or sets a set of property paths that should be included for consideration by the category chart, leaving the remainder excluded. If null, all properties will be considered.
        */
    get includedProperties() {
        return this.i.d;
    }
    set includedProperties(v) {
        this.i.d = v;
    }
    /**
         * Gets or sets a set of property paths that should be excluded from consideration by the category chart.
        */
    get excludedProperties() {
        return this.i.c;
    }
    set excludedProperties(v) {
        this.i.c = v;
    }
    /**
         * Gets or sets the palette of brushes to use for coloring the chart series.
         * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
        */
    get brushes() {
        return fromBrushCollection(this.i.j);
    }
    set brushes(v) {
        this.i.j = toBrushCollection(v);
    }
    /**
         * Gets or sets the palette of brushes to use for outlines on the chart series.
         * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
        */
    get outlines() {
        return fromBrushCollection(this.i.n);
    }
    set outlines(v) {
        this.i.n = toBrushCollection(v);
    }
    /**
         * Gets or sets whether the chart can be horizontally zoomed through user interactions.
        */
    get isHorizontalZoomEnabled() {
        return this.i.bq;
    }
    set isHorizontalZoomEnabled(v) {
        this.i.bq = ensureBool(v);
    }
    /**
         * Gets or sets whether the chart can be vertically zoomed through user interactions.
        */
    get isVerticalZoomEnabled() {
        return this.i.bw;
    }
    set isVerticalZoomEnabled(v) {
        this.i.bw = ensureBool(v);
    }
    /**
         * Gets or sets whether the chart can highlight series through user interactions.
         * This property applies to Category Chart and Financial Chart controls.
        */
    get isSeriesHighlightingEnabled() {
        return this.i.bs;
    }
    set isSeriesHighlightingEnabled(v) {
        this.i.bs = ensureBool(v);
    }
    /**
         * Gets or sets the rectangle representing the current scroll and zoom state of the chart.
         * WindowRect is expressed as a Rectangle with coordinates and sizes between 0 and 1.
        */
    get windowRect() {
        return fromRect(this.i.h6);
    }
    set windowRect(v) {
        this.i.h6 = toRect(v);
    }
    /**
         * Gets a rectangle representing the bounds of the plot area.
        */
    get viewport() {
        return fromRect(this.i.h5);
    }
    /**
         * Gets or sets text to display above the plot area.
        */
    get chartTitle() {
        return this.i.fd;
    }
    set chartTitle(v) {
        this.i.fd = v;
    }
    /**
         * Gets or sets text to display below the Title, above the plot area.
        */
    get subtitle() {
        return this.i.e2;
    }
    set subtitle(v) {
        this.i.e2 = v;
    }
    /**
         * Gets or sets horizontal alignment which determines the title position, relative to the left and right edges of the control.
        */
    get titleAlignment() {
        return this.i.hu;
    }
    set titleAlignment(v) {
        this.i.hu = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * Gets or sets horizontal alignment which determines the subtitle position, relative to the left and right edges of the control.
        */
    get subtitleAlignment() {
        return this.i.ht;
    }
    set subtitleAlignment(v) {
        this.i.ht = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * Gets or sets the behavior that determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
    get unknownValuePlotting() {
        return this.i.ax;
    }
    set unknownValuePlotting(v) {
        this.i.ax = ensureEnum(UnknownValuePlotting_$type, v);
    }
    /**
         * Gets or sets the rendering resolution for all series in this chart.
         * Where n = Resolution, for every n horizontal pixels, combine all items into a single datapoint.  When Resolution = 0, all datapoints will be rendered as graphical objects.  Charts with a higher resolution will have faster performance.
        */
    get resolution() {
        return this.i.cu;
    }
    set resolution(v) {
        this.i.cu = +v;
    }
    /**
         * Gets or sets the thickness for all series in this chart. Depending on the ChartType, this can be the main brush used, or just the outline.
        */
    get thickness() {
        return this.i.c0;
    }
    set thickness(v) {
        this.i.c0 = +v;
    }
    /**
         * Gets or sets the marker shapes used for indicating location of data points in this chart.
         * This property applies only to these chart types: point, line, spline, bubble, and polygon
        */
    get markerTypes() {
        if (this._markerTypes === null) {
            let coll = new MarkerTypeCollection();
            let innerColl = this.i.ak;
            if (!innerColl) {
                innerColl = new MarkerTypeCollection_internal();
            }
            this._markerTypes = coll._fromInner(innerColl);
            this.i.ak = innerColl;
        }
        return this._markerTypes;
    }
    set markerTypes(v) {
        if (this._markerTypes !== null) {
            this._markerTypes._setSyncTarget(null);
            this._markerTypes = null;
        }
        let coll = new MarkerTypeCollection();
        this._markerTypes = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(MarkerType_$type);
        let innerColl = this.i.ak;
        if (!innerColl) {
            innerColl = new MarkerTypeCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._markerTypes._setSyncTarget(syncColl);
        this.i.ak = innerColl;
    }
    /**
         * Gets or sets the palette of brushes used for rendering fill area of data point markers.
         * This property applies only to these chart types: point, line, spline, bubble, and polygon
        */
    get markerBrushes() {
        return fromBrushCollection(this.i.l);
    }
    set markerBrushes(v) {
        this.i.l = toBrushCollection(v);
    }
    /**
         * Gets or sets the palette of brushes used for rendering outlines of data point markers.
         * This property applies only to these chart types: point, line, spline, bubble, and polygon
        */
    get markerOutlines() {
        return fromBrushCollection(this.i.m);
    }
    set markerOutlines(v) {
        this.i.m = toBrushCollection(v);
    }
    /**
         * Gets or sets the maximum number of markers displyed in the plot area of the chart.
        */
    get markerMaxCount() {
        return this.i.dd;
    }
    set markerMaxCount(v) {
        this.i.dd = +v;
    }
    /**
         * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
        */
    get animateSeriesWhenAxisRangeChanges() {
        return this.i.bg;
    }
    set animateSeriesWhenAxisRangeChanges(v) {
        this.i.bg = ensureBool(v);
    }
    /**
         * Gets or sets the palette of brushes to used for coloring trend lines in this chart.
         * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
        */
    get trendLineBrushes() {
        return fromBrushCollection(this.i.o);
    }
    set trendLineBrushes(v) {
        this.i.o = toBrushCollection(v);
    }
    /**
         * Gets or sets the formula used for calculating trend lines in this chart.
         * This property applies only to these chart types: point, line, spline, and bubble
        */
    get trendLineType() {
        return this.i.av;
    }
    set trendLineType(v) {
        this.i.av = ensureEnum(TrendLineType_$type, v);
    }
    /**
         * Gets or sets the thickness of the trend lines in this chart.
         * This property applies only to these chart types: point, line, spline, and bubble
        */
    get trendLineThickness() {
        return this.i.c6;
    }
    set trendLineThickness(v) {
        this.i.c6 = +v;
    }
    /**
         * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
        */
    get alignsGridLinesToPixels() {
        return this.i.bf;
    }
    set alignsGridLinesToPixels(v) {
        this.i.bf = ensureBool(v);
    }
    get trendLinePeriod() {
        return this.i.df;
    }
    set trendLinePeriod(v) {
        this.i.df = +v;
    }
    /**
         * Gets or sets the style of tooltip to be displayed.
        */
    get toolTipType() {
        return this.i.at;
    }
    set toolTipType(v) {
        this.i.at = ensureEnum(ToolTipType_$type, v);
    }
    /**
         * Gets or sets the crosshairs to be displayed.
        */
    get crosshairsDisplayMode() {
        return this.i.t;
    }
    set crosshairsDisplayMode(v) {
        this.i.t = ensureEnum(CrosshairsDisplayMode_$type, v);
    }
    /**
         * Gets or sets whether crosshairs will snap to the nearest data point.
        */
    get crosshairsSnapToData() {
        return this.i.bl;
    }
    set crosshairsSnapToData(v) {
        this.i.bl = ensureBool(v);
    }
    /**
         * Gets or sets whether annotations are shown along the axis for crosshair values
        */
    get crosshairsAnnotationEnabled() {
        return this.i.bk;
    }
    set crosshairsAnnotationEnabled(v) {
        this.i.bk = ensureBool(v);
    }
    /**
         * Gets or sets whether annotations for the final value of each series is displayed on the axis.
        */
    get finalValueAnnotationsVisible() {
        return this.i.bm;
    }
    set finalValueAnnotationsVisible(v) {
        this.i.bm = ensureBool(v);
    }
    /**
         * Gets or sets if callouts should be displayed.
        */
    get calloutsVisible() {
        return this.i.bj;
    }
    set calloutsVisible(v) {
        this.i.bj = ensureBool(v);
    }
    /**
         * Gets or sets if event annotations should be displayed.
        */
    get calloutStyleUpdatingEventEnabled() {
        return this.i.bi;
    }
    set calloutStyleUpdatingEventEnabled(v) {
        this.i.bi = ensureBool(v);
    }
    /**
         * Gets or sets the member path of the X data for the callouts.
        */
    get calloutsXMemberPath() {
        return this.i.ea;
    }
    set calloutsXMemberPath(v) {
        this.i.ea = v;
    }
    /**
         * Gets or sets the member path of the Y data for the callouts.
        */
    get calloutsYMemberPath() {
        return this.i.ec;
    }
    set calloutsYMemberPath(v) {
        this.i.ec = v;
    }
    /**
         * Gets or sets the member path of the label data for the callouts.
        */
    get calloutsLabelMemberPath() {
        return this.i.d6;
    }
    set calloutsLabelMemberPath(v) {
        this.i.d6 = v;
    }
    /**
         * Gets or sets the member path of the content data for the callouts.
        */
    get calloutsContentMemberPath() {
        return this.i.d3;
    }
    set calloutsContentMemberPath(v) {
        this.i.d3 = v;
    }
    /**
         * Provides a container for this control
        
        */
    provideContainer(container) {
        this.i.provideContainer(container);
    }
    /**
         * Destroy this control
        
        */
    destroy() {
        this.i.destroy();
    }
    /**
         * Called when the control has been resized.
        
        */
    notifyResized() {
        this.i.notifyResized();
    }
    notifyVisualPropertiesChanged() {
        this.i.gv();
    }
    /**
         * Forces any pending refresh to the chart to be finished.
        
        */
    flush() {
        this.i.f7();
    }
    /**
         * Hides the active main tooltip, if displayed.
        
        */
    hideToolTip() {
        this.i.ga();
    }
    notifySetItem(source_, index, oldItem, newItem) {
        this.i.gu(source_, index, oldItem, newItem);
    }
    /**
         * Used to manually notify the chart that the data source has reset or cleared its items.
        
        */
    notifyClearItems(source_) {
        this.i.gq(source_);
    }
    notifyInsertItem(source_, index, newItem) {
        this.i.gr(source_, index, newItem);
    }
    notifyRemoveItem(source_, index, oldItem) {
        this.i.gs(source_, index, oldItem);
    }
    /**
         * Event raised when a series is initialized and added to this chart.
        */
    get seriesAdded() {
        if (this._seriesAdded == null) {
            this._seriesAdded = new EventEmitter();
            this.i.seriesAdded = delegateCombine(this.i.seriesAdded, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new ChartSeriesEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeSeriesAdded) {
                        this.beforeSeriesAdded(this, outerArgs);
                    }
                    this._seriesAdded.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesAdded;
    }
    /**
         * Event raised when a series is removed from this chart.
        */
    get seriesRemoved() {
        if (this._seriesRemoved == null) {
            this._seriesRemoved = new EventEmitter();
            this.i.seriesRemoved = delegateCombine(this.i.seriesRemoved, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new ChartSeriesEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeSeriesRemoved) {
                        this.beforeSeriesRemoved(this, outerArgs);
                    }
                    this._seriesRemoved.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesRemoved;
    }
    /**
         * Occurs when the pointer enters a Series.
        */
    get seriesPointerEnter() {
        if (this._seriesPointerEnter == null) {
            this._seriesPointerEnter = new EventEmitter();
            this.i.seriesPointerEnter = delegateCombine(this.i.seriesPointerEnter, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new DomainChartSeriesPointerEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeSeriesPointerEnter) {
                        this.beforeSeriesPointerEnter(this, outerArgs);
                    }
                    this._seriesPointerEnter.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesPointerEnter;
    }
    /**
         * Occurs when the pointer leaves a Series.
        */
    get seriesPointerLeave() {
        if (this._seriesPointerLeave == null) {
            this._seriesPointerLeave = new EventEmitter();
            this.i.seriesPointerLeave = delegateCombine(this.i.seriesPointerLeave, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new DomainChartSeriesPointerEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeSeriesPointerLeave) {
                        this.beforeSeriesPointerLeave(this, outerArgs);
                    }
                    this._seriesPointerLeave.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesPointerLeave;
    }
    /**
         * Occurs when the pointer moves over a Series.
        */
    get seriesPointerMove() {
        if (this._seriesPointerMove == null) {
            this._seriesPointerMove = new EventEmitter();
            this.i.seriesPointerMove = delegateCombine(this.i.seriesPointerMove, (o, e) => {
                let outerArgs = new DomainChartSeriesPointerEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeSeriesPointerMove) {
                    this.beforeSeriesPointerMove(this, outerArgs);
                }
                this._seriesPointerMove.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._seriesPointerMove;
    }
    /**
         * Occurs when the pointer is pressed down over a Series.
        */
    get seriesPointerDown() {
        if (this._seriesPointerDown == null) {
            this._seriesPointerDown = new EventEmitter();
            this.i.seriesPointerDown = delegateCombine(this.i.seriesPointerDown, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new DomainChartSeriesPointerEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeSeriesPointerDown) {
                        this.beforeSeriesPointerDown(this, outerArgs);
                    }
                    this._seriesPointerDown.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesPointerDown;
    }
    /**
         * Occurs when the pointer is released over a Series.
        */
    get seriesPointerUp() {
        if (this._seriesPointerUp == null) {
            this._seriesPointerUp = new EventEmitter();
            this.i.seriesPointerUp = delegateCombine(this.i.seriesPointerUp, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new DomainChartSeriesPointerEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeSeriesPointerUp) {
                        this.beforeSeriesPointerUp(this, outerArgs);
                    }
                    this._seriesPointerUp.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesPointerUp;
    }
    /**
         * Occurs when the style of a callout is updated.
        */
    get calloutStyleUpdating() {
        if (this._calloutStyleUpdating == null) {
            this._calloutStyleUpdating = new EventEmitter();
            this.i.calloutStyleUpdating = delegateCombine(this.i.calloutStyleUpdating, (o, e) => {
                let outerArgs = new CalloutStyleUpdatingEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCalloutStyleUpdating) {
                    this.beforeCalloutStyleUpdating(this, outerArgs);
                }
                this._calloutStyleUpdating.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._calloutStyleUpdating;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
IgxDomainChartComponent.propDecorators = {
    "tooltipTemplate": [{ type: Input },],
    "tooltipTemplates": [{ type: Input },],
    "legend": [{ type: Input },],
    "calloutsDataSource": [{ type: Input },],
    "pixelScalingRatio": [{ type: Input },],
    "titleLeftMargin": [{ type: Input },],
    "titleRightMargin": [{ type: Input },],
    "titleTopMargin": [{ type: Input },],
    "titleBottomMargin": [{ type: Input },],
    "subtitleLeftMargin": [{ type: Input },],
    "subtitleTopMargin": [{ type: Input },],
    "subtitleRightMargin": [{ type: Input },],
    "subtitleBottomMargin": [{ type: Input },],
    "subtitleTextColor": [{ type: Input },],
    "titleTextColor": [{ type: Input },],
    "leftMargin": [{ type: Input },],
    "topMargin": [{ type: Input },],
    "rightMargin": [{ type: Input },],
    "bottomMargin": [{ type: Input },],
    "transitionDuration": [{ type: Input },],
    "transitionEasingFunction": [{ type: Input },],
    "subtitleTextStyle": [{ type: Input },],
    "titleTextStyle": [{ type: Input },],
    "includedProperties": [{ type: Input },],
    "excludedProperties": [{ type: Input },],
    "brushes": [{ type: Input },],
    "outlines": [{ type: Input },],
    "isHorizontalZoomEnabled": [{ type: Input },],
    "isVerticalZoomEnabled": [{ type: Input },],
    "isSeriesHighlightingEnabled": [{ type: Input },],
    "windowRect": [{ type: Input },],
    "chartTitle": [{ type: Input },],
    "subtitle": [{ type: Input },],
    "titleAlignment": [{ type: Input },],
    "subtitleAlignment": [{ type: Input },],
    "unknownValuePlotting": [{ type: Input },],
    "resolution": [{ type: Input },],
    "thickness": [{ type: Input },],
    "markerTypes": [{ type: Input },],
    "markerBrushes": [{ type: Input },],
    "markerOutlines": [{ type: Input },],
    "markerMaxCount": [{ type: Input },],
    "animateSeriesWhenAxisRangeChanges": [{ type: Input },],
    "trendLineBrushes": [{ type: Input },],
    "trendLineType": [{ type: Input },],
    "trendLineThickness": [{ type: Input },],
    "alignsGridLinesToPixels": [{ type: Input },],
    "trendLinePeriod": [{ type: Input },],
    "toolTipType": [{ type: Input },],
    "crosshairsDisplayMode": [{ type: Input },],
    "crosshairsSnapToData": [{ type: Input },],
    "crosshairsAnnotationEnabled": [{ type: Input },],
    "finalValueAnnotationsVisible": [{ type: Input },],
    "calloutsVisible": [{ type: Input },],
    "calloutStyleUpdatingEventEnabled": [{ type: Input },],
    "calloutsXMemberPath": [{ type: Input },],
    "calloutsYMemberPath": [{ type: Input },],
    "calloutsLabelMemberPath": [{ type: Input },],
    "calloutsContentMemberPath": [{ type: Input },],
    "seriesAdded": [{ type: Output },],
    "seriesRemoved": [{ type: Output },],
    "seriesPointerEnter": [{ type: Output },],
    "seriesPointerLeave": [{ type: Output },],
    "seriesPointerMove": [{ type: Output },],
    "seriesPointerDown": [{ type: Output },],
    "seriesPointerUp": [{ type: Output },],
    "calloutStyleUpdating": [{ type: Output },],
};
//# sourceMappingURL=igx-domain-chart-component.js.map