import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSeriesComponent } from "./igx-series-component";
import { FinalValueSelectionMode, FinalValueSelectionMode_$type } from "./FinalValueSelectionMode";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { FinalValueLayer } from "./FinalValueLayer";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export const IgxFinalValueLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxFinalValueLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxFinalValueLayerComponent) }];
export class IgxFinalValueLayerComponent extends IgxAnnotationLayerComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new FinalValueLayer();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
    get targetSeries() {
        if (this.i.mx == null) {
            return null;
        }
        return this.i.mx.externalObject;
    }
    set targetSeries(v) {
        v == null ? this.i.mx = null : this.i.mx = v.i;
    }
    /**
         * Gets or sets how to select the final value to annotate.
        */
    get finalValueSelectionMode() {
        return this.i.mw;
    }
    set finalValueSelectionMode(v) {
        this.i.mw = ensureEnum(FinalValueSelectionMode_$type, v);
    }
    /**
         * Gets or sets the color to use for the axis annotation text. Leave unset for an automatic value.
        */
    get axisAnnotationTextColor() {
        return brushToString(this.i.nx);
    }
    set axisAnnotationTextColor(v) {
        this.i.nx = stringToBrush(v);
    }
    /**
         * Gets or sets the color to use for the axis annotation backing. Leave unset for an automatic value.
        */
    get axisAnnotationBackground() {
        return brushToString(this.i.nv);
    }
    set axisAnnotationBackground(v) {
        this.i.nv = stringToBrush(v);
    }
    /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
    get axisAnnotationInterpolatedValuePrecision() {
        return this.i.m6;
    }
    set axisAnnotationInterpolatedValuePrecision(v) {
        this.i.m6 = +v;
    }
    /**
         * Gets or sets the color to use for the axis annotation outline. Leave unset for an automatic value.
        */
    get axisAnnotationOutline() {
        return brushToString(this.i.nw);
    }
    set axisAnnotationOutline(v) {
        this.i.nw = stringToBrush(v);
    }
    /**
         * Gets or sets the left padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get axisAnnotationPaddingLeft() {
        return this.i.m2;
    }
    set axisAnnotationPaddingLeft(v) {
        this.i.m2 = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get axisAnnotationPaddingTop() {
        return this.i.m4;
    }
    set axisAnnotationPaddingTop(v) {
        this.i.m4 = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get axisAnnotationPaddingRight() {
        return this.i.m3;
    }
    set axisAnnotationPaddingRight(v) {
        this.i.m3 = +v;
    }
    /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
    get axisAnnotationPaddingBottom() {
        return this.i.m1;
    }
    set axisAnnotationPaddingBottom(v) {
        this.i.m1 = +v;
    }
    /**
         * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
        */
    get axisAnnotationStrokeThickness() {
        return this.i.m5;
    }
    set axisAnnotationStrokeThickness(v) {
        this.i.m5 = +v;
    }
}
IgxFinalValueLayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-final-value-layer',
                template: ``,
                providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxFinalValueLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxFinalValueLayerComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxFinalValueLayerComponent.ctorParameters = () => [];
IgxFinalValueLayerComponent.propDecorators = {
    "targetSeries": [{ type: Input },],
    "finalValueSelectionMode": [{ type: Input },],
    "axisAnnotationTextColor": [{ type: Input },],
    "axisAnnotationBackground": [{ type: Input },],
    "axisAnnotationInterpolatedValuePrecision": [{ type: Input },],
    "axisAnnotationOutline": [{ type: Input },],
    "axisAnnotationPaddingLeft": [{ type: Input },],
    "axisAnnotationPaddingTop": [{ type: Input },],
    "axisAnnotationPaddingRight": [{ type: Input },],
    "axisAnnotationPaddingBottom": [{ type: Input },],
    "axisAnnotationStrokeThickness": [{ type: Input },],
};
//# sourceMappingURL=igx-final-value-layer-component.js.map