import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ItemToolTipLayer } from "./ItemToolTipLayer";
import { ensureBool } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that displays tooltips for all target series individually.
*/
export const IgxItemToolTipLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxItemToolTipLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxItemToolTipLayerComponent) }];
export class IgxItemToolTipLayerComponent extends IgxAnnotationLayerComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new ItemToolTipLayer();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
        */
    get isDefaultTooltipBehaviorDisabled() {
        return this.i.cn;
    }
    /**
         * Gets or sets whether to use value interpolation when drawing the tooltips.
        */
    get useInterpolation() {
        return this.i.my;
    }
    set useInterpolation(v) {
        this.i.my = ensureBool(v);
    }
    /**
         * Gets or sets whether to skip past unknown values when searching for series values.
        */
    get skipUnknownValues() {
        return this.i.mx;
    }
    set skipUnknownValues(v) {
        this.i.mx = ensureBool(v);
    }
}
IgxItemToolTipLayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-item-tool-tip-layer',
                template: ``,
                providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxItemToolTipLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxItemToolTipLayerComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxItemToolTipLayerComponent.ctorParameters = () => [];
IgxItemToolTipLayerComponent.propDecorators = {
    "useInterpolation": [{ type: Input },],
    "skipUnknownValues": [{ type: Input },],
};
//# sourceMappingURL=igx-item-tool-tip-layer-component.js.map