import { EventEmitter, Output, Input, TemplateRef } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES2015/type";
import { LabelsPosition, LabelsPosition_$type } from "./LabelsPosition";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES2015/Visibility";
import { Style } from "igniteui-angular-core/ES2015/Style";
import { LeaderLineType, LeaderLineType_$type } from "./LeaderLineType";
import { OthersCategoryType, OthersCategoryType_$type } from "./OthersCategoryType";
import { PropertyUpdatedEventArgs } from "igniteui-angular-core/ES2015/igx-property-updated-event-args";
import { ensureEnum, toBrushCollection, fromBrushCollection, ensureBool } from "igniteui-angular-core/ES2015/componentUtil";
import { TypeRegistrar } from "igniteui-angular-core/ES2015/type";
/**
 * Represents a IgxRingSeriesBaseComponent base series.
*/
export const IgxRingSeriesBaseComponent_PROVIDERS = [];
export class IgxRingSeriesBaseComponent {
    constructor() {
        //
        this._dataSource = null;
        this._tooltipTemplate = null;
        this._tooltipContent = null;
        this._tooltipContainerTemplate = null;
        this._showDefaultTooltip = false;
        this._propertyUpdated = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return null;
    }
    ngOnInit() {
    }
    set dataSource(value) {
        this._dataSource = value;
        this.bindData();
    }
    get dataSource() {
        return this._dataSource;
    }
    bindData() {
        if (this.i != null && this.i !== undefined) {
            this.i.itemsSource = this._dataSource;
        }
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igx" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    get legend() {
        if (this.i.legend != null)
            return this.i.legend.externalObject;
    }
    set legend(v) {
        if (v != undefined && v != null)
            this.i.legend = v.i;
    }
    set tooltipTemplate(value) {
        this._tooltipTemplate = value;
        if (value == null) {
            if (this._tooltipContent !== null) {
                this._tooltipContent.destroy();
                this._tooltipContent = null;
            }
        }
        if (this._tooltipContent != null) {
            this._tooltipContent.instance.template = this._tooltipTemplate;
        }
        else {
            if (this.owner != null) {
                this.owner._ensureTooltipCreated(this);
            }
        }
    }
    get tooltipTemplate() {
        return this._tooltipTemplate;
    }
    set tooltipContainerTemplate(value) {
        this._tooltipContainerTemplate = value;
        if (this._tooltipContent != null) {
            this._tooltipContent.instance.containerTemplate = this._tooltipContainerTemplate;
        }
    }
    get tooltipContainerTemplate() {
        return this._tooltipContainerTemplate;
    }
    _ensureTooltipCreated(createTooltip, createWrapper) {
        if (this._tooltipTemplate == null) {
            this.i.toolTip = null;
        }
        if (this._tooltipContent == null && this._tooltipTemplate != null) {
            let tooltip = createTooltip();
            if (tooltip == null) {
                return;
            }
            this._tooltipContent = tooltip;
            tooltip.instance.template = this._tooltipTemplate;
            this.i.toolTip = createWrapper(tooltip.location.nativeElement);
        }
    }
    _ensureTooltipDestroyed() {
        if (this._tooltipContent !== null) {
            this._tooltipContent.destroy();
            this._tooltipContent = null;
        }
    }
    /**
         * Gets or sets whether default tooltip will be shown.
        */
    get showDefaultTooltip() {
        return this._showDefaultTooltip;
    }
    set showDefaultTooltip(v) {
        this._showDefaultTooltip = ensureBool(v);
    }
    sychronizeCollections() { }
    /**
         * Gets or Sets the property name that contains the values.
        */
    get valueMemberPath() {
        return this.i.b7;
    }
    set valueMemberPath(v) {
        this.i.b7 = v;
    }
    /**
         * Gets or sets the property name that contains the labels.
        */
    get labelMemberPath() {
        return this.i.bf;
    }
    set labelMemberPath(v) {
        this.i.bf = v;
    }
    /**
         * Gets or sets the property name that contains the legend labels.
        */
    get legendLabelMemberPath() {
        return this.i.bp;
    }
    set legendLabelMemberPath(v) {
        this.i.bp = v;
    }
    /**
         * Gets or sets the position of chart labels.
        */
    get labelsPosition() {
        return this.i.aj;
    }
    set labelsPosition(v) {
        this.i.aj = ensureEnum(LabelsPosition_$type, v);
    }
    /**
         * Gets or sets whether the leader lines are visible.
        */
    get leaderLineVisibility() {
        return this.i.dq;
    }
    set leaderLineVisibility(v) {
        this.i.dq = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets the fill brush.
        */
    get leaderLineFill() {
        return this.i.dk ? this.i.dk.fill : null;
    }
    set leaderLineFill(v) {
        this.ensureLeaderLineStyle();
        this.i.dk.fill = v;
    }
    /**
         * Gets or sets the stroke brush.
        */
    get leaderLineStroke() {
        return this.i.dk ? this.i.dk.stroke : null;
    }
    set leaderLineStroke(v) {
        this.ensureLeaderLineStyle();
        this.i.dk.stroke = v;
    }
    /**
         * Gets or sets the stroke thickness.
        */
    get leaderLineStrokeThickness() {
        return this.i.dk ? this.i.dk.strokeThickness : NaN;
    }
    set leaderLineStrokeThickness(v) {
        this.ensureLeaderLineStyle();
        this.i.dk.strokeThickness = +v;
    }
    /**
         * Gets or sets the opacity.
        */
    get leaderLineOpacity() {
        return this.i.dk ? this.i.dk.opacity : NaN;
    }
    set leaderLineOpacity(v) {
        this.ensureLeaderLineStyle();
        this.i.dk.opacity = +v;
    }
    ensureLeaderLineStyle() {
        if (this.i.dk) {
            return;
        }
        this.i.dk = new Style();
    }
    /**
         * Gets or sets what type of leader lines will be used for the outside end labels.
        */
    get leaderLineType() {
        return this.i.ak;
    }
    set leaderLineType(v) {
        this.i.ak = ensureEnum(LeaderLineType_$type, v);
    }
    /**
         * Gets or sets the margin between a label and its leader line. The default is 6 pixels.
        */
    get leaderLineMargin() {
        return this.i.a1;
    }
    set leaderLineMargin(v) {
        this.i.a1 = +v;
    }
    /**
         * Gets or sets the threshold value that determines if slices are grouped into the Others slice.
        */
    get othersCategoryThreshold() {
        return this.i.a2;
    }
    set othersCategoryThreshold(v) {
        this.i.a2 = +v;
    }
    /**
         * Gets or sets whether to use numeric or percent-based threshold value.
        */
    get othersCategoryType() {
        return this.i.al;
    }
    set othersCategoryType(v) {
        this.i.al = ensureEnum(OthersCategoryType_$type, v);
    }
    /**
         * Gets or sets the label of the Others slice.
        */
    get othersCategoryText() {
        return this.i.bt;
    }
    set othersCategoryText(v) {
        this.i.bt = v;
    }
    /**
         * Sets or gets a function which takes an object that produces a formatted label for displaying in the chart.
        */
    get formatLabel() {
        return this.i.am;
    }
    set formatLabel(v) {
        this.i.am = v;
    }
    /**
         * Sets or gets a function which takes an object that produces a formatted label for displaying in the chart's legend.
        */
    get formatLegendLabel() {
        return this.i.an;
    }
    set formatLegendLabel(v) {
        this.i.an = v;
    }
    /**
         * Gets or sets the pixel amount by which the labels are offset from the edge of the slices.
        */
    get labelExtent() {
        return this.i.a0;
    }
    set labelExtent(v) {
        this.i.a0 = +v;
    }
    /**
         * Gets or sets the starting angle of the chart.
         * The default zero value is equivalent to 3 o'clock.
        */
    get startAngle() {
        return this.i.a4;
    }
    set startAngle(v) {
        this.i.a4 = +v;
    }
    /**
         * Gets or sets the fill brush.
        */
    get selectedSliceFill() {
        return this.i.dm ? this.i.dm.fill : null;
    }
    set selectedSliceFill(v) {
        this.ensureSelectedStyle();
        this.i.dm.fill = v;
    }
    /**
         * Gets or sets the stroke brush.
        */
    get selectedSliceStroke() {
        return this.i.dm ? this.i.dm.stroke : null;
    }
    set selectedSliceStroke(v) {
        this.ensureSelectedStyle();
        this.i.dm.stroke = v;
    }
    /**
         * Gets or sets the stroke thickness.
        */
    get selectedSliceStrokeThickness() {
        return this.i.dm ? this.i.dm.strokeThickness : NaN;
    }
    set selectedSliceStrokeThickness(v) {
        this.ensureSelectedStyle();
        this.i.dm.strokeThickness = +v;
    }
    /**
         * Gets or sets the opacity.
        */
    get selectedSliceOpacity() {
        return this.i.dm ? this.i.dm.opacity : NaN;
    }
    set selectedSliceOpacity(v) {
        this.ensureSelectedStyle();
        this.i.dm.opacity = +v;
    }
    ensureSelectedStyle() {
        if (this.i.dm) {
            return;
        }
        this.i.dm = new Style();
    }
    /**
         * Gets or sets the palette of brushes to use for coloring the slices.
        */
    get brushes() {
        return fromBrushCollection(this.i.ag);
    }
    set brushes(v) {
        this.i.ag = toBrushCollection(v);
    }
    /**
         * Gets or sets the palette of brushes to use for outlines on the slices.
        */
    get outlines() {
        return fromBrushCollection(this.i.ah);
    }
    set outlines(v) {
        this.i.ah = toBrushCollection(v);
    }
    /**
         * Gets or sets whether all surface interactions with the plot area should be disabled.
        */
    get isSurfaceInteractionDisabled() {
        return this.i.ax;
    }
    set isSurfaceInteractionDisabled(v) {
        this.i.ax = ensureBool(v);
    }
    /**
         * Gets or sets the scaling factor of the chart's radius. Value between 0 and 1.
        */
    get radiusFactor() {
        return this.i.a3;
    }
    set radiusFactor(v) {
        this.i.a3 = +v;
    }
    /**
         * Called by the UI framework to provide a UI container for rendering this control.
        
        * @param container  * The UI container element.
        */
    provideContainer(container) {
        this.i.ck(container);
    }
    /**
         * Event raised when a property (including "effective" and non-dependency property) value changes.
        */
    get propertyUpdated() {
        if (this._propertyUpdated == null) {
            this._propertyUpdated = new EventEmitter();
            this.i.propertyUpdated = delegateCombine(this.i.propertyUpdated, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new PropertyUpdatedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforePropertyUpdated) {
                        this.beforePropertyUpdated(this, outerArgs);
                    }
                    this._propertyUpdated.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._propertyUpdated;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
IgxRingSeriesBaseComponent.propDecorators = {
    "dataSource": [{ type: Input },],
    "legend": [{ type: Input },],
    "tooltipTemplate": [{ type: Input },],
    "tooltipContainerTemplate": [{ type: Input },],
    "showDefaultTooltip": [{ type: Input },],
    "valueMemberPath": [{ type: Input },],
    "labelMemberPath": [{ type: Input },],
    "legendLabelMemberPath": [{ type: Input },],
    "labelsPosition": [{ type: Input },],
    "leaderLineVisibility": [{ type: Input },],
    "leaderLineFill": [{ type: Input },],
    "leaderLineStroke": [{ type: Input },],
    "leaderLineStrokeThickness": [{ type: Input },],
    "leaderLineOpacity": [{ type: Input },],
    "leaderLineType": [{ type: Input },],
    "leaderLineMargin": [{ type: Input },],
    "othersCategoryThreshold": [{ type: Input },],
    "othersCategoryType": [{ type: Input },],
    "othersCategoryText": [{ type: Input },],
    "formatLabel": [{ type: Input },],
    "formatLegendLabel": [{ type: Input },],
    "labelExtent": [{ type: Input },],
    "startAngle": [{ type: Input },],
    "selectedSliceFill": [{ type: Input },],
    "selectedSliceStroke": [{ type: Input },],
    "selectedSliceStrokeThickness": [{ type: Input },],
    "selectedSliceOpacity": [{ type: Input },],
    "brushes": [{ type: Input },],
    "outlines": [{ type: Input },],
    "isSurfaceInteractionDisabled": [{ type: Input },],
    "radiusFactor": [{ type: Input },],
    "propertyUpdated": [{ type: Output },],
};
//# sourceMappingURL=igx-ring-series-base-component.js.map