import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxValueBrushScaleComponent } from "./igx-value-brush-scale-component";
import { IgxContourValueResolverComponent } from "./igx-contour-value-resolver-component";
import { IgxScatterTriangulationSeriesComponent } from "./igx-scatter-triangulation-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ScatterContourSeries } from "./ScatterContourSeries";
/**
 * Series class for rendering isarithmic contours based on a triangulation of X+Y+Value points in the ItemsSource.
*/
export const IgxScatterContourSeriesComponent_PROVIDERS = [{ provide: IgxScatterTriangulationSeriesComponent, useExisting: forwardRef(() => IgxScatterContourSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxScatterContourSeriesComponent) }];
export class IgxScatterContourSeriesComponent extends IgxScatterTriangulationSeriesComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new ScatterContourSeries();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or set the name of the property from which to retrieve the numeric values from the ItemsSource items.
        */
    get valueMemberPath() {
        return this.i.nh;
    }
    set valueMemberPath(v) {
        this.i.nh = v;
    }
    /**
         * Gets or sets the ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
        */
    get fillScale() {
        if (this.i.nc == null) {
            return null;
        }
        if (!this.i.nc.externalObject) {
            let e = new IgxValueBrushScaleComponent();
            e._implementation = this.i.nc;
            this.i.nc.externalObject = e;
        }
        return this.i.nc.externalObject;
    }
    set fillScale(v) {
        v == null ? this.i.nc = null : this.i.nc = v.i;
    }
    /**
         * Gets or set the ContourValueResolver used to determine the numeric values of contours.
        */
    get valueResolver() {
        if (this.i.na == null) {
            return null;
        }
        return this.i.na.externalObject;
    }
    set valueResolver(v) {
        v == null ? this.i.na = null : this.i.na = v.i;
    }
}
IgxScatterContourSeriesComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-scatter-contour-series',
                template: ``,
                providers: [{ provide: IgxScatterTriangulationSeriesComponent, useExisting: forwardRef(() => IgxScatterContourSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxScatterContourSeriesComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxScatterContourSeriesComponent.ctorParameters = () => [];
IgxScatterContourSeriesComponent.propDecorators = {
    "valueMemberPath": [{ type: Input },],
    "fillScale": [{ type: Input },],
    "valueResolver": [{ type: Input },],
};
//# sourceMappingURL=igx-scatter-contour-series-component.js.map