import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { Style } from "igniteui-angular-core/ES2015/igx-style";
import { MarkerType, MarkerType_$type } from "./MarkerType";
import { CollisionAvoidanceType, CollisionAvoidanceType_$type } from "./CollisionAvoidanceType";
import { IgxShapeSeriesBaseComponent } from "./igx-shape-series-base-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ScatterPolygonSeries } from "./ScatterPolygonSeries";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES2015/componentUtil";
import { StyleSelector } from "./StyleSelector";
/**
 * Series class which renders polygons as Paths based on lists of points in the ItemsSource.
*/
export const IgxScatterPolygonSeriesComponent_PROVIDERS = [{ provide: IgxShapeSeriesBaseComponent, useExisting: forwardRef(() => IgxScatterPolygonSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxScatterPolygonSeriesComponent) }];
export class IgxScatterPolygonSeriesComponent extends IgxShapeSeriesBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new ScatterPolygonSeries();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Returns whether the current series supports visual markers.
        */
    get hasMarkers() {
        return this.i.hasMarkers;
    }
    /**
         * The StyleSelector which is used to select a style for each Shape.
        */
    get shapeStyleSelector() {
        return this.i.m8;
    }
    set shapeStyleSelector(v) {
        this.i.m8 = v;
    }
    /**
         * The default style to apply to all Shapes in the series.
        */
    get shapeStyle() {
        if (this.i.n5 == null) {
            return null;
        }
        if (!this.i.n5.externalObject) {
            let e = new Style();
            e._implementation = this.i.n5;
            this.i.n5.externalObject = e;
        }
        return this.i.n5.externalObject;
    }
    set shapeStyle(v) {
        v == null ? this.i.n5 = null : this.i.n5 = v.i;
    }
    /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
    get markerType() {
        return this.i.m3;
    }
    set markerType(v) {
        this.i.m3 = ensureEnum(MarkerType_$type, v);
    }
    /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
    get markerTemplate() {
        return this.i.nn;
    }
    set markerTemplate(v) {
        this.i.nn = v;
    }
    /**
         * Gets the effective marker template for the current series object.
        */
    get actualMarkerTemplate() {
        return this.i.nm;
    }
    set actualMarkerTemplate(v) {
        this.i.nm = v;
    }
    /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
    get markerBrush() {
        return brushToString(this.i.n1);
    }
    set markerBrush(v) {
        this.i.n1 = stringToBrush(v);
    }
    /**
         * Gets the effective marker brush for the current series object.
        */
    get actualMarkerBrush() {
        return brushToString(this.i.nz);
    }
    set actualMarkerBrush(v) {
        this.i.nz = stringToBrush(v);
    }
    /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
    get markerOutline() {
        return brushToString(this.i.n2);
    }
    set markerOutline(v) {
        this.i.n2 = stringToBrush(v);
    }
    /**
         * Gets the effective marker outline for the current series object.
        */
    get actualMarkerOutline() {
        return brushToString(this.i.n0);
    }
    set actualMarkerOutline(v) {
        this.i.n0 = stringToBrush(v);
    }
    /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
    get markerCollisionAvoidance() {
        return this.i.m2;
    }
    set markerCollisionAvoidance(v) {
        this.i.m2 = ensureEnum(CollisionAvoidanceType_$type, v);
    }
}
IgxScatterPolygonSeriesComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-scatter-polygon-series',
                template: ``,
                providers: [{ provide: IgxShapeSeriesBaseComponent, useExisting: forwardRef(() => IgxScatterPolygonSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxScatterPolygonSeriesComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxScatterPolygonSeriesComponent.ctorParameters = () => [];
IgxScatterPolygonSeriesComponent.propDecorators = {
    "shapeStyleSelector": [{ type: Input },],
    "shapeStyle": [{ type: Input },],
    "markerType": [{ type: Input },],
    "markerTemplate": [{ type: Input },],
    "actualMarkerTemplate": [{ type: Input },],
    "markerBrush": [{ type: Input },],
    "actualMarkerBrush": [{ type: Input },],
    "markerOutline": [{ type: Input },],
    "actualMarkerOutline": [{ type: Input },],
    "markerCollisionAvoidance": [{ type: Input },],
};
//# sourceMappingURL=igx-scatter-polygon-series-component.js.map