import { Type, EventEmitter } from '@angular/core';
import { IgPoint } from "igniteui-angular-core/ES2015/IgPoint";
import { StackedSeriesCreatedEventArgs } from "./igx-stacked-series-created-event-args";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { StackedSeriesBase } from "./StackedSeriesBase";
/**
 * Represents a base class for stacked series.
*/
export declare const IgxStackedSeriesBaseComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare abstract class IgxStackedSeriesBaseComponent extends IgxCategorySeriesComponent {
    readonly i: StackedSeriesBase;
    constructor();
    /**
     * Gets or sets whether series should be automatically generated. Reqiures the use of GroupBy as the ItemsSource.
    */
    autoGenerateSeries: boolean;
    /**
     * Gets or sets whether the order of the fragment series should be reversed in the legend.
    */
    reverseLegendOrder: boolean;
    /**
     * Checks if this series is a stacked series
    */
    readonly isStacked: boolean;
    /**
     * Simulates a pointer hover over the series surface.
    
    * @param point  * The pointer position relative to the series viewport over which to hover.
    */
    simulateHover(point: IgPoint): void;
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item: any): boolean;
    private _seriesCreated;
    /**
     * Event raised when a new fragment series is automatically generated.
    */
    readonly seriesCreated: EventEmitter<{
        sender: any;
        args: StackedSeriesCreatedEventArgs;
    }>;
}
