import { EventEmitter, Output, forwardRef, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES2015/type";
import { StackedSeriesCreatedEventArgs } from "./igx-stacked-series-created-event-args";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureBool, toPoint } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a base class for stacked series.
*/
export const IgxStackedSeriesBaseComponent_PROVIDERS = [{ provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxStackedSeriesBaseComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxStackedSeriesBaseComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxStackedSeriesBaseComponent) }];
export class IgxStackedSeriesBaseComponent extends IgxCategorySeriesComponent {
    constructor() {
        super();
        this._seriesCreated = null;
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets whether series should be automatically generated. Reqiures the use of GroupBy as the ItemsSource.
        */
    get autoGenerateSeries() {
        return this.i.ox;
    }
    set autoGenerateSeries(v) {
        this.i.ox = ensureBool(v);
    }
    /**
         * Gets or sets whether the order of the fragment series should be reversed in the legend.
        */
    get reverseLegendOrder() {
        return this.i.oy;
    }
    set reverseLegendOrder(v) {
        this.i.oy = ensureBool(v);
    }
    /**
         * Checks if this series is a stacked series
        */
    get isStacked() {
        return this.i.isStacked;
    }
    /**
         * Simulates a pointer hover over the series surface.
        
        * @param point  * The pointer position relative to the series viewport over which to hover.
        */
    simulateHover(point) {
        this.i.jc(toPoint(point));
    }
    /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    scrollIntoView(item) {
        let iv = this.i.c8(item);
        return (iv);
    }
    /**
         * Event raised when a new fragment series is automatically generated.
        */
    get seriesCreated() {
        if (this._seriesCreated == null) {
            this._seriesCreated = new EventEmitter();
            this.i.seriesCreated = delegateCombine(this.i.seriesCreated, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new StackedSeriesCreatedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeSeriesCreated) {
                        this.beforeSeriesCreated(this, outerArgs);
                    }
                    this._seriesCreated.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesCreated;
    }
}
IgxStackedSeriesBaseComponent.propDecorators = {
    "autoGenerateSeries": [{ type: Input },],
    "reverseLegendOrder": [{ type: Input },],
    "seriesCreated": [{ type: Output },],
};
//# sourceMappingURL=igx-stacked-series-base-component.js.map