import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { IgxFinancialIndicatorComponent } from "./igx-financial-indicator-component";
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { StochRSIIndicator } from "./StochRSIIndicator";
/**
 * Represents a IgxDataChartComponent StochRSI indicator series.
 * Default required members: Close
*
* `IgxStochRSIIndicatorComponent` or Stochastic Relative Strength IndexI Indicator (SRSI) measures when a security is overbought or oversold within a specified period of time. The values range from 0 to 1. The StochRSI Indicator is calculated by applying the Stochastic Oscillator formula to RelativeStrengthIndexIndicator (RSI) data.
*
* Using this indicator requires setting the `CloseMemberPath`.
*
* ```html
* <igx-data-chart
*     width=500px
*     height=500px
*     [dataSource]="data" >
*     <igx-ordinal-time-x-axis
*         dateTimeMemberPath="TimeStamp"
*         #xAxis>
*       </igx-ordinal-time-x-axis>
*     <igx-numeric-y-axis
*        #yAxis></igx-numeric-y-axis>
*     <igx-stoch-rsi-indicator
*        [xAxis]="xAxis"
*        [yAxis]="yAxis"
*        closeMemberPath="Close">
*      </igx-stoch-rsi-indicator>
* </igx-data-chart>
* ```
*/
export const IgxStochRSIIndicatorComponent_PROVIDERS = [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(() => IgxStochRSIIndicatorComponent) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(() => IgxStochRSIIndicatorComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxStochRSIIndicatorComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxStochRSIIndicatorComponent) }];
export class IgxStochRSIIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new StochRSIIndicator();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the moving average period for the current StochRSIIndicator object.
         * The typical, and initial, value for StochRSI periods is 14.
        *
        * ```html
        * <igx-data-chart
        *     width=500px
        *     height=500px
        *     [dataSource]="data" >
        *     <igx-ordinal-time-x-axis
        *         dateTimeMemberPath="TimeStamp"
        *         #xAxis>
        *       </igx-ordinal-time-x-axis>
        *     <igx-numeric-y-axis
        *        #yAxis></igx-numeric-y-axis>
        *     <igx-stoch-rsi-indicator
        *        [xAxis]="xAxis"
        *        [yAxis]="yAxis"
        *        closeMemberPath="Close"
        *        period=10>
        *      </igx-stoch-rsi-indicator>
        * </igx-data-chart>
        * ```
        */
    get period() {
        return this.i.qp;
    }
    set period(v) {
        this.i.qp = +v;
    }
}
IgxStochRSIIndicatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-stoch-rsi-indicator',
                template: ``,
                providers: [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(() => IgxStochRSIIndicatorComponent) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(() => IgxStochRSIIndicatorComponent) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxStochRSIIndicatorComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxStochRSIIndicatorComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxStochRSIIndicatorComponent.ctorParameters = () => [];
IgxStochRSIIndicatorComponent.propDecorators = {
    "period": [{ type: Input },],
};
//# sourceMappingURL=igx-stoch-rsi-indicator-component.js.map