import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxBrushScaleComponent } from "./igx-brush-scale-component";
import { ValueBrushScale } from "./ValueBrushScale";
import { ensureBool } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a brush scale that uses value-based brush selection.
*/
export const IgxValueBrushScaleComponent_PROVIDERS = [{ provide: IgxBrushScaleComponent, useExisting: forwardRef(() => IgxValueBrushScaleComponent) }];
export class IgxValueBrushScaleComponent extends IgxBrushScaleComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new ValueBrushScale();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the minimum value for this scale.
        */
    get minimumValue() {
        return this.i.minimumValue;
    }
    set minimumValue(v) {
        this.i.minimumValue = +v;
    }
    /**
         * Gets or sets the maximum value for this scale.
        */
    get maximumValue() {
        return this.i.maximumValue;
    }
    set maximumValue(v) {
        this.i.maximumValue = +v;
    }
    /**
         * Gets or sets whether the scale is logarithmic.
        */
    get isLogarithmic() {
        return this.i.isLogarithmic;
    }
    set isLogarithmic(v) {
        this.i.isLogarithmic = ensureBool(v);
    }
    /**
         * Gets or sets the logarithm base for this scale.
        */
    get logarithmBase() {
        return this.i.logarithmBase;
    }
    set logarithmBase(v) {
        this.i.logarithmBase = +v;
    }
    /**
         * Checks if the value brush scale is ready for usage in the chart
        */
    get isReady() {
        return this.i.isReady;
    }
}
IgxValueBrushScaleComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-value-brush-scale',
                template: ``,
                providers: [{ provide: IgxBrushScaleComponent, useExisting: forwardRef(() => IgxValueBrushScaleComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxValueBrushScaleComponent.ctorParameters = () => [];
IgxValueBrushScaleComponent.propDecorators = {
    "minimumValue": [{ type: Input },],
    "maximumValue": [{ type: Input },],
    "isLogarithmic": [{ type: Input },],
    "logarithmBase": [{ type: Input },],
};
//# sourceMappingURL=igx-value-brush-scale-component.js.map