import { forwardRef, Input } from '@angular/core';
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxCategoryYAxisComponent } from "./igx-category-y-axis-component";
import { IgxStackedSeriesBaseComponent } from "./igx-stacked-series-base-component";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
/**
 * Base class for stacked series with a numeric x-axis and a category y-axis.
*/
export const IgxVerticalStackedSeriesBaseComponent_PROVIDERS = [{ provide: IgxStackedSeriesBaseComponent, useExisting: forwardRef(() => IgxVerticalStackedSeriesBaseComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxVerticalStackedSeriesBaseComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxVerticalStackedSeriesBaseComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxVerticalStackedSeriesBaseComponent) }];
export class IgxVerticalStackedSeriesBaseComponent extends IgxStackedSeriesBaseComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the effective x-axis for the current CategorySeries object.
        */
    get xAxis() {
        if (this.i.xAxis == null) {
            return null;
        }
        if (!this.i.xAxis.externalObject) {
            let e = new IgxNumericXAxisComponent();
            e._implementation = this.i.xAxis;
            this.i.xAxis.externalObject = e;
        }
        return this.i.xAxis.externalObject;
    }
    set xAxis(v) {
        v == null ? this.i.xAxis = null : this.i.xAxis = v.i;
    }
    /**
         * Gets or sets the effective y-axis for the current CategorySeries object.
        */
    get yAxis() {
        if (this.i.yAxis == null) {
            return null;
        }
        if (!this.i.yAxis.externalObject) {
            let e = new IgxCategoryYAxisComponent();
            e._implementation = this.i.yAxis;
            this.i.yAxis.externalObject = e;
        }
        return this.i.yAxis.externalObject;
    }
    set yAxis(v) {
        v == null ? this.i.yAxis = null : this.i.yAxis = v.i;
    }
    /**
         * Gets whether or not the current series is vertical series
        */
    get isVertical() {
        return this.i.isVertical;
    }
    /**
         * Returns the offset value for this series if grouped on a category axis.
        
        */
    getOffsetValue() {
        let iv = this.i.getOffsetValue();
        return (iv);
    }
    /**
         * Returns the width of the category grouping this series is in.
        
        */
    getCategoryWidth() {
        let iv = this.i.getCategoryWidth();
        return (iv);
    }
    /**
         * Determine if object can be used as YAxis
        
        * @param axis  * The object to check
        */
    canUseAsYAxis(axis) {
        let iv = this.i.pp(axis);
        return (iv);
    }
    /**
         * Determine if object can be used as XAxis
        
        * @param axis  * The object to check
        */
    canUseAsXAxis(axis) {
        let iv = this.i.po(axis);
        return (iv);
    }
}
IgxVerticalStackedSeriesBaseComponent.propDecorators = {
    "xAxis": [{ type: Input },],
    "yAxis": [{ type: Input },],
};
//# sourceMappingURL=igx-vertical-stacked-series-base-component.js.map