import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { IgxFinancialIndicatorComponent } from "./igx-financial-indicator-component";
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { AbsoluteVolumeOscillatorIndicator } from "./AbsoluteVolumeOscillatorIndicator";
/**
 * Represents a IgxDataChartComponent Absolute Volume Oscillator indicator series.
 * Default required members: Volume
*
* ---
* mentionedTypes: ['CategoryChart', 'CategoryChartType']
* ---
*
* You can use the `IgxAbsoluteVolumeOscillatorIndicatorComponent` to identify whether volume trands are increasing or decreasing.
*
* ```html
* <igx-data-chart
* 	#chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
*     <igx-absolute-volume-oscillator-indicator
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		openMemberPath="open"
* 		highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close">
*     </igx-absolute-volume-oscillator-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxAbsoluteVolumeOscillatorIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export var IgxAbsoluteVolumeOscillatorIndicatorComponent_PROVIDERS = [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(function () { return IgxAbsoluteVolumeOscillatorIndicatorComponent; }) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(function () { return IgxAbsoluteVolumeOscillatorIndicatorComponent; }) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxAbsoluteVolumeOscillatorIndicatorComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxAbsoluteVolumeOscillatorIndicatorComponent; }) }];
var IgxAbsoluteVolumeOscillatorIndicatorComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxAbsoluteVolumeOscillatorIndicatorComponent, _super);
    function IgxAbsoluteVolumeOscillatorIndicatorComponent() {
        return _super.call(this) || this;
    }
    IgxAbsoluteVolumeOscillatorIndicatorComponent.prototype.createImplementation = function () {
        return new AbsoluteVolumeOscillatorIndicator();
    };
    Object.defineProperty(IgxAbsoluteVolumeOscillatorIndicatorComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAbsoluteVolumeOscillatorIndicatorComponent.prototype, "shortPeriod", {
        /**
         * Gets or sets the short moving average period for the current AbsoluteVolumeOscillatorIndicator object.
         * The typical, and initial, value for short AVO periods is 10.
        *
        * You can use the `shortPeriod` to set the short moving average period.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data" >
        *     <igx-category-x-axis
        * 		label="label"
        * 		#xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        * 		#yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-absolute-volume-oscillator-indicator
        * 		#series
        * 		[xAxis]="xAxis"
        * 		[yAxis]="yAxis"
        * 		openMemberPath="open"
        * 		highMemberPath="high"
        * 		lowMemberPath="low"
        * 		closeMemberPath="close"
        * 		shortPeriod="10">
        *     </igx-absolute-volume-oscillator-indicator>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.series.shortPeriod = 10;
        * ```
        */
        get: /**
             * Gets or sets the short moving average period for the current AbsoluteVolumeOscillatorIndicator object.
             * The typical, and initial, value for short AVO periods is 10.
            *
            * You can use the `shortPeriod` to set the short moving average period.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data" >
            *     <igx-category-x-axis
            * 		label="label"
            * 		#xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            * 		#yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-absolute-volume-oscillator-indicator
            * 		#series
            * 		[xAxis]="xAxis"
            * 		[yAxis]="yAxis"
            * 		openMemberPath="open"
            * 		highMemberPath="high"
            * 		lowMemberPath="low"
            * 		closeMemberPath="close"
            * 		shortPeriod="10">
            *     </igx-absolute-volume-oscillator-indicator>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            * this.series.shortPeriod = 10;
            * ```
            */
        function () {
            return this.i.shortPeriod;
        },
        set: function (v) {
            this.i.shortPeriod = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAbsoluteVolumeOscillatorIndicatorComponent.prototype, "longPeriod", {
        /**
         * Gets or sets the short moving average period for the current AbsoluteVolumeOscillatorIndicator object.
         * The typical, and initial, value for long AVO periods is 30.
        *
        * You can use the `longPeriod` to set the long moving average period.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data" >
        *     <igx-category-x-axis
        * 		label="label"
        * 		#xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        * 		#yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-absolute-volume-oscillator-indicator
        * 		#series
        * 		[xAxis]="xAxis"
        * 		[yAxis]="yAxis"
        * 		openMemberPath="open"
        * 		highMemberPath="high"
        * 		lowMemberPath="low"
        * 		closeMemberPath="close"
        * 		longPeriod="30">
        *     </igx-absolute-volume-oscillator-indicator>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.series.longPeriod = 30;
        * ```
        */
        get: /**
             * Gets or sets the short moving average period for the current AbsoluteVolumeOscillatorIndicator object.
             * The typical, and initial, value for long AVO periods is 30.
            *
            * You can use the `longPeriod` to set the long moving average period.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data" >
            *     <igx-category-x-axis
            * 		label="label"
            * 		#xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            * 		#yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-absolute-volume-oscillator-indicator
            * 		#series
            * 		[xAxis]="xAxis"
            * 		[yAxis]="yAxis"
            * 		openMemberPath="open"
            * 		highMemberPath="high"
            * 		lowMemberPath="low"
            * 		closeMemberPath="close"
            * 		longPeriod="30">
            *     </igx-absolute-volume-oscillator-indicator>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            * this.series.longPeriod = 30;
            * ```
            */
        function () {
            return this.i.longPeriod;
        },
        set: function (v) {
            this.i.longPeriod = +v;
        },
        enumerable: true,
        configurable: true
    });
    IgxAbsoluteVolumeOscillatorIndicatorComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-absolute-volume-oscillator-indicator',
                    template: "",
                    providers: [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(function () { return IgxAbsoluteVolumeOscillatorIndicatorComponent; }) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(function () { return IgxAbsoluteVolumeOscillatorIndicatorComponent; }) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxAbsoluteVolumeOscillatorIndicatorComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxAbsoluteVolumeOscillatorIndicatorComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxAbsoluteVolumeOscillatorIndicatorComponent.ctorParameters = function () { return []; };
    IgxAbsoluteVolumeOscillatorIndicatorComponent.propDecorators = {
        "shortPeriod": [{ type: Input },],
        "longPeriod": [{ type: Input },],
    };
    return IgxAbsoluteVolumeOscillatorIndicatorComponent;
}(IgxStrategyBasedIndicatorComponent));
export { IgxAbsoluteVolumeOscillatorIndicatorComponent };
//# sourceMappingURL=igx-absolute-volume-oscillator-indicator-component.js.map