import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSeriesComponent } from "./igx-series-component";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES5/Visibility";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { CrosshairLayer } from "./CrosshairLayer";
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export var IgxCrosshairLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxCrosshairLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxCrosshairLayerComponent; }) }];
var IgxCrosshairLayerComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxCrosshairLayerComponent, _super);
    function IgxCrosshairLayerComponent() {
        return _super.call(this) || this;
    }
    IgxCrosshairLayerComponent.prototype.createImplementation = function () {
        return new CrosshairLayer();
    };
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "horizontalLineStroke", {
        /**
         * Gets or sets the color to use for the horizontal line. Leave null for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the horizontal line. Leave null for an automatic value.
            */
        function () {
            return brushToString(this.i.o0);
        },
        set: function (v) {
            this.i.o0 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "verticalLineStroke", {
        /**
         * Gets or sets the color to use for vertical line. Leave null for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for vertical line. Leave null for an automatic value.
            */
        function () {
            return brushToString(this.i.o1);
        },
        set: function (v) {
            this.i.o1 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "targetSeries", {
        /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: /**
             * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
            */
        function () {
            if (this.i.mx == null) {
                return null;
            }
            return this.i.mx.externalObject;
        },
        set: function (v) {
            v == null ? this.i.mx = null : this.i.mx = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "useInterpolation", {
        /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
        */
        get: /**
             * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
            */
        function () {
            return this.i.m2;
        },
        set: function (v) {
            this.i.m2 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "isAxisAnnotationEnabled", {
        /**
         * Gets or sets whether to draw annotations over the axes where the crosshair meets with them.
        */
        get: /**
             * Gets or sets whether to draw annotations over the axes where the crosshair meets with them.
            */
        function () {
            return this.i.m0;
        },
        set: function (v) {
            this.i.m0 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationTextColor", {
        /**
         * Gets or sets the color to use for the x axis annotation text. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the x axis annotation text. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.o4);
        },
        set: function (v) {
            this.i.o4 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationBackground", {
        /**
         * Gets or sets the color to use for the x axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the x axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.o2);
        },
        set: function (v) {
            this.i.o2 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationInterpolatedValuePrecision", {
        /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
        get: /**
             * Gets or sets the precision to use displaying values for interpolated crosshair positions.
            */
        function () {
            return this.i.nf;
        },
        set: function (v) {
            this.i.nf = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationOutline", {
        /**
         * Gets or sets the color to use for the x axis annotation outline. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the x axis annotation outline. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.o3);
        },
        set: function (v) {
            this.i.o3 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationPaddingLeft", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: /**
             * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
            */
        function () {
            return this.i.m6;
        },
        set: function (v) {
            this.i.m6 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationPaddingTop", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: /**
             * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
            */
        function () {
            return this.i.m8;
        },
        set: function (v) {
            this.i.m8 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationPaddingRight", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: /**
             * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
            */
        function () {
            return this.i.m7;
        },
        set: function (v) {
            this.i.m7 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationPaddingBottom", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: /**
             * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
            */
        function () {
            return this.i.m5;
        },
        set: function (v) {
            this.i.m5 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationPaddingLeft", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: /**
             * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
            */
        function () {
            return this.i.nb;
        },
        set: function (v) {
            this.i.nb = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationPaddingTop", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: /**
             * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
            */
        function () {
            return this.i.nd;
        },
        set: function (v) {
            this.i.nd = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationPaddingRight", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: /**
             * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
            */
        function () {
            return this.i.nc;
        },
        set: function (v) {
            this.i.nc = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationPaddingBottom", {
        /**
         * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: /**
             * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
            */
        function () {
            return this.i.na;
        },
        set: function (v) {
            this.i.na = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationStrokeThickness", {
        /**
         * Gets or sets the stroke thickness for the x axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the stroke thickness for the x axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return this.i.m9;
        },
        set: function (v) {
            this.i.m9 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationTextColor", {
        /**
         * Gets or sets the color to use for the y axis annotation text. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the y axis annotation text. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.o7);
        },
        set: function (v) {
            this.i.o7 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationBackground", {
        /**
         * Gets or sets the color to use for the y axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the y axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.o5);
        },
        set: function (v) {
            this.i.o5 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationInterpolatedValuePrecision", {
        /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
        get: /**
             * Gets or sets the precision to use displaying values for interpolated crosshair positions.
            */
        function () {
            return this.i.ng;
        },
        set: function (v) {
            this.i.ng = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationOutline", {
        /**
         * Gets or sets the color to use for the y axis annotation outline. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the y axis annotation outline. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.o6);
        },
        set: function (v) {
            this.i.o6 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationStrokeThickness", {
        /**
         * Gets or sets the stroke thickness for the y axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the stroke thickness for the y axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return this.i.ne;
        },
        set: function (v) {
            this.i.ne = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "verticalLineVisibility", {
        /**
         * Gets or sets whether to display the vertical line.
        */
        get: /**
             * Gets or sets whether to display the vertical line.
            */
        function () {
            return this.i.pb;
        },
        set: function (v) {
            this.i.pb = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "horizontalLineVisibility", {
        /**
         * Gets or sets whether to display the horizontal line.
        */
        get: /**
             * Gets or sets whether to display the horizontal line.
            */
        function () {
            return this.i.pa;
        },
        set: function (v) {
            this.i.pa = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "skipUnknownValues", {
        /**
         * Gets or sets whether to skip unknown values when searching for series values.
        */
        get: /**
             * Gets or sets whether to skip unknown values when searching for series values.
            */
        function () {
            return this.i.m1;
        },
        set: function (v) {
            this.i.m1 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    IgxCrosshairLayerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-crosshair-layer',
                    template: "",
                    providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxCrosshairLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxCrosshairLayerComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxCrosshairLayerComponent.ctorParameters = function () { return []; };
    IgxCrosshairLayerComponent.propDecorators = {
        "horizontalLineStroke": [{ type: Input },],
        "verticalLineStroke": [{ type: Input },],
        "targetSeries": [{ type: Input },],
        "useInterpolation": [{ type: Input },],
        "isAxisAnnotationEnabled": [{ type: Input },],
        "xAxisAnnotationTextColor": [{ type: Input },],
        "xAxisAnnotationBackground": [{ type: Input },],
        "xAxisAnnotationInterpolatedValuePrecision": [{ type: Input },],
        "xAxisAnnotationOutline": [{ type: Input },],
        "xAxisAnnotationPaddingLeft": [{ type: Input },],
        "xAxisAnnotationPaddingTop": [{ type: Input },],
        "xAxisAnnotationPaddingRight": [{ type: Input },],
        "xAxisAnnotationPaddingBottom": [{ type: Input },],
        "yAxisAnnotationPaddingLeft": [{ type: Input },],
        "yAxisAnnotationPaddingTop": [{ type: Input },],
        "yAxisAnnotationPaddingRight": [{ type: Input },],
        "yAxisAnnotationPaddingBottom": [{ type: Input },],
        "xAxisAnnotationStrokeThickness": [{ type: Input },],
        "yAxisAnnotationTextColor": [{ type: Input },],
        "yAxisAnnotationBackground": [{ type: Input },],
        "yAxisAnnotationInterpolatedValuePrecision": [{ type: Input },],
        "yAxisAnnotationOutline": [{ type: Input },],
        "yAxisAnnotationStrokeThickness": [{ type: Input },],
        "verticalLineVisibility": [{ type: Input },],
        "horizontalLineVisibility": [{ type: Input },],
        "skipUnknownValues": [{ type: Input },],
    };
    return IgxCrosshairLayerComponent;
}(IgxAnnotationLayerComponent));
export { IgxCrosshairLayerComponent };
//# sourceMappingURL=igx-crosshair-layer-component.js.map