import * as tslib_1 from "tslib";
import { EventEmitter, Output, forwardRef, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES5/type";
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxNumericYAxisComponent } from "./igx-numeric-y-axis-component";
import { CategoryTransitionInMode, CategoryTransitionInMode_$type } from "./CategoryTransitionInMode";
import { AssigningCategoryStyleEventArgs } from "./igx-assigning-category-style-event-args";
import { FinancialEventArgs } from "./igx-financial-event-args";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureBool, brushToString, stringToBrush, ensureEnum, toPoint, fromPoint } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents the base class for all financial indicator and overlay series.
*/
export var IgxFinancialSeriesComponent_PROVIDERS = [{ provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxFinancialSeriesComponent; }) }];
var IgxFinancialSeriesComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxFinancialSeriesComponent, _super);
    function IgxFinancialSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._assigningCategoryStyle = null;
        _this._typical = null;
        _this._typicalBasedOn = null;
        return _this;
    }
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "isFinancial", {
        /**
         * Gets whether the current series is a financial type series.
        */
        get: /**
             * Gets whether the current series is a financial type series.
            */
        function () {
            return this.i.cr;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "negativeBrush", {
        /**
         * Gets or sets the brush to use for negative portions of the series.
        */
        get: /**
             * Gets or sets the brush to use for negative portions of the series.
            */
        function () {
            return brushToString(this.i.o6);
        },
        set: function (v) {
            this.i.o6 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "xAxis", {
        /**
         * Gets or sets the effective x-axis for the current FinancialSeries object.
        */
        get: /**
             * Gets or sets the effective x-axis for the current FinancialSeries object.
            */
        function () {
            if (this.i.l0 == null) {
                return null;
            }
            return this.i.l0.externalObject;
        },
        set: function (v) {
            v == null ? this.i.l0 = null : this.i.l0 = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "yAxis", {
        /**
         * Gets or sets the effective y-axis for the current FinancialSeries object.
        */
        get: /**
             * Gets or sets the effective y-axis for the current FinancialSeries object.
            */
        function () {
            if (this.i.ml == null) {
                return null;
            }
            if (!this.i.ml.externalObject) {
                var e = new IgxNumericYAxisComponent();
                e._implementation = this.i.ml;
                this.i.ml.externalObject = e;
            }
            return this.i.ml.externalObject;
        },
        set: function (v) {
            v == null ? this.i.ml = null : this.i.ml = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "openMemberPath", {
        /**
         * Gets or sets the open mapping property for the current series object.
        */
        get: /**
             * Gets or sets the open mapping property for the current series object.
            */
        function () {
            return this.i.og;
        },
        set: function (v) {
            this.i.og = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "highMemberPath", {
        /**
         * Gets or sets the high mapping property for the current series object.
        */
        get: /**
             * Gets or sets the high mapping property for the current series object.
            */
        function () {
            return this.i.n7;
        },
        set: function (v) {
            this.i.n7 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "lowMemberPath", {
        /**
         * Gets or sets the low mapping property for the current series object.
        */
        get: /**
             * Gets or sets the low mapping property for the current series object.
            */
        function () {
            return this.i.oc;
        },
        set: function (v) {
            this.i.oc = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "closeMemberPath", {
        /**
         * Gets or sets the close mapping property for the current series object.
        */
        get: /**
             * Gets or sets the close mapping property for the current series object.
            */
        function () {
            return this.i.n4;
        },
        set: function (v) {
            this.i.n4 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "volumeMemberPath", {
        /**
         * Gets or sets the volume mapping property for the current series object.
        */
        get: /**
             * Gets or sets the volume mapping property for the current series object.
            */
        function () {
            return this.i.ok;
        },
        set: function (v) {
            this.i.ok = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "isCustomCategoryStyleAllowed", {
        /**
         * Gets or sets whether this category series should allow custom style overrides of its individual visuals.
        */
        get: /**
             * Gets or sets whether this category series should allow custom style overrides of its individual visuals.
            */
        function () {
            return this.i.m6;
        },
        set: function (v) {
            this.i.m6 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "transitionInMode", {
        /**
         * Gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
         * Note: Transitions are not currently supported for stacked series.
        */
        get: /**
             * Gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
             * Note: Transitions are not currently supported for stacked series.
            */
        function () {
            return this.i.ma;
        },
        set: function (v) {
            this.i.ma = ensureEnum(CategoryTransitionInMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "isTransitionInEnabled", {
        /**
         * Gets or sets whether the series should transition into the plot area when a new data source is assigned.
         * Note: Transitions are not currently supported for stacked series.
        */
        get: /**
             * Gets or sets whether the series should transition into the plot area when a new data source is assigned.
             * Note: Transitions are not currently supported for stacked series.
            */
        function () {
            return this.i.m7;
        },
        set: function (v) {
            this.i.m7 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "isNegativeColorSupported", {
        /**
         * Overridden by derived series classes to indicate when negative colors are supported or not.
        */
        get: /**
             * Overridden by derived series classes to indicate when negative colors are supported or not.
            */
        function () {
            return this.i.cz;
        },
        enumerable: true,
        configurable: true
    });
    IgxFinancialSeriesComponent.prototype.getPreviousOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.fb(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgxFinancialSeriesComponent.prototype.getNextOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.e9(toPoint(world), skipUnknowns);
        return (iv);
    };
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    /**
         * Returns the offset value for this series if grouped on a category axis.
        
        */
    IgxFinancialSeriesComponent.prototype.getOffsetValue = /**
         * Returns the offset value for this series if grouped on a category axis.
        
        */
    function () {
        var iv = this.i.getOffsetValue();
        return (iv);
    };
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    /**
         * Returns the width of the category grouping this series is in.
        
        */
    IgxFinancialSeriesComponent.prototype.getCategoryWidth = /**
         * Returns the width of the category grouping this series is in.
        
        */
    function () {
        var iv = this.i.getCategoryWidth();
        return (iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ld(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ek(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesHighValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.eg(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesLowValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ei(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesCloseValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ns(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesOpenValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.nt(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesVolumeValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.nu(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesHighValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.k9(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesLowValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.lb(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesOpenValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.o8(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesCloseValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.o7(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgxFinancialSeriesComponent.prototype.getSeriesVolumeValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.o9(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as YAxis
        
        * @param axis  * The object to check
        */
    IgxFinancialSeriesComponent.prototype.canUseAsYAxis = /**
         * Determine if object can be used as YAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.m2(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as XAxis
        
        * @param axis  * The object to check
        */
    IgxFinancialSeriesComponent.prototype.canUseAsXAxis = /**
         * Determine if object can be used as XAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.m1(axis);
        return (iv);
    };
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    /**
         * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
        
        * @param world  * The world position for which to return the index.
        */
    IgxFinancialSeriesComponent.prototype.getExactItemIndex = /**
         * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
        
        * @param world  * The world position for which to return the index.
        */
    function (world) {
        var iv = this.i.d8(toPoint(world));
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    /**
         * Gets the index of the item that resides at the provided world coordinates.
        
        * @param world  * The world coordinates of the requested item.
        */
    IgxFinancialSeriesComponent.prototype.getItemIndex = /**
         * Gets the index of the item that resides at the provided world coordinates.
        
        * @param world  * The world coordinates of the requested item.
        */
    function (world) {
        var iv = this.i.e5(toPoint(world));
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    IgxFinancialSeriesComponent.prototype.getItem = /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    function (world) {
        var iv = this.i.fm(toPoint(world));
        return (iv);
    };
    IgxFinancialSeriesComponent.prototype.setNegativeColors = function (negativeBrush, negativeOutline) {
        this.i.ja(stringToBrush(negativeBrush), stringToBrush(negativeOutline));
    };
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "assigningCategoryStyle", {
        get: /**
             * Event raised when Assigning Category Style
            */
        function () {
            var _this = this;
            if (this._assigningCategoryStyle == null) {
                this._assigningCategoryStyle = new EventEmitter();
                this.i.assigningCategoryStyle = delegateCombine(this.i.assigningCategoryStyle, function (o, e) {
                    var outerArgs = new AssigningCategoryStyleEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeAssigningCategoryStyle) {
                        _this.beforeAssigningCategoryStyle(_this, outerArgs);
                    }
                    _this._assigningCategoryStyle.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._assigningCategoryStyle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "typical", {
        get: /**
             * Handle this event in order to perform a custom typical price calculation.
            */
        function () {
            var _this = this;
            if (this._typical == null) {
                this._typical = new EventEmitter();
                this.i.typical = delegateCombine(this.i.typical, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new FinancialEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeTypical) {
                            _this.beforeTypical(_this, outerArgs);
                        }
                        _this._typical.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._typical;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinancialSeriesComponent.prototype, "typicalBasedOn", {
        get: /**
             * Handle this event in order to specify which columns the Typical price calculation is based on.
            */
        function () {
            var _this = this;
            if (this._typicalBasedOn == null) {
                this._typicalBasedOn = new EventEmitter();
                this.i.typicalBasedOn = delegateCombine(this.i.typicalBasedOn, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new FinancialEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeTypicalBasedOn) {
                            _this.beforeTypicalBasedOn(_this, outerArgs);
                        }
                        _this._typicalBasedOn.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._typicalBasedOn;
        },
        enumerable: true,
        configurable: true
    });
    IgxFinancialSeriesComponent.propDecorators = {
        "negativeBrush": [{ type: Input },],
        "xAxis": [{ type: Input },],
        "yAxis": [{ type: Input },],
        "openMemberPath": [{ type: Input },],
        "highMemberPath": [{ type: Input },],
        "lowMemberPath": [{ type: Input },],
        "closeMemberPath": [{ type: Input },],
        "volumeMemberPath": [{ type: Input },],
        "isCustomCategoryStyleAllowed": [{ type: Input },],
        "transitionInMode": [{ type: Input },],
        "isTransitionInEnabled": [{ type: Input },],
        "assigningCategoryStyle": [{ type: Output },],
        "typical": [{ type: Output },],
        "typicalBasedOn": [{ type: Output },],
    };
    return IgxFinancialSeriesComponent;
}(IgxSeriesComponent));
export { IgxFinancialSeriesComponent };
//# sourceMappingURL=igx-financial-series-component.js.map