import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxNumericYAxisComponent } from "./igx-numeric-y-axis-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { HighDensityScatterSeries } from "./HighDensityScatterSeries";
import { ensureBool, colorToString, stringToColor, toPoint } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent series where a high volume of scatter points can be displayed.
*/
export var IgxHighDensityScatterSeriesComponent_PROVIDERS = [{ provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxHighDensityScatterSeriesComponent; }) }];
var IgxHighDensityScatterSeriesComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxHighDensityScatterSeriesComponent, _super);
    function IgxHighDensityScatterSeriesComponent() {
        return _super.call(this) || this;
    }
    IgxHighDensityScatterSeriesComponent.prototype.createImplementation = function () {
        return new HighDensityScatterSeries();
    };
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "isScatter", {
        /**
         * Checks if this series is a scatter series
        */
        get: /**
             * Checks if this series is a scatter series
            */
        function () {
            return this.i.c4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "xAxis", {
        /**
         * Gets or sets the effective x-axis for the current object.
        */
        get: /**
             * Gets or sets the effective x-axis for the current object.
            */
        function () {
            if (this.i.lz == null) {
                return null;
            }
            if (!this.i.lz.externalObject) {
                var e = new IgxNumericXAxisComponent();
                e._implementation = this.i.lz;
                this.i.lz.externalObject = e;
            }
            return this.i.lz.externalObject;
        },
        set: function (v) {
            v == null ? this.i.lz = null : this.i.lz = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "yAxis", {
        /**
         * Gets or sets the effective y-axis for the current object.
        */
        get: /**
             * Gets or sets the effective y-axis for the current object.
            */
        function () {
            if (this.i.l1 == null) {
                return null;
            }
            if (!this.i.l1.externalObject) {
                var e = new IgxNumericYAxisComponent();
                e._implementation = this.i.l1;
                this.i.l1.externalObject = e;
            }
            return this.i.l1.externalObject;
        },
        set: function (v) {
            v == null ? this.i.l1 = null : this.i.l1 = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "xMemberPath", {
        /**
         * Gets or sets the x value mapping property for the current series object.
        */
        get: /**
             * Gets or sets the x value mapping property for the current series object.
            */
        function () {
            return this.i.nv;
        },
        set: function (v) {
            this.i.nv = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "yMemberPath", {
        /**
         * Gets or sets the y value mapping property for the current series object.
        */
        get: /**
             * Gets or sets the y value mapping property for the current series object.
            */
        function () {
            return this.i.nz;
        },
        set: function (v) {
            this.i.nz = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "useBruteForce", {
        /**
         * Gets or sets the whether to use use brute force mode.
        */
        get: /**
             * Gets or sets the whether to use use brute force mode.
            */
        function () {
            return this.i.mf;
        },
        set: function (v) {
            this.i.mf = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "progressiveLoad", {
        /**
         * Gets or sets the whether to progressively load the data into the chart.
        */
        get: /**
             * Gets or sets the whether to progressively load the data into the chart.
            */
        function () {
            return this.i.me;
        },
        set: function (v) {
            this.i.me = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "heatMinimum", {
        /**
         * Gets or sets the density value that maps to the minimum heat color.
        */
        get: /**
             * Gets or sets the density value that maps to the minimum heat color.
            */
        function () {
            return this.i.m7;
        },
        set: function (v) {
            this.i.m7 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "heatMaximum", {
        /**
         * Gets or sets the value that maps to the maximum heat color.
        */
        get: /**
             * Gets or sets the value that maps to the maximum heat color.
            */
        function () {
            return this.i.m6;
        },
        set: function (v) {
            this.i.m6 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "heatMinimumColor", {
        /**
         * Gets or sets the color to use for the minimum end of the scale.
        */
        get: /**
             * Gets or sets the color to use for the minimum end of the scale.
            */
        function () {
            return colorToString(this.i.os);
        },
        set: function (v) {
            this.i.os = stringToColor(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "heatMaximumColor", {
        /**
         * Gets or sets the color to use for the maximum end of the scale.
        */
        get: /**
             * Gets or sets the color to use for the maximum end of the scale.
            */
        function () {
            return colorToString(this.i.or);
        },
        set: function (v) {
            this.i.or = stringToColor(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "pointExtent", {
        /**
         * Gets or sets the the pixel extent of the square data points that are rendered.
        */
        get: /**
             * Gets or sets the the pixel extent of the square data points that are rendered.
            */
        function () {
            return this.i.nj;
        },
        set: function (v) {
            this.i.nj = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighDensityScatterSeriesComponent.prototype, "progressiveStatus", {
        /**
         * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
        */
        get: /**
             * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
            */
        function () {
            return this.i.nk;
        },
        set: function (v) {
            this.i.nk = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as YAxis
        
        * @param axis  * The object to check
        */
    IgxHighDensityScatterSeriesComponent.prototype.canUseAsYAxis = /**
         * Determine if object can be used as YAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.md(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as XAxis
        
        * @param axis  * The object to check
        */
    IgxHighDensityScatterSeriesComponent.prototype.canUseAsXAxis = /**
         * Determine if object can be used as XAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.mc(axis);
        return (iv);
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    IgxHighDensityScatterSeriesComponent.prototype.scrollIntoView = /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    function (item) {
        var iv = this.i.c8(item);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    IgxHighDensityScatterSeriesComponent.prototype.getItem = /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    function (world) {
        var iv = this.i.fm(toPoint(world));
        return (iv);
    };
    IgxHighDensityScatterSeriesComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-high-density-scatter-series',
                    template: "",
                    providers: [{ provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxHighDensityScatterSeriesComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxHighDensityScatterSeriesComponent.ctorParameters = function () { return []; };
    IgxHighDensityScatterSeriesComponent.propDecorators = {
        "xAxis": [{ type: Input },],
        "yAxis": [{ type: Input },],
        "xMemberPath": [{ type: Input },],
        "yMemberPath": [{ type: Input },],
        "useBruteForce": [{ type: Input },],
        "progressiveLoad": [{ type: Input },],
        "heatMinimum": [{ type: Input },],
        "heatMaximum": [{ type: Input },],
        "heatMinimumColor": [{ type: Input },],
        "heatMaximumColor": [{ type: Input },],
        "pointExtent": [{ type: Input },],
        "progressiveStatus": [{ type: Input },],
    };
    return IgxHighDensityScatterSeriesComponent;
}(IgxSeriesComponent));
export { IgxHighDensityScatterSeriesComponent };
//# sourceMappingURL=igx-high-density-scatter-series-component.js.map