import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { MarkerType, MarkerType_$type } from "./MarkerType";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents the base class for series containing markers.
*
* MarkerSeries represents the base class for series containing markers.
*
* Example:
*
* ```html
* <igx-data-chart
*     [dataSource]="data">
* 	<igx-category-x-axis
*         label="label"
*         #xAxis
*         >
*       </igx-category-x-axis>
*       <igx-numeric-y-axis
*         minimumValue="0"
*         #yAxis>
*       </igx-numeric-y-axis>
* 	 <igx-column-series
*         #series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*      valueMemberPath="value">
*      </igx-column-series>
* </igx-data-chart>
* ```
*/
export var IgxMarkerSeriesComponent_PROVIDERS = [{ provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxMarkerSeriesComponent; }) }];
var IgxMarkerSeriesComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxMarkerSeriesComponent, _super);
    function IgxMarkerSeriesComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "hasMarkers", {
        /**
         * Returns whether the current series supports visual markers.
        *
        * `hasMarkers` property is overriden, it returns whether the current series supports visual markers. You can use it like this:
        *
        * ```ts
        *  let gotMarkers: boolean = this.series.hasMarkers;
        * ```
        */
        get: /**
             * Returns whether the current series supports visual markers.
            *
            * `hasMarkers` property is overriden, it returns whether the current series supports visual markers. You can use it like this:
            *
            * ```ts
            *  let gotMarkers: boolean = this.series.hasMarkers;
            * ```
            */
        function () {
            return this.i.hasMarkers;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        *
        * `markerType` property gets or sets the marker type for the current series object. For example, you can set it like this:
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data">
        * 	 <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        * 	 <igx-column-series
        *         #series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *      valueMemberPath="value">
        * 	 markerType = "circle">
        *      </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the marker type for the current series object.
             * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
            *
            * `markerType` property gets or sets the marker type for the current series object. For example, you can set it like this:
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data">
            * 	 <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            * 	 <igx-column-series
            *         #series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *      valueMemberPath="value">
            * 	 markerType = "circle">
            *      </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.lt;
        },
        set: function (v) {
            this.i.lt = ensureEnum(MarkerType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        *
        * `markerTemplate` property gets or sets the MarkerTemplate for the current series object. For example, you can use it like this:
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data">
        * 	<igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *       </igx-category-x-axis>
        *       <igx-numeric-y-axis #yAxis>
        *       </igx-numeric-y-axis>
        * 	 <igx-column-series
        *         #series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *      valueMemberPath="value">
        * 	 markerTemplate="circleMarkerTemplate">
        *      </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the MarkerTemplate for the current series object.
            *
            * `markerTemplate` property gets or sets the MarkerTemplate for the current series object. For example, you can use it like this:
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data">
            * 	<igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *       </igx-category-x-axis>
            *       <igx-numeric-y-axis #yAxis>
            *       </igx-numeric-y-axis>
            * 	 <igx-column-series
            *         #series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *      valueMemberPath="value">
            * 	 markerTemplate="circleMarkerTemplate">
            *      </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.mc;
        },
        set: function (v) {
            this.i.mc = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        *
        * `actualMarkerTemplate` property gets the effective marker template for the current series object. You can use it like this:
        *
        * ```ts
        *  let effectiveMarkerTemplate: IgxDataTemplate = this.series.actualMarkerTemplate;
        * ```
        */
        get: /**
             * Gets the effective marker template for the current series object.
            *
            * `actualMarkerTemplate` property gets the effective marker template for the current series object. You can use it like this:
            *
            * ```ts
            *  let effectiveMarkerTemplate: IgxDataTemplate = this.series.actualMarkerTemplate;
            * ```
            */
        function () {
            return this.i.ma;
        },
        set: function (v) {
            this.i.ma = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        *
        * `markerBrush` property gets or sets the brush that specifies how the current series object's marker interiors are painted. You can use it like this:
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data">
        * 	<igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *       </igx-category-x-axis>
        *       <igx-numeric-y-axis #yAxis>
        *       </igx-numeric-y-axis>
        * 	 <igx-column-series
        *         #series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *      valueMemberPath="value"
        * 	 markerBrush = "blue">
        *      </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
            *
            * `markerBrush` property gets or sets the brush that specifies how the current series object's marker interiors are painted. You can use it like this:
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data">
            * 	<igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *       </igx-category-x-axis>
            *       <igx-numeric-y-axis #yAxis>
            *       </igx-numeric-y-axis>
            * 	 <igx-column-series
            *         #series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *      valueMemberPath="value"
            * 	 markerBrush = "blue">
            *      </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return brushToString(this.i.mp);
        },
        set: function (v) {
            this.i.mp = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        *
        * `actualMarkerBrush` property gets the effective marker brush for the current series object. For example, you can use it like this:
        *
        * ```ts
        *  let effectiveMarkerBrush: string = this.series.actualMarkerBrush;
        *
        * ```
        */
        get: /**
             * Gets the effective marker brush for the current series object.
            *
            * `actualMarkerBrush` property gets the effective marker brush for the current series object. For example, you can use it like this:
            *
            * ```ts
            *  let effectiveMarkerBrush: string = this.series.actualMarkerBrush;
            *
            * ```
            */
        function () {
            return brushToString(this.i.mn);
        },
        set: function (v) {
            this.i.mn = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        *
        * `markerOutline` property gets or sets the brush that specifies how the current series object's marker outlines are painted. You can use it like this:
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data">
        * 	<igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *       </igx-category-x-axis>
        *       <igx-numeric-y-axis #yAxis>
        *       </igx-numeric-y-axis>
        * 	 <igx-column-series
        *         #series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *      valueMemberPath="value">
        * 	 markerOutline = "blue">
        *      </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
            *
            * `markerOutline` property gets or sets the brush that specifies how the current series object's marker outlines are painted. You can use it like this:
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data">
            * 	<igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *       </igx-category-x-axis>
            *       <igx-numeric-y-axis #yAxis>
            *       </igx-numeric-y-axis>
            * 	 <igx-column-series
            *         #series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *      valueMemberPath="value">
            * 	 markerOutline = "blue">
            *      </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return brushToString(this.i.mq);
        },
        set: function (v) {
            this.i.mq = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        *
        * `actualMarkerOutline` property gets the effective marker outline for the current series object. You can use it like this:
        *
        * ```ts
        *  let effectiveMarkerOutline: string = this.series.actualMarkerOutline;
        *
        * ```
        */
        get: /**
             * Gets the effective marker outline for the current series object.
            *
            * `actualMarkerOutline` property gets the effective marker outline for the current series object. You can use it like this:
            *
            * ```ts
            *  let effectiveMarkerOutline: string = this.series.actualMarkerOutline;
            *
            * ```
            */
        function () {
            return brushToString(this.i.mo);
        },
        set: function (v) {
            this.i.mo = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    IgxMarkerSeriesComponent.propDecorators = {
        "markerType": [{ type: Input },],
        "markerTemplate": [{ type: Input },],
        "actualMarkerTemplate": [{ type: Input },],
        "markerBrush": [{ type: Input },],
        "actualMarkerBrush": [{ type: Input },],
        "markerOutline": [{ type: Input },],
        "actualMarkerOutline": [{ type: Input },],
    };
    return IgxMarkerSeriesComponent;
}(IgxSeriesComponent));
export { IgxMarkerSeriesComponent };
//# sourceMappingURL=igx-marker-series-component.js.map