import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { IgxNumericAngleAxisComponent } from "./igx-numeric-angle-axis-component";
import { IgxNumericRadiusAxisComponent } from "./igx-numeric-radius-axis-component";
import { TrendLineType, TrendLineType_$type } from "igniteui-angular-core/ES5/TrendLineType";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureBool, ensureEnum, brushToString, stringToBrush, toPoint } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents the base class from which all IgxDataChartComponent polar series are derived.
*/
export var IgxPolarBaseComponent_PROVIDERS = [{ provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxPolarBaseComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxPolarBaseComponent; }) }];
var IgxPolarBaseComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxPolarBaseComponent, _super);
    function IgxPolarBaseComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxPolarBaseComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "isPolar", {
        /**
         * Checks if this series is a polar series
        */
        get: /**
             * Checks if this series is a polar series
            */
        function () {
            return this.i.c0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "angleMemberPath", {
        /**
         * Gets or sets the path to use to find the angle values for the series.
        */
        get: /**
             * Gets or sets the path to use to find the angle values for the series.
            */
        function () {
            return this.i.no;
        },
        set: function (v) {
            this.i.no = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "radiusMemberPath", {
        /**
         * Gets or sets the path to use to get the radius values for the series.
        */
        get: /**
             * Gets or sets the path to use to get the radius values for the series.
            */
        function () {
            return this.i.nu;
        },
        set: function (v) {
            this.i.nu = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "angleAxis", {
        /**
         * Gets the effective angle axis for the current series object.
        */
        get: /**
             * Gets the effective angle axis for the current series object.
            */
        function () {
            if (this.i.mv == null) {
                return null;
            }
            if (!this.i.mv.externalObject) {
                var e = new IgxNumericAngleAxisComponent();
                e._implementation = this.i.mv;
                this.i.mv.externalObject = e;
            }
            return this.i.mv.externalObject;
        },
        set: function (v) {
            v == null ? this.i.mv = null : this.i.mv = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "radiusAxis", {
        /**
         * Gets the effective radius axis for the current series object.
        */
        get: /**
             * Gets the effective radius axis for the current series object.
            */
        function () {
            if (this.i.mw == null) {
                return null;
            }
            if (!this.i.mw.externalObject) {
                var e = new IgxNumericRadiusAxisComponent();
                e._implementation = this.i.mw;
                this.i.mw.externalObject = e;
            }
            return this.i.mw.externalObject;
        },
        set: function (v) {
            v == null ? this.i.mw = null : this.i.mw = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "useCartesianInterpolation", {
        /**
         * Gets or sets whether Cartesian Interpolation should be used rather than Archimedian
         * spiral based interpolation.
        */
        get: /**
             * Gets or sets whether Cartesian Interpolation should be used rather than Archimedian
             * spiral based interpolation.
            */
        function () {
            return this.i.ng;
        },
        set: function (v) {
            this.i.ng = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "maximumMarkers", {
        /**
         * Gets or sets the maximum number of markers displayed by the current series.
         * If more than the specified number of markers are visible, the polar series will automatically
         * choose a representative set.
        */
        get: /**
             * Gets or sets the maximum number of markers displayed by the current series.
             * If more than the specified number of markers are visible, the polar series will automatically
             * choose a representative set.
            */
        function () {
            return this.i.nj;
        },
        set: function (v) {
            this.i.nj = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "trendLineType", {
        /**
         * Gets or sets the trend type for the current series object.
        */
        get: /**
             * Gets or sets the trend type for the current series object.
            */
        function () {
            return this.i.m7;
        },
        set: function (v) {
            this.i.m7 = ensureEnum(TrendLineType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "trendLineBrush", {
        /**
         * Gets or sets the brush that specifies how the current series
         * object's trend line is drawn.
        */
        get: /**
             * Gets or sets the brush that specifies how the current series
             * object's trend line is drawn.
            */
        function () {
            return brushToString(this.i.ok);
        },
        set: function (v) {
            this.i.ok = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "actualTrendLineBrush", {
        /**
         * Gets the effective TrendLineBrush for this series.
        */
        get: /**
             * Gets the effective TrendLineBrush for this series.
            */
        function () {
            return brushToString(this.i.oj);
        },
        set: function (v) {
            this.i.oj = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "trendLineThickness", {
        /**
         * Gets or sets the thickness of the current series object's trend line.
        */
        get: /**
             * Gets or sets the thickness of the current series object's trend line.
            */
        function () {
            return this.i.ni;
        },
        set: function (v) {
            this.i.ni = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "trendLinePeriod", {
        /**
         * Gets or sets the moving average period for the current series object.
        */
        get: /**
             * Gets or sets the moving average period for the current series object.
            */
        function () {
            return this.i.nk;
        },
        set: function (v) {
            this.i.nk = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "trendLineZIndex", {
        /**
         * Sets or Gets the Trendline Z index.
        */
        get: /**
             * Sets or Gets the Trendline Z index.
            */
        function () {
            return this.i.nl;
        },
        set: function (v) {
            this.i.nl = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxPolarBaseComponent.prototype, "clipSeriesToBounds", {
        /**
         * Gets or sets whether to clip the series to the bounds.
         * Setting this to true can effect performance.
        */
        get: /**
             * Gets or sets whether to clip the series to the bounds.
             * Setting this to true can effect performance.
            */
        function () {
            return this.i.ne;
        },
        set: function (v) {
            this.i.ne = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Scrolls the requested item into view, if possible.
    
    * @param item  * The item to scroll into view.
    */
    /**
         * Scrolls the requested item into view, if possible.
        
        * @param item  * The item to scroll into view.
        */
    IgxPolarBaseComponent.prototype.scrollIntoView = /**
         * Scrolls the requested item into view, if possible.
        
        * @param item  * The item to scroll into view.
        */
    function (item) {
        var iv = this.i.c8(item);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    IgxPolarBaseComponent.prototype.getItem = /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    function (world) {
        var iv = this.i.fm(toPoint(world));
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    /**
         * Gets the index of the item that resides at the provided world coordinates.
        
        * @param world  * The world coordinates of the requested item.
        */
    IgxPolarBaseComponent.prototype.getItemIndex = /**
         * Gets the index of the item that resides at the provided world coordinates.
        
        * @param world  * The world coordinates of the requested item.
        */
    function (world) {
        var iv = this.i.e5(toPoint(world));
        return (iv);
    };
    /**
     * Determine if object can be used as RadiusAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as RadiusAxis
        
        * @param axis  * The object to check
        */
    IgxPolarBaseComponent.prototype.canUseAsRadiusAxis = /**
         * Determine if object can be used as RadiusAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.nd(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as AngleAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as AngleAxis
        
        * @param axis  * The object to check
        */
    IgxPolarBaseComponent.prototype.canUseAsAngleAxis = /**
         * Determine if object can be used as AngleAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.nc(axis);
        return (iv);
    };
    IgxPolarBaseComponent.propDecorators = {
        "angleMemberPath": [{ type: Input },],
        "radiusMemberPath": [{ type: Input },],
        "angleAxis": [{ type: Input },],
        "radiusAxis": [{ type: Input },],
        "useCartesianInterpolation": [{ type: Input },],
        "maximumMarkers": [{ type: Input },],
        "trendLineType": [{ type: Input },],
        "trendLineBrush": [{ type: Input },],
        "actualTrendLineBrush": [{ type: Input },],
        "trendLineThickness": [{ type: Input },],
        "trendLinePeriod": [{ type: Input },],
        "trendLineZIndex": [{ type: Input },],
        "clipSeriesToBounds": [{ type: Input },],
    };
    return IgxPolarBaseComponent;
}(IgxMarkerSeriesComponent));
export { IgxPolarBaseComponent };
//# sourceMappingURL=igx-polar-base-component.js.map