import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { IgxCategoryAngleAxisComponent } from "./igx-category-angle-axis-component";
import { IgxNumericRadiusAxisComponent } from "./igx-numeric-radius-axis-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureBool, toPoint } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent radial series
*/
export var IgxRadialBaseComponent_PROVIDERS = [{ provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxRadialBaseComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxRadialBaseComponent; }) }];
var IgxRadialBaseComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxRadialBaseComponent, _super);
    function IgxRadialBaseComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxRadialBaseComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "isRadial", {
        /**
         * Checks if this series is a radial series
        */
        get: /**
             * Checks if this series is a radial series
            */
        function () {
            return this.i.c2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "angleAxis", {
        /**
         * Gets the effective angle axis for the current series object.
        */
        get: /**
             * Gets the effective angle axis for the current series object.
            */
        function () {
            if (this.i.ms == null) {
                return null;
            }
            if (!this.i.ms.externalObject) {
                var e = new IgxCategoryAngleAxisComponent();
                e._implementation = this.i.ms;
                this.i.ms.externalObject = e;
            }
            return this.i.ms.externalObject;
        },
        set: function (v) {
            v == null ? this.i.ms = null : this.i.ms = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "valueAxis", {
        /**
         * Gets the effective value axis for the current series object.
        */
        get: /**
             * Gets the effective value axis for the current series object.
            */
        function () {
            if (this.i.mu == null) {
                return null;
            }
            if (!this.i.mu.externalObject) {
                var e = new IgxNumericRadiusAxisComponent();
                e._implementation = this.i.mu;
                this.i.mu.externalObject = e;
            }
            return this.i.mu.externalObject;
        },
        set: function (v) {
            v == null ? this.i.mu = null : this.i.mu = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxRadialBaseComponent.prototype, "clipSeriesToBounds", {
        /**
         * Gets or sets whether to clip the series to the bounds.
         * Setting this property to true will decrease chart performance.
        */
        get: /**
             * Gets or sets whether to clip the series to the bounds.
             * Setting this property to true will decrease chart performance.
            */
        function () {
            return this.i.m3;
        },
        set: function (v) {
            this.i.m3 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Determine if object can be used as ValueAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as ValueAxis
        
        * @param axis  * The object to check
        */
    IgxRadialBaseComponent.prototype.canUseAsValueAxis = /**
         * Determine if object can be used as ValueAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.m2(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as AngleAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as AngleAxis
        
        * @param axis  * The object to check
        */
    IgxRadialBaseComponent.prototype.canUseAsAngleAxis = /**
         * Determine if object can be used as AngleAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.m1(axis);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    IgxRadialBaseComponent.prototype.getItem = /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    function (world) {
        var iv = this.i.fm(toPoint(world));
        return (iv);
    };
    /**
     * Gets the angle to the provided world position from the center of the radial series.
    
    * @param world  * The world position to get the angle for
    */
    /**
         * Gets the angle to the provided world position from the center of the radial series.
        
        * @param world  * The world position to get the angle for
        */
    IgxRadialBaseComponent.prototype.getAngleFromWorld = /**
         * Gets the angle to the provided world position from the center of the radial series.
        
        * @param world  * The world position to get the angle for
        */
    function (world) {
        var iv = this.i.m5(toPoint(world));
        return (iv);
    };
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    /**
         * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
        
        * @param world  * The world position for which to return the index.
        */
    IgxRadialBaseComponent.prototype.getExactItemIndex = /**
         * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
        
        * @param world  * The world position for which to return the index.
        */
    function (world) {
        var iv = this.i.m6(toPoint(world));
        return (iv);
    };
    /**
     * Get the index of the item near the provided world coordinates.
    
    * @param world  * The world coordinates for which to getch the item index.
    */
    /**
         * Get the index of the item near the provided world coordinates.
        
        * @param world  * The world coordinates for which to getch the item index.
        */
    IgxRadialBaseComponent.prototype.getItemIndex = /**
         * Get the index of the item near the provided world coordinates.
        
        * @param world  * The world coordinates for which to getch the item index.
        */
    function (world) {
        var iv = this.i.e5(toPoint(world));
        return (iv);
    };
    /**
     * Scrolls the specified item into the view.
    
    * @param item  * The item to scroll into view.
    */
    /**
         * Scrolls the specified item into the view.
        
        * @param item  * The item to scroll into view.
        */
    IgxRadialBaseComponent.prototype.scrollIntoView = /**
         * Scrolls the specified item into the view.
        
        * @param item  * The item to scroll into view.
        */
    function (item) {
        var iv = this.i.c8(item);
        return (iv);
    };
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    /**
         * Returns the offset value for this series if grouped on a category axis.
        
        */
    IgxRadialBaseComponent.prototype.getOffsetValue = /**
         * Returns the offset value for this series if grouped on a category axis.
        
        */
    function () {
        var iv = this.i.getOffsetValue();
        return (iv);
    };
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    /**
         * Returns the width of the category grouping this series is in.
        
        */
    IgxRadialBaseComponent.prototype.getCategoryWidth = /**
         * Returns the width of the category grouping this series is in.
        
        */
    function () {
        var iv = this.i.getCategoryWidth();
        return (iv);
    };
    IgxRadialBaseComponent.propDecorators = {
        "angleAxis": [{ type: Input },],
        "valueAxis": [{ type: Input },],
        "clipSeriesToBounds": [{ type: Input },],
    };
    return IgxRadialBaseComponent;
}(IgxMarkerSeriesComponent));
export { IgxRadialBaseComponent };
//# sourceMappingURL=igx-radial-base-component.js.map