import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxNumericYAxisComponent } from "./igx-numeric-y-axis-component";
import { TrendLineType, TrendLineType_$type } from "igniteui-angular-core/ES5/TrendLineType";
import { CollisionAvoidanceType, CollisionAvoidanceType_$type } from "./CollisionAvoidanceType";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureEnum, brushToString, stringToBrush, toPoint, fromRect } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent scatter series
*/
export var IgxScatterBaseComponent_PROVIDERS = [{ provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxScatterBaseComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxScatterBaseComponent; }) }];
var IgxScatterBaseComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxScatterBaseComponent, _super);
    function IgxScatterBaseComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxScatterBaseComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "isScatter", {
        /**
         * Checks if this series is a scatter series
        */
        get: /**
             * Checks if this series is a scatter series
            */
        function () {
            return this.i.c4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "xAxis", {
        /**
         * Gets or sets the effective x-axis for the current object.
        */
        get: /**
             * Gets or sets the effective x-axis for the current object.
            */
        function () {
            if (this.i.xAxis == null) {
                return null;
            }
            if (!this.i.xAxis.externalObject) {
                var e = new IgxNumericXAxisComponent();
                e._implementation = this.i.xAxis;
                this.i.xAxis.externalObject = e;
            }
            return this.i.xAxis.externalObject;
        },
        set: function (v) {
            v == null ? this.i.xAxis = null : this.i.xAxis = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "yAxis", {
        /**
         * Gets or sets the effective y-axis for the current object.
        */
        get: /**
             * Gets or sets the effective y-axis for the current object.
            */
        function () {
            if (this.i.yAxis == null) {
                return null;
            }
            if (!this.i.yAxis.externalObject) {
                var e = new IgxNumericYAxisComponent();
                e._implementation = this.i.yAxis;
                this.i.yAxis.externalObject = e;
            }
            return this.i.yAxis.externalObject;
        },
        set: function (v) {
            v == null ? this.i.yAxis = null : this.i.yAxis = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "xMemberPath", {
        /**
         * Gets or sets the value mapping property for the current series object.
        */
        get: /**
             * Gets or sets the value mapping property for the current series object.
            */
        function () {
            return this.i.nj;
        },
        set: function (v) {
            this.i.nj = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "yMemberPath", {
        /**
         * Gets or sets the value mapping property for the current series object.
        */
        get: /**
             * Gets or sets the value mapping property for the current series object.
            */
        function () {
            return this.i.nn;
        },
        set: function (v) {
            this.i.nn = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "trendLineType", {
        /**
         * Gets or sets the trend type for the current scatter series.
        */
        get: /**
             * Gets or sets the trend type for the current scatter series.
            */
        function () {
            return this.i.trendLineType;
        },
        set: function (v) {
            this.i.trendLineType = ensureEnum(TrendLineType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "trendLineBrush", {
        /**
         * Gets or sets the brush to use to draw the trend line.
        */
        get: /**
             * Gets or sets the brush to use to draw the trend line.
            */
        function () {
            return brushToString(this.i.trendLineBrush);
        },
        set: function (v) {
            this.i.trendLineBrush = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "actualTrendLineBrush", {
        /**
         * Gets the effective TrendLineBrush for this series.
        */
        get: /**
             * Gets the effective TrendLineBrush for this series.
            */
        function () {
            return brushToString(this.i.ok);
        },
        set: function (v) {
            this.i.ok = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "trendLineThickness", {
        /**
         * Gets or sets the thickness of the current scatter series object's trend line.
        */
        get: /**
             * Gets or sets the thickness of the current scatter series object's trend line.
            */
        function () {
            return this.i.trendLineThickness;
        },
        set: function (v) {
            this.i.trendLineThickness = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "trendLinePeriod", {
        /**
         * Gets or sets the moving average period for the current scatter series object.
         * The typical, and initial, value for trend line period is 7.
        */
        get: /**
             * Gets or sets the moving average period for the current scatter series object.
             * The typical, and initial, value for trend line period is 7.
            */
        function () {
            return this.i.trendLinePeriod;
        },
        set: function (v) {
            this.i.trendLinePeriod = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "markerCollisionAvoidance", {
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get: /**
             * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
            */
        function () {
            return this.i.mt;
        },
        set: function (v) {
            this.i.mt = ensureEnum(CollisionAvoidanceType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "trendLineZIndex", {
        /**
         * Gets or sets the Z-Index of the trend line.  Values greater than 1000 will result in the trend line being rendered in front of the series data.
        */
        get: /**
             * Gets or sets the Z-Index of the trend line.  Values greater than 1000 will result in the trend line being rendered in front of the series data.
            */
        function () {
            return this.i.nd;
        },
        set: function (v) {
            this.i.nd = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterBaseComponent.prototype, "maximumMarkers", {
        /**
         * Gets or sets the maximum number of markerItems displayed by the current series.
         * If more than the specified number of markerItems are visible, the series will automatically
         * choose a representative set.
        */
        get: /**
             * Gets or sets the maximum number of markerItems displayed by the current series.
             * If more than the specified number of markerItems are visible, the series will automatically
             * choose a representative set.
            */
        function () {
            return this.i.nc;
        },
        set: function (v) {
            this.i.nc = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinates for which to get a value marker bounding box for
    */
    /**
         * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinates for which to get a value marker bounding box for
        */
    IgxScatterBaseComponent.prototype.getSeriesValueMarkerBoundingBox = /**
         * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinates for which to get a value marker bounding box for
        */
    function (world) {
        var iv = this.i.lo(toPoint(world));
        return fromRect(iv);
    };
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as YAxis
        
        * @param axis  * The object to check
        */
    IgxScatterBaseComponent.prototype.canUseAsYAxis = /**
         * Determine if object can be used as YAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.m9(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    /**
         * Determine if object can be used as XAxis
        
        * @param axis  * The object to check
        */
    IgxScatterBaseComponent.prototype.canUseAsXAxis = /**
         * Determine if object can be used as XAxis
        
        * @param axis  * The object to check
        */
    function (axis) {
        var iv = this.i.m8(axis);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    IgxScatterBaseComponent.prototype.getItem = /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    function (world) {
        var iv = this.i.fm(toPoint(world));
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    /**
         * Gets the index of the item that resides at the provided world coordinates.
        
        * @param world  * The world coordinates of the requested item.
        */
    IgxScatterBaseComponent.prototype.getItemIndex = /**
         * Gets the index of the item that resides at the provided world coordinates.
        
        * @param world  * The world coordinates of the requested item.
        */
    function (world) {
        var iv = this.i.e5(toPoint(world));
        return (iv);
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    IgxScatterBaseComponent.prototype.scrollIntoView = /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    function (item) {
        var iv = this.i.c8(item);
        return (iv);
    };
    IgxScatterBaseComponent.propDecorators = {
        "xAxis": [{ type: Input },],
        "yAxis": [{ type: Input },],
        "xMemberPath": [{ type: Input },],
        "yMemberPath": [{ type: Input },],
        "trendLineType": [{ type: Input },],
        "trendLineBrush": [{ type: Input },],
        "actualTrendLineBrush": [{ type: Input },],
        "trendLineThickness": [{ type: Input },],
        "trendLinePeriod": [{ type: Input },],
        "markerCollisionAvoidance": [{ type: Input },],
        "trendLineZIndex": [{ type: Input },],
        "maximumMarkers": [{ type: Input },],
    };
    return IgxScatterBaseComponent;
}(IgxMarkerSeriesComponent));
export { IgxScatterBaseComponent };
//# sourceMappingURL=igx-scatter-base-component.js.map