import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { Style } from "igniteui-angular-core/ES5/igx-style";
import { MarkerType, MarkerType_$type } from "./MarkerType";
import { CollisionAvoidanceType, CollisionAvoidanceType_$type } from "./CollisionAvoidanceType";
import { IgxShapeSeriesBaseComponent } from "./igx-shape-series-base-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ScatterPolygonSeries } from "./ScatterPolygonSeries";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES5/componentUtil";
import { StyleSelector } from "./StyleSelector";
/**
 * Series class which renders polygons as Paths based on lists of points in the ItemsSource.
*/
export var IgxScatterPolygonSeriesComponent_PROVIDERS = [{ provide: IgxShapeSeriesBaseComponent, useExisting: forwardRef(function () { return IgxScatterPolygonSeriesComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxScatterPolygonSeriesComponent; }) }];
var IgxScatterPolygonSeriesComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxScatterPolygonSeriesComponent, _super);
    function IgxScatterPolygonSeriesComponent() {
        return _super.call(this) || this;
    }
    IgxScatterPolygonSeriesComponent.prototype.createImplementation = function () {
        return new ScatterPolygonSeries();
    };
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "hasMarkers", {
        /**
         * Returns whether the current series supports visual markers.
        */
        get: /**
             * Returns whether the current series supports visual markers.
            */
        function () {
            return this.i.hasMarkers;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "shapeStyleSelector", {
        /**
         * The StyleSelector which is used to select a style for each Shape.
        */
        get: /**
             * The StyleSelector which is used to select a style for each Shape.
            */
        function () {
            return this.i.m8;
        },
        set: function (v) {
            this.i.m8 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "shapeStyle", {
        /**
         * The default style to apply to all Shapes in the series.
        */
        get: /**
             * The default style to apply to all Shapes in the series.
            */
        function () {
            if (this.i.n5 == null) {
                return null;
            }
            if (!this.i.n5.externalObject) {
                var e = new Style();
                e._implementation = this.i.n5;
                this.i.n5.externalObject = e;
            }
            return this.i.n5.externalObject;
        },
        set: function (v) {
            v == null ? this.i.n5 = null : this.i.n5 = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get: /**
             * Gets or sets the marker type for the current series object.
             * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
            */
        function () {
            return this.i.m3;
        },
        set: function (v) {
            this.i.m3 = ensureEnum(MarkerType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get: /**
             * Gets or sets the MarkerTemplate for the current series object.
            */
        function () {
            return this.i.nn;
        },
        set: function (v) {
            this.i.nn = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        */
        get: /**
             * Gets the effective marker template for the current series object.
            */
        function () {
            return this.i.nm;
        },
        set: function (v) {
            this.i.nm = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get: /**
             * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
            */
        function () {
            return brushToString(this.i.n1);
        },
        set: function (v) {
            this.i.n1 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        */
        get: /**
             * Gets the effective marker brush for the current series object.
            */
        function () {
            return brushToString(this.i.nz);
        },
        set: function (v) {
            this.i.nz = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get: /**
             * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
            */
        function () {
            return brushToString(this.i.n2);
        },
        set: function (v) {
            this.i.n2 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        */
        get: /**
             * Gets the effective marker outline for the current series object.
            */
        function () {
            return brushToString(this.i.n0);
        },
        set: function (v) {
            this.i.n0 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScatterPolygonSeriesComponent.prototype, "markerCollisionAvoidance", {
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get: /**
             * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
            */
        function () {
            return this.i.m2;
        },
        set: function (v) {
            this.i.m2 = ensureEnum(CollisionAvoidanceType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    IgxScatterPolygonSeriesComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-scatter-polygon-series',
                    template: "",
                    providers: [{ provide: IgxShapeSeriesBaseComponent, useExisting: forwardRef(function () { return IgxScatterPolygonSeriesComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxScatterPolygonSeriesComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxScatterPolygonSeriesComponent.ctorParameters = function () { return []; };
    IgxScatterPolygonSeriesComponent.propDecorators = {
        "shapeStyleSelector": [{ type: Input },],
        "shapeStyle": [{ type: Input },],
        "markerType": [{ type: Input },],
        "markerTemplate": [{ type: Input },],
        "actualMarkerTemplate": [{ type: Input },],
        "markerBrush": [{ type: Input },],
        "actualMarkerBrush": [{ type: Input },],
        "markerOutline": [{ type: Input },],
        "actualMarkerOutline": [{ type: Input },],
        "markerCollisionAvoidance": [{ type: Input },],
    };
    return IgxScatterPolygonSeriesComponent;
}(IgxShapeSeriesBaseComponent));
export { IgxScatterPolygonSeriesComponent };
//# sourceMappingURL=igx-scatter-polygon-series-component.js.map