import { EventEmitter, Output, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES5/type";
import { ChartHitTestMode, ChartHitTestMode_$type } from "./ChartHitTestMode";
import { WindowResponse, WindowResponse_$type } from "./WindowResponse";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES5/Visibility";
import { InteractionState, InteractionState_$type } from "igniteui-angular-core/ES5/InteractionState";
import { ModifierKeys, ModifierKeys_$type } from "igniteui-angular-core/ES5/ModifierKeys";
import { HorizontalAlignment, HorizontalAlignment_$type } from "igniteui-angular-core/ES5/HorizontalAlignment";
import { ChartCursorEventArgs } from "./igx-chart-cursor-event-args";
import { DataChartMouseButtonEventArgs } from "./igx-data-chart-mouse-button-event-args";
import { ChartMouseEventArgs } from "./igx-chart-mouse-event-args";
import { RectChangedEventArgs } from "igniteui-angular-core/ES5/igx-rect-changed-event-args";
import { fromPoint, toPoint, ensureBool, fromRect, toRect, ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES5/componentUtil";
import { SyncSettings } from "./SyncSettings";
/**
 * Represents a control for viewing series objects.
*/
export var IgxSeriesViewerComponent_PROVIDERS = [];
var IgxSeriesViewerComponent = /** @class */ (function () {
    function IgxSeriesViewerComponent() {
        this._seriesCursorMouseMove = null;
        this._seriesMouseLeftButtonDown = null;
        this._seriesMouseLeftButtonUp = null;
        this._seriesMouseMove = null;
        this._seriesMouseEnter = null;
        this._seriesMouseLeave = null;
        this._windowRectChanged = null;
        this._sizeChanged = null;
        this._gridAreaRectChanged = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgxSeriesViewerComponent.prototype.createImplementation = function () {
        return null;
    };
    IgxSeriesViewerComponent.prototype.ngOnInit = function () {
    };
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    IgxSeriesViewerComponent.prototype.onImplementationCreated = function () {
    };
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "crosshairPoint", {
        /**
         * Gets or sets the cross hair point (in world coordinates)
         * Either or both of the crosshair point's X and Y may be set to double.NaN, in which
         * case the relevant crosshair line is hidden.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     crosshairVisibility="visible"
        *     crosshairPoint={x:.8,y:.2}>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.crosshairPoint = {x:.8,y:.2};
        * ```
        */
        get: /**
             * Gets or sets the cross hair point (in world coordinates)
             * Either or both of the crosshair point's X and Y may be set to double.NaN, in which
             * case the relevant crosshair line is hidden.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     crosshairVisibility="visible"
            *     crosshairPoint={x:.8,y:.2}>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            * this.chart.crosshairPoint = {x:.8,y:.2};
            * ```
            */
        function () {
            return fromPoint(this.i.mf);
        },
        set: function (v) {
            this.i.mf = toPoint(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "animateSeriesWhenAxisRangeChanges", {
        /**
         * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     animateSeriesWhenAxisRangeChanges=true>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         transitionInMode="accordionFromBottom"
        *         isTransitionInEnabled=true
        *         transitionInSpeedType="indexScaled"
        *         transitionDuration=1000>
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.animateSeriesWhenAxisRangeChanges = true;
        * ```
        */
        get: /**
             * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     animateSeriesWhenAxisRangeChanges=true>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value"
            *         transitionInMode="accordionFromBottom"
            *         isTransitionInEnabled=true
            *         transitionInSpeedType="indexScaled"
            *         transitionDuration=1000>
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            * this.chart.animateSeriesWhenAxisRangeChanges = true;
            * ```
            */
        function () {
            return this.i.cc;
        },
        set: function (v) {
            this.i.cc = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "viewportRect", {
        /**
         * Gets the viewport rectangle associated with the SeriesViewer, the physical dimensions of the plot area.
        *
        * ```ts
        * let viewPortRect: IgxRect = this.chart.viewportRect;
        * ```
        */
        get: /**
             * Gets the viewport rectangle associated with the SeriesViewer, the physical dimensions of the plot area.
            *
            * ```ts
            * let viewPortRect: IgxRect = this.chart.viewportRect;
            * ```
            */
        function () {
            return fromRect(this.i.m0);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "effectiveViewport", {
        /**
         * Gets the EffectiveViewport rectangle, representing the effective viewport area after margins have been subtracted.
        *
        *  ``ts
        * let viewport: IgxRect = this.chart.effectiveViewport;
        *
        * ```
        *
        * ```
        */
        get: /**
             * Gets the EffectiveViewport rectangle, representing the effective viewport area after margins have been subtracted.
            *
            *  ``ts
            * let viewport: IgxRect = this.chart.effectiveViewport;
            *
            * ```
            *
            * ```
            */
        function () {
            return fromRect(this.i.mr);
        },
        set: function (v) {
            this.i.mr = toRect(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "contentViewport", {
        /**
         * Represents the subset area within the viewport into which content should be mapped.
         * This is the projection of the current EffectiveViewport into the viewport at current zoom level.
        *
        * ```ts
        * let contentViewport: IgxRect = this.chart.contentViewport;
        * ```
        */
        get: /**
             * Represents the subset area within the viewport into which content should be mapped.
             * This is the projection of the current EffectiveViewport into the viewport at current zoom level.
            *
            * ```ts
            * let contentViewport: IgxRect = this.chart.contentViewport;
            * ```
            */
        function () {
            return fromRect(this.i.mq);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowRect", {
        /**
         * A rectangle representing the portion of the SeriesViewer currently in view.
         * A rectangle at X=0, Y=0 with a Height and Width of 1 implies the entire plotting area is in view.  A Height and Width of .5 would imply that the view is halfway zoomed in.
        *
        * You can set the `windowRect` to zoom in on an area of interest in the chart.
        *
        * ```ts
        * this.chart.windowRect = {left:0, top:1, width: .5, height: .5};
        * ```
        */
        get: /**
             * A rectangle representing the portion of the SeriesViewer currently in view.
             * A rectangle at X=0, Y=0 with a Height and Width of 1 implies the entire plotting area is in view.  A Height and Width of .5 would imply that the view is halfway zoomed in.
            *
            * You can set the `windowRect` to zoom in on an area of interest in the chart.
            *
            * ```ts
            * this.chart.windowRect = {left:0, top:1, width: .5, height: .5};
            * ```
            */
        function () {
            return fromRect(this.i.m1);
        },
        set: function (v) {
            this.i.m1 = toRect(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "useTiledZooming", {
        /**
         * Gets or sets whether the series viewer should use cached tiles during zooms rather than the default live content.
        */
        get: /**
             * Gets or sets whether the series viewer should use cached tiles during zooms rather than the default live content.
            */
        function () {
            return this.i.di;
        },
        set: function (v) {
            this.i.di = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "preferHigherResolutionTiles", {
        /**
         * Gets or sets whether the series viewer should prefer selecting higher resolution tiles over lower resolution tiles when performing tile zooming. Setting this to true will lower performance but increase quality.
        */
        get: /**
             * Gets or sets whether the series viewer should prefer selecting higher resolution tiles over lower resolution tiles when performing tile zooming. Setting this to true will lower performance but increase quality.
            */
        function () {
            return this.i.da;
        },
        set: function (v) {
            this.i.da = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "zoomTileCacheSize", {
        /**
         * Gets or sets the maximum number of zoom tiles that the series viewer should cache while in tiled zooming mode.
        */
        get: /**
             * Gets or sets the maximum number of zoom tiles that the series viewer should cache while in tiled zooming mode.
            */
        function () {
            return this.i.e5;
        },
        set: function (v) {
            this.i.e5 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "highlightingTransitionDuration", {
        /**
         * Gets or sets the duration the highlighting/de-highlighting effects.
        */
        get: /**
             * Gets or sets the duration the highlighting/de-highlighting effects.
            */
        function () {
            return this.i.e4;
        },
        set: function (v) {
            this.i.e4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "isPagePanningAllowed", {
        /**
         * Gets or sets the whether the series viewer can allow the page to pan if a control pan is not possible in the requested direction.
        */
        get: /**
             * Gets or sets the whether the series viewer can allow the page to pan if a control pan is not possible in the requested direction.
            */
        function () {
            return this.i.cx;
        },
        set: function (v) {
            this.i.cx = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "contentHitTestMode", {
        /**
         * Determines the method of hit testing used when mousing over elements in the chart.
        *
        * ```ts
        * this.chart.contentHitTestMode = ChartHitTestMode.Computational;
        * ```
        */
        get: /**
             * Determines the method of hit testing used when mousing over elements in the chart.
            *
            * ```ts
            * this.chart.contentHitTestMode = ChartHitTestMode.Computational;
            * ```
            */
        function () {
            return this.i.ap;
        },
        set: function (v) {
            this.i.ap = ensureEnum(ChartHitTestMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualContentHitTestMode", {
        /**
         * Resolved method of hit testing used when the pointer is over elements in the chart.
        *
        * ```ts
        * let actualContentHitTestMode: ChartHitTestMode  =this.chart.actualContentHitTestMode;
        * ```
        */
        get: /**
             * Resolved method of hit testing used when the pointer is over elements in the chart.
            *
            * ```ts
            * let actualContentHitTestMode: ChartHitTestMode  =this.chart.actualContentHitTestMode;
            * ```
            */
        function () {
            return this.i.ao;
        },
        set: function (v) {
            this.i.ao = ensureEnum(ChartHitTestMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "isSurfaceInteractionDisabled", {
        /**
         * Gets or sets whether all surface interactions with the plot area should be disabled.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isSurfaceInteractionDisabled=true>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets whether all surface interactions with the plot area should be disabled.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     isSurfaceInteractionDisabled=true>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.cy;
        },
        set: function (v) {
            this.i.cy = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "isMap", {
        /**
         * Indicates if this SeriesViewer is a map.
        */
        get: /**
             * Indicates if this SeriesViewer is a map.
            */
        function () {
            return this.i.cw;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowResponse", {
        /**
         * The response to user panning and zooming: whether to update the view immediately while the user action is happening, or to defer the update to after the user action is complete.  The user action will be an action such as a mouse drag which causes panning and/or zooming to occur.
        *
        * ```ts
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     windowResponse="deferred">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * The response to user panning and zooming: whether to update the view immediately while the user action is happening, or to defer the update to after the user action is complete.  The user action will be an action such as a mouse drag which causes panning and/or zooming to occur.
            *
            * ```ts
            * <igx-data-chart
            *     [dataSource]="data"
            *     isHorizontalZoomEnabled=true
            *     windowResponse="deferred">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.ba;
        },
        set: function (v) {
            this.i.ba = ensureEnum(WindowResponse_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowRectMinWidth", {
        /**
         * Sets or gets the minimum width that the window rect is allowed to reach before being clamped.
         * Decrease this value if you want to allow for further zooming into the viewer.
         * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     windowRectMinWidth=.2>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Sets or gets the minimum width that the window rect is allowed to reach before being clamped.
             * Decrease this value if you want to allow for further zooming into the viewer.
             * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     isHorizontalZoomEnabled=true
            *     windowRectMinWidth=.2>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.ew;
        },
        set: function (v) {
            this.i.ew = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "overviewPlusDetailPaneVisibility", {
        /**
         * The visibility of the OverviewPlusDetailPane.
        */
        get: /**
             * The visibility of the OverviewPlusDetailPane.
            */
        function () {
            return this.i.m5;
        },
        set: function (v) {
            this.i.m5 = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "crosshairVisibility", {
        /**
         * Gets or sets the current SeriesViewer's crosshair visibility override.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     crosshairVisibility="visible">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.crosshairVisibility = Visibility.Visible;
        * ```
        */
        get: /**
             * Gets or sets the current SeriesViewer's crosshair visibility override.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     crosshairVisibility="visible">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            * this.chart.crosshairVisibility = Visibility.Visible;
            * ```
            */
        function () {
            return this.i.m4;
        },
        set: function (v) {
            this.i.m4 = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "plotAreaBackground", {
        /**
         * Gets or sets the brush used as the background for the current SeriesViewer object's plot area.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     plotAreaBackground="#F0F8FF">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the brush used as the background for the current SeriesViewer object's plot area.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     plotAreaBackground="#F0F8FF">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return brushToString(this.i.ma);
        },
        set: function (v) {
            this.i.ma = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "defaultInteraction", {
        /**
         * Gets or sets the DefaultInteraction property.
         * The default interaction state defines the SeriesViewer's response to mouse events.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     defaultInteraction="dragPan">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.defaultInteraction = InteractionState.DragPan;
        * ```
        */
        get: /**
             * Gets or sets the DefaultInteraction property.
             * The default interaction state defines the SeriesViewer's response to mouse events.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     isHorizontalZoomEnabled=true
            *     defaultInteraction="dragPan">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            * this.chart.defaultInteraction = InteractionState.DragPan;
            * ```
            */
        function () {
            return this.i.bc;
        },
        set: function (v) {
            this.i.bc = ensureEnum(InteractionState_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "dragModifier", {
        /**
         * Gets or sets the current SeriesViewer's DragModifier property.
        *
        * `dragModifier` is useful to enable zooming when zooming is not the default interaction.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     defaultInteraction="dragPan"
        *     dragModifier="alt">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.dragModifier = ModifierKeys.Alt;
        * ```
        */
        get: /**
             * Gets or sets the current SeriesViewer's DragModifier property.
            *
            * `dragModifier` is useful to enable zooming when zooming is not the default interaction.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     isHorizontalZoomEnabled=true
            *     defaultInteraction="dragPan"
            *     dragModifier="alt">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            * this.chart.dragModifier = ModifierKeys.Alt;
            * ```
            */
        function () {
            return this.i.lx;
        },
        set: function (v) {
            this.i.lx = ensureEnum(ModifierKeys_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "panModifier", {
        /**
         * Gets or sets the current SeriesViewer's PanModifier property.
        *
        * `panModifier` is useful to enable panning when panning is not the default interaction.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     defaultInteraction="dragZoom"
        *     panModifier="alt">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.panModifier = ModifierKeys.Alt;
        * ```
        */
        get: /**
             * Gets or sets the current SeriesViewer's PanModifier property.
            *
            * `panModifier` is useful to enable panning when panning is not the default interaction.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     isHorizontalZoomEnabled=true
            *     defaultInteraction="dragZoom"
            *     panModifier="alt">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            * this.chart.panModifier = ModifierKeys.Alt;
            * ```
            */
        function () {
            return this.i.ly;
        },
        set: function (v) {
            this.i.ly = ensureEnum(ModifierKeys_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "previewRect", {
        /**
         * Gets or sets the preview rectangle.
         * The preview rectangle may be set to Rect.Empty, in which case the visible preview
         * strokePath is hidden.
        *
        * `previewRect` can be used to highlight an area of importance.
        *
        * ```ts
        * this.chart.previewRect = {left:0,top:0,height:.5,width:.5};
        * ```
        */
        get: /**
             * Gets or sets the preview rectangle.
             * The preview rectangle may be set to Rect.Empty, in which case the visible preview
             * strokePath is hidden.
            *
            * `previewRect` can be used to highlight an area of importance.
            *
            * ```ts
            * this.chart.previewRect = {left:0,top:0,height:.5,width:.5};
            * ```
            */
        function () {
            return fromRect(this.i.mw);
        },
        set: function (v) {
            this.i.mw = toRect(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowPositionHorizontal", {
        /**
         * A number between 0 and 1 determining the position of the horizontal scroll.
         * This property is effectively a shortcut to the X position of the WindowRect property.
        *
        * ```ts
        * this.chart.windowPositionHorizontal = .2;
        * ```
        */
        get: /**
             * A number between 0 and 1 determining the position of the horizontal scroll.
             * This property is effectively a shortcut to the X position of the WindowRect property.
            *
            * ```ts
            * this.chart.windowPositionHorizontal = .2;
            * ```
            */
        function () {
            return this.i.eu;
        },
        set: function (v) {
            this.i.eu = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowPositionVertical", {
        /**
         * A number between 0 and 1 determining the position of the vertical scroll.
         * This property is effectively a shortcut to the Y position of the WindowRect property.
        *
        * ```ts
        * this.chart.windowPositionVertical = .2;
        * ```
        */
        get: /**
             * A number between 0 and 1 determining the position of the vertical scroll.
             * This property is effectively a shortcut to the Y position of the WindowRect property.
            *
            * ```ts
            * this.chart.windowPositionVertical = .2;
            * ```
            */
        function () {
            return this.i.ev;
        },
        set: function (v) {
            this.i.ev = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "chartTitle", {
        /**
         * Text to display above the plot area.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Text to display above the plot area.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.go;
        },
        set: function (v) {
            this.i.go = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleHorizontalAlignment", {
        /**
         * Gets or sets the TitleHorizontalAlignment property.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     titleHorizontalAlignment="left"
        *     subtitleHorizontalAlignment="left">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the TitleHorizontalAlignment property.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     subtitle="date of sale: 1/1/2018"
            *     titleHorizontalAlignment="left"
            *     subtitleHorizontalAlignment="left">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.lw;
        },
        set: function (v) {
            this.i.lw = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleHorizontalAlignment", {
        /**
         * Gets or sets the SubtitleHorizontalAlignment property.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="Date of Sale: 1/1/2018"
        *     titleHorizontalAlignment="left"
        *     subtitleHorizontalAlignment="left">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the SubtitleHorizontalAlignment property.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     subtitle="Date of Sale: 1/1/2018"
            *     titleHorizontalAlignment="left"
            *     subtitleHorizontalAlignment="left">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.lv;
        },
        set: function (v) {
            this.i.lv = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleTextStyle", {
        /**
         * Font settings for the title.
        */
        get: /**
             * Font settings for the title.
            */
        function () {
            return this.i.gv;
        },
        set: function (v) {
            this.i.gv = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleTextStyle", {
        /**
         * Font settings for the subtitle.
        */
        get: /**
             * Font settings for the subtitle.
            */
        function () {
            return this.i.gj;
        },
        set: function (v) {
            this.i.gj = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleTextColor", {
        /**
         * Gets or sets the Color used for the Title Text.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     titleTextColor="blue">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the Color used for the Title Text.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     subtitle="date of sale: 1/1/2018"
            *     titleTextColor="blue">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return brushToString(this.i.md);
        },
        set: function (v) {
            this.i.md = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleTextColor", {
        /**
         * Gets or sets the Color used for the Subtitle Text.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="Date of Sale: 1/1/2018"
        *     subtitleTextColor="blue">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the Color used for the Subtitle Text.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     subtitle="Date of Sale: 1/1/2018"
            *     subtitleTextColor="blue">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return brushToString(this.i.mc);
        },
        set: function (v) {
            this.i.mc = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleTopMargin", {
        /**
         * Margin applied above the title.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     titleLeftMarging=10
        *     titleTopMargin=10
        *     titleRightMargin=10
        *     titleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Margin applied above the title.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     titleLeftMarging=10
            *     titleTopMargin=10
            *     titleRightMargin=10
            *     titleBottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.es;
        },
        set: function (v) {
            this.i.es = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleLeftMargin", {
        /**
         * Margin applied to the left of the title.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     titleLeftMarging=10
        *     titleTopMargin=10
        *     titleRightMargin=10
        *     titleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Margin applied to the left of the title.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     titleLeftMarging=10
            *     titleTopMargin=10
            *     titleRightMargin=10
            *     titleBottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.eq;
        },
        set: function (v) {
            this.i.eq = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleRightMargin", {
        /**
         * Margin applied to the right of the title.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     titleLeftMarging=10
        *     titleTopMargin=10
        *     titleRightMargin=10
        *     titleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Margin applied to the right of the title.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     titleLeftMarging=10
            *     titleTopMargin=10
            *     titleRightMargin=10
            *     titleBottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.er;
        },
        set: function (v) {
            this.i.er = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleBottomMargin", {
        /**
         * Margin applied below the title.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     titleLeftMarging=10
        *     titleTopMargin=10
        *     titleRightMargin=10
        *     titleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Margin applied below the title.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     titleLeftMarging=10
            *     titleTopMargin=10
            *     titleRightMargin=10
            *     titleBottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.ep;
        },
        set: function (v) {
            this.i.ep = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleTopMargin", {
        /**
         * Margin applied above the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     subtitleLeftMarging=10
        *     subtitleTopMargin=10
        *     subtitleRightMargin=10
        *     subtitleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Margin applied above the subtitle.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     subtitle="date of sale: 1/1/2018"
            *     subtitleLeftMarging=10
            *     subtitleTopMargin=10
            *     subtitleRightMargin=10
            *     subtitleBottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.eo;
        },
        set: function (v) {
            this.i.eo = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleLeftMargin", {
        /**
         * Margin applied to the left of the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     subtitleLeftMarging=10
        *     subtitleTopMargin=10
        *     subtitleRightMargin=10
        *     subtitleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Margin applied to the left of the subtitle.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     subtitle="date of sale: 1/1/2018"
            *     subtitleLeftMarging=10
            *     subtitleTopMargin=10
            *     subtitleRightMargin=10
            *     subtitleBottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.em;
        },
        set: function (v) {
            this.i.em = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleRightMargin", {
        /**
         * Margin applied to the right of the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     subtitleLeftMarging=10
        *     subtitleTopMargin=10
        *     subTitleRightMargin=10
        *     subtitleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Margin applied to the right of the subtitle.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     subtitle="date of sale: 1/1/2018"
            *     subtitleLeftMarging=10
            *     subtitleTopMargin=10
            *     subTitleRightMargin=10
            *     subtitleBottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.en;
        },
        set: function (v) {
            this.i.en = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleBottomMargin", {
        /**
         * Margin applied below the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     subtitleLeftMarging=10
        *     subtitleTopMargin=10
        *     subtitleRightMargin=10
        *     subtitleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Margin applied below the subtitle.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     subtitle="date of sale: 1/1/2018"
            *     subtitleLeftMarging=10
            *     subtitleTopMargin=10
            *     subtitleRightMargin=10
            *     subtitleBottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.el;
        },
        set: function (v) {
            this.i.el = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitle", {
        /**
         * Gets or sets the Subtitle property.
         * The Title property defines the Subtitle of the chart
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="Date of Sale: 1/1/2018">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Gets or sets the Subtitle property.
             * The Title property defines the Subtitle of the chart
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     title="Items Sold"
            *     subtitle="Date of Sale: 1/1/2018">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.gc;
        },
        set: function (v) {
            this.i.gc = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "SyncChannel", {
        /**
         * Gets or sets the channel with which to synchronize.
        *
        * Synchronization is the coordination of zooming, panning and crosshairs events between multiple charts. Multiple chart controls can be synchronized horizontally (along X-Axis), vertically (along Y-Axis), or both. If you want to synchronize a set of charts, assign them the same name to the `SyncChannel` and then specify whether or not synchronize chart horizontally and/or vertically.
        */
        get: /**
             * Gets or sets the channel with which to synchronize.
            *
            * Synchronization is the coordination of zooming, panning and crosshairs events between multiple charts. Multiple chart controls can be synchronized horizontally (along X-Axis), vertically (along Y-Axis), or both. If you want to synchronize a set of charts, assign them the same name to the `SyncChannel` and then specify whether or not synchronize chart horizontally and/or vertically.
            */
        function () {
            return this.i.a9 ? this.i.a9.ae : null;
        },
        set: function (v) {
            this.ensureSyncSettings();
            this.i.a9.ae = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "SynchronizeVertically", {
        /**
         * Gets or sets the bool used to display the window preview shadow.
        *
        * Synchronization is the coordination of zooming, panning and crosshairs events between multiple charts. Multiple chart controls can be synchronized horizontally (along X-Axis), vertically (along Y-Axis), or both. If you want to synchronize a set of charts, assign them the same name to the `SyncChannel` and then specify whether or not synchronize chart horizontally and/or vertically.
        */
        get: /**
             * Gets or sets the bool used to display the window preview shadow.
            *
            * Synchronization is the coordination of zooming, panning and crosshairs events between multiple charts. Multiple chart controls can be synchronized horizontally (along X-Axis), vertically (along Y-Axis), or both. If you want to synchronize a set of charts, assign them the same name to the `SyncChannel` and then specify whether or not synchronize chart horizontally and/or vertically.
            */
        function () {
            return this.i.a9 ? this.i.a9.ad : false;
        },
        set: function (v) {
            this.ensureSyncSettings();
            this.i.a9.ad = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "SynchronizeHorizontally", {
        /**
         * Gets or sets the bool used to display the window preview shadow.
        *
        * Synchronization is the coordination of zooming, panning and crosshairs events between multiple charts. Multiple chart controls can be synchronized horizontally (along X-Axis), vertically (along Y-Axis), or both. If you want to synchronize a set of charts, assign them the same name to the `SyncChannel` and then specify whether or not synchronize chart horizontally and/or vertically.
        */
        get: /**
             * Gets or sets the bool used to display the window preview shadow.
            *
            * Synchronization is the coordination of zooming, panning and crosshairs events between multiple charts. Multiple chart controls can be synchronized horizontally (along X-Axis), vertically (along Y-Axis), or both. If you want to synchronize a set of charts, assign them the same name to the `SyncChannel` and then specify whether or not synchronize chart horizontally and/or vertically.
            */
        function () {
            return this.i.a9 ? this.i.a9.ac : false;
        },
        set: function (v) {
            this.ensureSyncSettings();
            this.i.a9.ac = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    IgxSeriesViewerComponent.prototype.ensureSyncSettings = function () {
        if (this.i.a9) {
            return;
        }
        this.i.a9 = new SyncSettings();
    };
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "topMargin", {
        /**
         * Sets or gets the top margin to use around the chart content.
        *
        * ```html
        *  <igx-data-chart
        *     [dataSource]="data"
        *     leftMargin=20
        *     rightMargin=20
        *     topMargin=30
        *     bottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Sets or gets the top margin to use around the chart content.
            *
            * ```html
            *  <igx-data-chart
            *     [dataSource]="data"
            *     leftMargin=20
            *     rightMargin=20
            *     topMargin=30
            *     bottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.et;
        },
        set: function (v) {
            this.i.et = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "leftMargin", {
        /**
         * Sets or gets the left margin to use around the chart content.
        *
        * ```html
        *  <igx-data-chart
        *     [dataSource]="data"
        *     leftMargin=20
        *     rightMargin=20
        *     topMargin=30
        *     bottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Sets or gets the left margin to use around the chart content.
            *
            * ```html
            *  <igx-data-chart
            *     [dataSource]="data"
            *     leftMargin=20
            *     rightMargin=20
            *     topMargin=30
            *     bottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.ei;
        },
        set: function (v) {
            this.i.ei = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "rightMargin", {
        /**
         * Sets or gets the right margin to use around the chart content.
        *
        * ```html
        *  <igx-data-chart
        *     [dataSource]="data"
        *     leftMargin=20
        *     rightMargin=20
        *     topMargin=30
        *     bottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Sets or gets the right margin to use around the chart content.
            *
            * ```html
            *  <igx-data-chart
            *     [dataSource]="data"
            *     leftMargin=20
            *     rightMargin=20
            *     topMargin=30
            *     bottomMargin=20>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.ek;
        },
        set: function (v) {
            this.i.ek = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "bottomMargin", {
        /**
         * Sets or gets the bottom margin to use around the chart content.
        *
        * ```ts
        * this.chart.bottomMargin = 50;
        * ```
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     bottomMargin=50>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: /**
             * Sets or gets the bottom margin to use around the chart content.
            *
            * ```ts
            * this.chart.bottomMargin = 50;
            * ```
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     bottomMargin=50>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            */
        function () {
            return this.i.ee;
        },
        set: function (v) {
            this.i.ee = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "autoMarginWidth", {
        /**
         * Sets or gets the automatic width to add when automatically adding margins to the chart.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     autoMarginWidth=50>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.autoMarginWidth = 50;
        * ```
        */
        get: /**
             * Sets or gets the automatic width to add when automatically adding margins to the chart.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     autoMarginWidth=50>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            * this.chart.autoMarginWidth = 50;
            * ```
            */
        function () {
            return this.i.ed;
        },
        set: function (v) {
            this.i.ed = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "autoMarginHeight", {
        /**
         * Sets or gets the automatic height to add when automatically adding margins to the chart.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     autoMarginHeight=50>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        *  this.chart.autoMarginHeight = 50;
        * ```
        */
        get: /**
             * Sets or gets the automatic height to add when automatically adding margins to the chart.
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     autoMarginHeight=50>
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-column-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-column-series>
            * </igx-data-chart>
            * ```
            *
            * ```ts
            *  this.chart.autoMarginHeight = 50;
            * ```
            */
        function () {
            return this.i.ec;
        },
        set: function (v) {
            this.i.ec = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "isAntiAliasingEnabledDuringInteraction", {
        /**
         * Gets or sets the IsAntiAliasingEnabledDuringInteraction property.
        */
        get: /**
             * Gets or sets the IsAntiAliasingEnabledDuringInteraction property.
            */
        function () {
            return this.i.co;
        },
        set: function (v) {
            this.i.co = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "pixelScalingRatio", {
        /**
         * Gets or sets the scaling value used to affect the pixel density of the control.
         * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
         * to appear blurry.
        */
        get: /**
             * Gets or sets the scaling value used to affect the pixel density of the control.
             * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
             * to appear blurry.
            */
        function () {
            return this.i.ej;
        },
        set: function (v) {
            this.i.ej = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "interactionPixelScalingRatio", {
        /**
         * Method of pixel scaling to use during end user interaction with the chart.
        */
        get: /**
             * Method of pixel scaling to use during end user interaction with the chart.
            */
        function () {
            return this.i.eh;
        },
        set: function (v) {
            this.i.eh = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "overviewPlusDetailPaneBackgroundImageUri", {
        /**
         * Uri for the background image to display behind the overview plus detail pane.
        */
        get: /**
             * Uri for the background image to display behind the overview plus detail pane.
            */
        function () {
            return this.i.f0;
        },
        set: function (v) {
            this.i.f0 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualPixelScalingRatio", {
        /**
         * Gets the resolved pixel scaling ratio.
        *
        * A higher scaling ratio will produce crisper visuals at the expense of memory. Lower values will cause the control to appear blurry
        *
        * ```ts
        * let actualPixelScalingRatio: number = this.chart.actualPixelScalingRatio;
        * ```
        */
        get: /**
             * Gets the resolved pixel scaling ratio.
            *
            * A higher scaling ratio will produce crisper visuals at the expense of memory. Lower values will cause the control to appear blurry
            *
            * ```ts
            * let actualPixelScalingRatio: number = this.chart.actualPixelScalingRatio;
            * ```
            */
        function () {
            return this.i.d9;
        },
        set: function (v) {
            this.i.d9 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualInteractionPixelScalingRatio", {
        /**
         * Resolved method of pixel scaling to use during end user interaction with the chart.
        *
        * ```ts
        * let actualInteractionPixelScalingRatio: number = this.chart.actualInteractionPixelScalingRatio;
        * ```
        */
        get: /**
             * Resolved method of pixel scaling to use during end user interaction with the chart.
            *
            * ```ts
            * let actualInteractionPixelScalingRatio: number = this.chart.actualInteractionPixelScalingRatio;
            * ```
            */
        function () {
            return this.i.d8;
        },
        set: function (v) {
            this.i.d8 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualWindowRect", {
        /**
         * Gets the actual value of the window rectangle, which represents the current zoom level.
        *
        * ```ts
        * let actualWindowRect: IgxRect = this.chart.actualWindowRect;
        * ``
        * ```
        */
        get: /**
             * Gets the actual value of the window rectangle, which represents the current zoom level.
            *
            * ```ts
            * let actualWindowRect: IgxRect = this.chart.actualWindowRect;
            * ``
            * ```
            */
        function () {
            return fromRect(this.i.mn);
        },
        set: function (v) {
            this.i.mn = toRect(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualWindowPositionHorizontal", {
        /**
         * A number between 0 and 1 determining the position of the horizontal scroll.
         * This property is effectively a shortcut to the Left of the ActualWindowRect property.
        *
        * ```ts
        * let actualWindowPositionHorizontal: number = this.chart.actualWindowPositionHorizontal;
        * ```
        */
        get: /**
             * A number between 0 and 1 determining the position of the horizontal scroll.
             * This property is effectively a shortcut to the Left of the ActualWindowRect property.
            *
            * ```ts
            * let actualWindowPositionHorizontal: number = this.chart.actualWindowPositionHorizontal;
            * ```
            */
        function () {
            return this.i.ea;
        },
        set: function (v) {
            this.i.ea = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualWindowPositionVertical", {
        /**
         * A number between 0 and 1 determining the position of the vertical scroll.
         * This property is effectively a shortcut to the Top of the ActualWindowRect property.
        *
        * ```ts
        * let actualWindowPositionVertical: number = this.chart.actualWindowPositionVertical;
        * ``
        * ```
        */
        get: /**
             * A number between 0 and 1 determining the position of the vertical scroll.
             * This property is effectively a shortcut to the Top of the ActualWindowRect property.
            *
            * ```ts
            * let actualWindowPositionVertical: number = this.chart.actualWindowPositionVertical;
            * ``
            * ```
            */
        function () {
            return this.i.eb;
        },
        set: function (v) {
            this.i.eb = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Hides the active main tooltip, if displayed.
    
    *
    * ```ts
    * this.chart.hideToolTip();
    * ```
    */
    /**
         * Hides the active main tooltip, if displayed.
        
        *
        * ```ts
        * this.chart.hideToolTip();
        * ```
        */
    IgxSeriesViewerComponent.prototype.hideToolTip = /**
         * Hides the active main tooltip, if displayed.
        
        *
        * ```ts
        * this.chart.hideToolTip();
        * ```
        */
    function () {
        this.i.hm();
    };
    /**
     * Manually starts a tiled zoom if one isn't already running.
    
    */
    /**
         * Manually starts a tiled zoom if one isn't already running.
        
        */
    IgxSeriesViewerComponent.prototype.startTiledZoomingIfNecessary = /**
         * Manually starts a tiled zoom if one isn't already running.
        
        */
    function () {
        this.i.j5();
    };
    /**
     * Manually ends a tiled zoom if one is running.
    
    */
    /**
         * Manually ends a tiled zoom if one is running.
        
        */
    IgxSeriesViewerComponent.prototype.endTiledZoomingIfRunning = /**
         * Manually ends a tiled zoom if one is running.
        
        */
    function () {
        this.i.hh();
    };
    /**
     * Clears the tile zoom tile cache so that new tiles will be generated. Only applies if the viewer is using a tile based zoom.
    
    */
    /**
         * Clears the tile zoom tile cache so that new tiles will be generated. Only applies if the viewer is using a tile based zoom.
        
        */
    IgxSeriesViewerComponent.prototype.clearTileZoomCache = /**
         * Clears the tile zoom tile cache so that new tiles will be generated. Only applies if the viewer is using a tile based zoom.
        
        */
    function () {
        this.i.hb();
    };
    /**
     * Resets the zoom level to default.
    
    */
    /**
         * Resets the zoom level to default.
        
        */
    IgxSeriesViewerComponent.prototype.resetZoom = /**
         * Resets the zoom level to default.
        
        */
    function () {
        this.i.jz();
    };
    /**
     * Gets actual window scale for horizontal dimension of the control
    
    *
    * ```ts
    * let actualWindowScaleHorizontal: number = chart.getActualWindowScaleHorizontal();
    * ```
    */
    /**
         * Gets actual window scale for horizontal dimension of the control
        
        *
        * ```ts
        * let actualWindowScaleHorizontal: number = chart.getActualWindowScaleHorizontal();
        * ```
        */
    IgxSeriesViewerComponent.prototype.getActualWindowScaleHorizontal = /**
         * Gets actual window scale for horizontal dimension of the control
        
        *
        * ```ts
        * let actualWindowScaleHorizontal: number = chart.getActualWindowScaleHorizontal();
        * ```
        */
    function () {
        var iv = this.i.ef();
        return (iv);
    };
    /**
     * Gets actual window scale for vertical dimension of the control
    
    *
    * ```ts
    * let actualWindowScaleVertical: number = chart.getActualWindowScaleVertical();
    * ```
    */
    /**
         * Gets actual window scale for vertical dimension of the control
        
        *
        * ```ts
        * let actualWindowScaleVertical: number = chart.getActualWindowScaleVertical();
        * ```
        */
    IgxSeriesViewerComponent.prototype.getActualWindowScaleVertical = /**
         * Gets actual window scale for vertical dimension of the control
        
        *
        * ```ts
        * let actualWindowScaleVertical: number = chart.getActualWindowScaleVertical();
        * ```
        */
    function () {
        var iv = this.i.eg();
        return (iv);
    };
    /**
     * Notification from the containing object that the container has been resized.
    
    */
    /**
         * Notification from the containing object that the container has been resized.
        
        */
    IgxSeriesViewerComponent.prototype.notifyContainerResized = /**
         * Notification from the containing object that the container has been resized.
        
        */
    function () {
        this.i.notifyContainerResized();
    };
    /**
     * Attaches the given series to the chart.
    
    * @param s  * The series to attach to the chart.
    */
    /**
         * Attaches the given series to the chart.
        
        * @param s  * The series to attach to the chart.
        */
    IgxSeriesViewerComponent.prototype.attachSeries = /**
         * Attaches the given series to the chart.
        
        * @param s  * The series to attach to the chart.
        */
    function (s) {
        this.i.g9((s == null ? null : s.i));
    };
    IgxSeriesViewerComponent.prototype.notifySetItem = function (source_, index, oldItem, newItem) {
        this.i.hy(source_, index, oldItem, newItem);
    };
    /**
     * Used to manually notify the SeriesViewer that the data source has reset or cleared its items.  Invoking this method is only necessary if that datasource is not observable.
    
    * @param source_  * The data source which was cleared or reset.
    *
    * ```ts
    * this.chart.notifyClearItems(this.data);
    * ```
    */
    /**
         * Used to manually notify the SeriesViewer that the data source has reset or cleared its items.  Invoking this method is only necessary if that datasource is not observable.
        
        * @param source_  * The data source which was cleared or reset.
        *
        * ```ts
        * this.chart.notifyClearItems(this.data);
        * ```
        */
    IgxSeriesViewerComponent.prototype.notifyClearItems = /**
         * Used to manually notify the SeriesViewer that the data source has reset or cleared its items.  Invoking this method is only necessary if that datasource is not observable.
        
        * @param source_  * The data source which was cleared or reset.
        *
        * ```ts
        * this.chart.notifyClearItems(this.data);
        * ```
        */
    function (source_) {
        this.i.ht(source_);
    };
    IgxSeriesViewerComponent.prototype.notifyInsertItem = function (source_, index, newItem) {
        this.i.hw(source_, index, newItem);
    };
    IgxSeriesViewerComponent.prototype.notifyRemoveItem = function (source_, index, oldItem) {
        this.i.hx(source_, index, oldItem);
    };
    /**
     * Release any resources held by the control.
    
    */
    /**
         * Release any resources held by the control.
        
        */
    IgxSeriesViewerComponent.prototype.destroy = /**
         * Release any resources held by the control.
        
        */
    function () {
        this.i.destroy();
    };
    /**
     * Use to force the SeriesViewer to finish any deferred work before printing or evaluating its visual.
     * This should only be called if the visual of the SeriesViewer needs to be synchronously saved or evaluated.
     * Calling this method too often will hinder the performance of the SeriesViewer.
    
    *
    * ```ts
    * this.chart.flush();
    * ```
    */
    /**
         * Use to force the SeriesViewer to finish any deferred work before printing or evaluating its visual.
         * This should only be called if the visual of the SeriesViewer needs to be synchronously saved or evaluated.
         * Calling this method too often will hinder the performance of the SeriesViewer.
        
        *
        * ```ts
        * this.chart.flush();
        * ```
        */
    IgxSeriesViewerComponent.prototype.flush = /**
         * Use to force the SeriesViewer to finish any deferred work before printing or evaluating its visual.
         * This should only be called if the visual of the SeriesViewer needs to be synchronously saved or evaluated.
         * Calling this method too often will hinder the performance of the SeriesViewer.
        
        *
        * ```ts
        * this.chart.flush();
        * ```
        */
    function () {
        this.i.flush();
    };
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesCursorMouseMove", {
        get: /**
             * Occurs when the cursors are moved over a series in this SeriesViewer.
            */
        function () {
            var _this = this;
            if (this._seriesCursorMouseMove == null) {
                this._seriesCursorMouseMove = new EventEmitter();
                this.i.seriesCursorMouseMove = delegateCombine(this.i.seriesCursorMouseMove, function (o, e) {
                    var outerArgs = new ChartCursorEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeSeriesCursorMouseMove) {
                        _this.beforeSeriesCursorMouseMove(_this, outerArgs);
                    }
                    _this._seriesCursorMouseMove.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._seriesCursorMouseMove;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseLeftButtonDown", {
        get: /**
             * Occurs when the left mouse button is pressed while the mouse pointer is over a Series.
            *
            * &lt;-- position: content member-->
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     (seriesMouseLeftButtonDown)="onSeriesMouseLeftButtonDown($event)">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value"
            *         thickness=5>
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * &lt;-- position: content member-->
            *
            * ```ts
            * public onSeriesMouseLeftButtonDown(event: {sender: any, args: DataChartMouseButtonEventArgs})
            * {
            *     var item = event.args.item;
            * }
            * ```
            */
        function () {
            var _this = this;
            if (this._seriesMouseLeftButtonDown == null) {
                this._seriesMouseLeftButtonDown = new EventEmitter();
                this.i.seriesMouseLeftButtonDown = delegateCombine(this.i.seriesMouseLeftButtonDown, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new DataChartMouseButtonEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesMouseLeftButtonDown) {
                            _this.beforeSeriesMouseLeftButtonDown(_this, outerArgs);
                        }
                        _this._seriesMouseLeftButtonDown.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesMouseLeftButtonDown;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseLeftButtonUp", {
        get: /**
             * Occurs when the left mouse button is released while the mouse pointer is over a Series.
            *
            * &lt;-- position: content member-->
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     (seriesMouseLeftButtonUp)="onSeriesMouseLeftButtonUp($event)">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value"
            *         thickness=5>
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * &lt;-- position: content member-->
            *
            * ```ts
            * public onSeriesMouseLeftButtonUp(event: {sender: any, args: DataChartMouseButtonEventArgs})
            * {
            *     var item = event.args.item;
            * }
            * ```
            */
        function () {
            var _this = this;
            if (this._seriesMouseLeftButtonUp == null) {
                this._seriesMouseLeftButtonUp = new EventEmitter();
                this.i.seriesMouseLeftButtonUp = delegateCombine(this.i.seriesMouseLeftButtonUp, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new DataChartMouseButtonEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesMouseLeftButtonUp) {
                            _this.beforeSeriesMouseLeftButtonUp(_this, outerArgs);
                        }
                        _this._seriesMouseLeftButtonUp.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesMouseLeftButtonUp;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseMove", {
        get: /**
             * Occurs when the mouse pointer moves while over a Series.
            *
            * &lt;-- position: content member-->
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     (seriesMouseMove)="onSeriesMouseMove($event)">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value"
            *         thickness=5>
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * &lt;-- position: content member-->
            *
            * ```ts
            * public onSeriesMouseMove(event: {sender: any, args: ChartMouseEventArgs})
            * {
            *     var item = event.args.item;
            * }
            * ```
            */
        function () {
            var _this = this;
            if (this._seriesMouseMove == null) {
                this._seriesMouseMove = new EventEmitter();
                this.i.seriesMouseMove = delegateCombine(this.i.seriesMouseMove, function (o, e) {
                    var outerArgs = new ChartMouseEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeSeriesMouseMove) {
                        _this.beforeSeriesMouseMove(_this, outerArgs);
                    }
                    _this._seriesMouseMove.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._seriesMouseMove;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseEnter", {
        get: /**
             * Occurs when the mouse pointer enters a Series.
            *
            * &lt;-- position: content member-->
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     (seriesMouseEnter)="onSeriesMouseEnter($event)">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value"
            *         thickness=5>
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * &lt;-- position: content member-->
            *
            * ```ts
            * public onSeriesMouseEnter(event: {sender: any, args: ChartMouseEventArgs})
            * {
            *     var item = event.args.item;
            * }
            * ```
            */
        function () {
            var _this = this;
            if (this._seriesMouseEnter == null) {
                this._seriesMouseEnter = new EventEmitter();
                this.i.seriesMouseEnter = delegateCombine(this.i.seriesMouseEnter, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new ChartMouseEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesMouseEnter) {
                            _this.beforeSeriesMouseEnter(_this, outerArgs);
                        }
                        _this._seriesMouseEnter.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesMouseEnter;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseLeave", {
        get: /**
             * Occurs when the mouse pointer leaves a Series.
            *
            * &lt;-- position: content member-->
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     (seriesMouseLeave)="onSeriesMouseLeave($event)">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value"
            *         thickness=5>
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * &lt;-- position: content member-->
            *
            * ```ts
            * public onSeriesMouseLeave(event: {sender: any, args: ChartMouseEventArgs})
            * {
            *     var item = event.args.item;
            * }
            * ```
            */
        function () {
            var _this = this;
            if (this._seriesMouseLeave == null) {
                this._seriesMouseLeave = new EventEmitter();
                this.i.seriesMouseLeave = delegateCombine(this.i.seriesMouseLeave, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new ChartMouseEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesMouseLeave) {
                            _this.beforeSeriesMouseLeave(_this, outerArgs);
                        }
                        _this._seriesMouseLeave.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesMouseLeave;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowRectChanged", {
        get: /**
             * Occurs just after the current SeriesViewer's window rectangle is changed.
            *
            * &lt;-- position: content member-->
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     isHorizontalZoomEnabled=true
            *     (windowRectChanged)="onWindowRectChanged($event)">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * &lt;-- position: content member-->
            *
            * ```ts
            * public onWindowRectChanged(event: {sender: any, args: RectChangedEventArgs})
            * {
            *     let newRect: IgxRect = event.args.newRect;
            * }
            * ```
            */
        function () {
            var _this = this;
            if (this._windowRectChanged == null) {
                this._windowRectChanged = new EventEmitter();
                this.i.windowRectChanged = delegateCombine(this.i.windowRectChanged, function (o, e) {
                    var outerArgs = new RectChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeWindowRectChanged) {
                        _this.beforeWindowRectChanged(_this, outerArgs);
                    }
                    _this._windowRectChanged.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._windowRectChanged;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "sizeChanged", {
        get: /**
             * Occurs after the size of the series viewer changes.
            *
            * &lt;-- position: content member-->
            *
            * ```html
            * <igx-data-chart
            *     [dataSource]="data"
            *     (sizeChanged)="onSizeChanged($event)">
            *     <igx-category-x-axis
            *         label="label"
            *         #xAxis>
            *     </igx-category-x-axis>
            *     <igx-numeric-y-axis
            *         #yAxis>
            *     </igx-numeric-y-axis>
            *     <igx-line-series
            *         [xAxis]="xAxis"
            *         [yAxis]="yAxis"
            *         valueMemberPath="value">
            *     </igx-line-series>
            * </igx-data-chart>
            * ```
            *
            * &lt;-- position: content member-->
            *
            * ```ts
            * public onSizeChanged(event: {sender: any, args: RectChangedEventArgs})
            * {
            *     let newRect: IgxRect = event.args.newRect;
            * }
            * ```
            */
        function () {
            var _this = this;
            if (this._sizeChanged == null) {
                this._sizeChanged = new EventEmitter();
                this.i.sizeChanged = delegateCombine(this.i.sizeChanged, function (o, e) {
                    var outerArgs = new RectChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeSizeChanged) {
                        _this.beforeSizeChanged(_this, outerArgs);
                    }
                    _this._sizeChanged.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._sizeChanged;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "gridAreaRectChanged", {
        get: /**
             * Occurs just after the current SeriesViewer's grid area rectangle is changed.
             * The grid area may change as the result of the SeriesViewer being resized, or
             * of an axis being added or changing size, possibly in another SeriesViewer.
            */
        function () {
            var _this = this;
            if (this._gridAreaRectChanged == null) {
                this._gridAreaRectChanged = new EventEmitter();
                this.i.gridAreaRectChanged = delegateCombine(this.i.gridAreaRectChanged, function (o, e) {
                    var outerArgs = new RectChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeGridAreaRectChanged) {
                        _this.beforeGridAreaRectChanged(_this, outerArgs);
                    }
                    _this._gridAreaRectChanged.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._gridAreaRectChanged;
        },
        enumerable: true,
        configurable: true
    });
    IgxSeriesViewerComponent.prototype._runInZone = function (act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    };
    IgxSeriesViewerComponent.propDecorators = {
        "crosshairPoint": [{ type: Input },],
        "animateSeriesWhenAxisRangeChanges": [{ type: Input },],
        "effectiveViewport": [{ type: Input },],
        "windowRect": [{ type: Input },],
        "useTiledZooming": [{ type: Input },],
        "preferHigherResolutionTiles": [{ type: Input },],
        "zoomTileCacheSize": [{ type: Input },],
        "highlightingTransitionDuration": [{ type: Input },],
        "isPagePanningAllowed": [{ type: Input },],
        "contentHitTestMode": [{ type: Input },],
        "actualContentHitTestMode": [{ type: Input },],
        "isSurfaceInteractionDisabled": [{ type: Input },],
        "windowResponse": [{ type: Input },],
        "windowRectMinWidth": [{ type: Input },],
        "overviewPlusDetailPaneVisibility": [{ type: Input },],
        "crosshairVisibility": [{ type: Input },],
        "plotAreaBackground": [{ type: Input },],
        "defaultInteraction": [{ type: Input },],
        "dragModifier": [{ type: Input },],
        "panModifier": [{ type: Input },],
        "previewRect": [{ type: Input },],
        "windowPositionHorizontal": [{ type: Input },],
        "windowPositionVertical": [{ type: Input },],
        "chartTitle": [{ type: Input },],
        "titleHorizontalAlignment": [{ type: Input },],
        "subtitleHorizontalAlignment": [{ type: Input },],
        "titleTextStyle": [{ type: Input },],
        "subtitleTextStyle": [{ type: Input },],
        "titleTextColor": [{ type: Input },],
        "subtitleTextColor": [{ type: Input },],
        "titleTopMargin": [{ type: Input },],
        "titleLeftMargin": [{ type: Input },],
        "titleRightMargin": [{ type: Input },],
        "titleBottomMargin": [{ type: Input },],
        "subtitleTopMargin": [{ type: Input },],
        "subtitleLeftMargin": [{ type: Input },],
        "subtitleRightMargin": [{ type: Input },],
        "subtitleBottomMargin": [{ type: Input },],
        "subtitle": [{ type: Input },],
        "SyncChannel": [{ type: Input },],
        "SynchronizeVertically": [{ type: Input },],
        "SynchronizeHorizontally": [{ type: Input },],
        "topMargin": [{ type: Input },],
        "leftMargin": [{ type: Input },],
        "rightMargin": [{ type: Input },],
        "bottomMargin": [{ type: Input },],
        "autoMarginWidth": [{ type: Input },],
        "autoMarginHeight": [{ type: Input },],
        "isAntiAliasingEnabledDuringInteraction": [{ type: Input },],
        "pixelScalingRatio": [{ type: Input },],
        "interactionPixelScalingRatio": [{ type: Input },],
        "overviewPlusDetailPaneBackgroundImageUri": [{ type: Input },],
        "actualPixelScalingRatio": [{ type: Input },],
        "actualInteractionPixelScalingRatio": [{ type: Input },],
        "actualWindowRect": [{ type: Input },],
        "actualWindowPositionHorizontal": [{ type: Input },],
        "actualWindowPositionVertical": [{ type: Input },],
        "seriesCursorMouseMove": [{ type: Output },],
        "seriesMouseLeftButtonDown": [{ type: Output },],
        "seriesMouseLeftButtonUp": [{ type: Output },],
        "seriesMouseMove": [{ type: Output },],
        "seriesMouseEnter": [{ type: Output },],
        "seriesMouseLeave": [{ type: Output },],
        "windowRectChanged": [{ type: Output },],
        "sizeChanged": [{ type: Output },],
        "gridAreaRectChanged": [{ type: Output },],
    };
    return IgxSeriesViewerComponent;
}());
export { IgxSeriesViewerComponent };
//# sourceMappingURL=igx-series-viewer-component.js.map