import * as tslib_1 from "tslib";
import { EventEmitter, Output, forwardRef, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES5/type";
import { StackedSeriesCreatedEventArgs } from "./igx-stacked-series-created-event-args";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureBool, toPoint } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents a base class for stacked series.
*/
export var IgxStackedSeriesBaseComponent_PROVIDERS = [{ provide: IgxCategorySeriesComponent, useExisting: forwardRef(function () { return IgxStackedSeriesBaseComponent; }) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxStackedSeriesBaseComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxStackedSeriesBaseComponent; }) }];
var IgxStackedSeriesBaseComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxStackedSeriesBaseComponent, _super);
    function IgxStackedSeriesBaseComponent() {
        var _this = _super.call(this) || this;
        _this._seriesCreated = null;
        return _this;
    }
    Object.defineProperty(IgxStackedSeriesBaseComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxStackedSeriesBaseComponent.prototype, "autoGenerateSeries", {
        /**
         * Gets or sets whether series should be automatically generated. Reqiures the use of GroupBy as the ItemsSource.
        */
        get: /**
             * Gets or sets whether series should be automatically generated. Reqiures the use of GroupBy as the ItemsSource.
            */
        function () {
            return this.i.ox;
        },
        set: function (v) {
            this.i.ox = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxStackedSeriesBaseComponent.prototype, "reverseLegendOrder", {
        /**
         * Gets or sets whether the order of the fragment series should be reversed in the legend.
        */
        get: /**
             * Gets or sets whether the order of the fragment series should be reversed in the legend.
            */
        function () {
            return this.i.oy;
        },
        set: function (v) {
            this.i.oy = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxStackedSeriesBaseComponent.prototype, "isStacked", {
        /**
         * Checks if this series is a stacked series
        */
        get: /**
             * Checks if this series is a stacked series
            */
        function () {
            return this.i.isStacked;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Simulates a pointer hover over the series surface.
    
    * @param point  * The pointer position relative to the series viewport over which to hover.
    */
    /**
         * Simulates a pointer hover over the series surface.
        
        * @param point  * The pointer position relative to the series viewport over which to hover.
        */
    IgxStackedSeriesBaseComponent.prototype.simulateHover = /**
         * Simulates a pointer hover over the series surface.
        
        * @param point  * The pointer position relative to the series viewport over which to hover.
        */
    function (point) {
        this.i.jc(toPoint(point));
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    IgxStackedSeriesBaseComponent.prototype.scrollIntoView = /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    function (item) {
        var iv = this.i.c8(item);
        return (iv);
    };
    Object.defineProperty(IgxStackedSeriesBaseComponent.prototype, "seriesCreated", {
        get: /**
             * Event raised when a new fragment series is automatically generated.
            */
        function () {
            var _this = this;
            if (this._seriesCreated == null) {
                this._seriesCreated = new EventEmitter();
                this.i.seriesCreated = delegateCombine(this.i.seriesCreated, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new StackedSeriesCreatedEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesCreated) {
                            _this.beforeSeriesCreated(_this, outerArgs);
                        }
                        _this._seriesCreated.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesCreated;
        },
        enumerable: true,
        configurable: true
    });
    IgxStackedSeriesBaseComponent.propDecorators = {
        "autoGenerateSeries": [{ type: Input },],
        "reverseLegendOrder": [{ type: Input },],
        "seriesCreated": [{ type: Output },],
    };
    return IgxStackedSeriesBaseComponent;
}(IgxCategorySeriesComponent));
export { IgxStackedSeriesBaseComponent };
//# sourceMappingURL=igx-stacked-series-base-component.js.map