import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { HorizontalAlignment, HorizontalAlignment_$type } from "igniteui-angular-core/ES5/HorizontalAlignment";
import { VerticalAlignment, VerticalAlignment_$type } from "igniteui-angular-core/ES5/VerticalAlignment";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES5/Visibility";
import { AxisLabelsLocation, AxisLabelsLocation_$type } from "./AxisLabelsLocation";
import { IgxDomainChartComponent } from "./igx-domain-chart-component";
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents a base class for domain charts with X/Y axes
*/
export var IgxXYChartComponent_PROVIDERS = [{ provide: IgxDomainChartComponent, useExisting: forwardRef(function () { return IgxXYChartComponent; }) }];
var IgxXYChartComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxXYChartComponent, _super);
    function IgxXYChartComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxXYChartComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisFormatLabel", {
        /**
         * Gets or sets function which takes an context object and returns a formatted label for the X-axis.
        *
        * To customize the text of the x-axis label, set `xAxisFormatLabel` to a single-parameter function.  The argument passed to that function will be your data item.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     [xAxisFormatLabel]="formatX"
        *     xAxisExtent="250">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * formatX(item: any): string {
        *     return "[ " + item.label + "! ]";
        * }
        * ```
        */
        get: /**
             * Gets or sets function which takes an context object and returns a formatted label for the X-axis.
            *
            * To customize the text of the x-axis label, set `xAxisFormatLabel` to a single-parameter function.  The argument passed to that function will be your data item.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     [xAxisFormatLabel]="formatX"
            *     xAxisExtent="250">
            * </igx-category-chart>
            * ```
            *
            * ```ts
            * formatX(item: any): string {
            *     return "[ " + item.label + "! ]";
            * }
            * ```
            */
        function () {
            return this.i.ib;
        },
        set: function (v) {
            this.i.ib = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisFormatLabel", {
        /**
         * Gets or sets function which takes a context object and returns a formatted label for the Y-axis.
        *
        * To customize the text of the y-axis label, set `yAxisFormatLabel` to a single-parameter function.  The argument passed to that function will be the numeric value corresponding to a position on the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     [yAxisFormatLabel]="formatY">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * formatY(value: any): string {
        *     return "[ " + value+ "! ]";
        * }
        * ```
        */
        get: /**
             * Gets or sets function which takes a context object and returns a formatted label for the Y-axis.
            *
            * To customize the text of the y-axis label, set `yAxisFormatLabel` to a single-parameter function.  The argument passed to that function will be the numeric value corresponding to a position on the y-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     [yAxisFormatLabel]="formatY">
            * </igx-category-chart>
            * ```
            *
            * ```ts
            * formatY(value: any): string {
            *     return "[ " + value+ "! ]";
            * }
            * ```
            */
        function () {
            return this.i.ic;
        },
        set: function (v) {
            this.i.ic = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelLeftMargin", {
        /**
         * Gets or sets the left margin of labels on the X-axis
        *
        * Use the `xAxisLabelLeftMargin` property to apply a margin left of the x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelLeftMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the left margin of labels on the X-axis
            *
            * Use the `xAxisLabelLeftMargin` property to apply a margin left of the x-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisLabelLeftMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jq;
        },
        set: function (v) {
            this.i.jq = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelTopMargin", {
        /**
         * Gets or sets the top margin of labels on the X-axis
        *
        * Use the `xAxisLabelTopMargin` property to apply a margin above the x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleTopMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the top margin of labels on the X-axis
            *
            * Use the `xAxisLabelTopMargin` property to apply a margin above the x-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis"
            *     xAxisTitleTopMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.js;
        },
        set: function (v) {
            this.i.js = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelRightMargin", {
        /**
         * Gets or sets the right margin of labels on the X-axis
        *
        * Use the `xAxisLabelRightMargin` property to apply a margin right of the x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelRightMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the right margin of labels on the X-axis
            *
            * Use the `xAxisLabelRightMargin` property to apply a margin right of the x-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisLabelRightMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jr;
        },
        set: function (v) {
            this.i.jr = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelBottomMargin", {
        /**
         * Gets or sets the bottom margin of labels on the X-axis
        *
        * Use the `xAxisLabelBottomMargin` property to apply a margin below the x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelBottomMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the bottom margin of labels on the X-axis
            *
            * Use the `xAxisLabelBottomMargin` property to apply a margin below the x-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisLabelBottomMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jp;
        },
        set: function (v) {
            this.i.jp = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelLeftMargin", {
        /**
         * Gets or sets the left margin of labels on the Y-axis
        *
        * Use the `yAxisLabelLeftMargin` property to apply a margin left of the y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelLeftMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the left margin of labels on the Y-axis
            *
            * Use the `yAxisLabelLeftMargin` property to apply a margin left of the y-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisLabelLeftMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.j7;
        },
        set: function (v) {
            this.i.j7 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelTopMargin", {
        /**
         * Gets or sets the top margin of labels on the Y-axis
        *
        * Use the `yAxisLabelTopMargin` property to apply a margin above the y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelTopMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the top margin of labels on the Y-axis
            *
            * Use the `yAxisLabelTopMargin` property to apply a margin above the y-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisLabelTopMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.j9;
        },
        set: function (v) {
            this.i.j9 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelRightMargin", {
        /**
         * Gets or sets the right margin of labels on the Y-axis
        *
        * Use the `yAxisLabelRightMargin` property to apply a margin right of the y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelRightMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the right margin of labels on the Y-axis
            *
            * Use the `yAxisLabelRightMargin` property to apply a margin right of the y-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisLabelRightMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.j8;
        },
        set: function (v) {
            this.i.j8 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelBottomMargin", {
        /**
         * Gets or sets the bottom margin of labels on the Y-axis
        *
        * Use the `yAxisLabelBottomMargin` property to apply a margin below the y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelBottomMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the bottom margin of labels on the Y-axis
            *
            * Use the `yAxisLabelBottomMargin` property to apply a margin below the y-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisLabelBottomMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.j6;
        },
        set: function (v) {
            this.i.j6 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelTextColor", {
        /**
         * Gets or sets color of labels on the X-axis
        *
        * To change the color of x-axis labels, set the `xAxisLabelTextColor` property to a color string.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelTextColor="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets color of labels on the X-axis
            *
            * To change the color of x-axis labels, set the `xAxisLabelTextColor` property to a color string.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisLabelTextColor="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.nx);
        },
        set: function (v) {
            this.i.nx = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelTextColor", {
        /**
         * Gets or sets color of labels on the Y-axis
        *
        * To change the color of y-axis labels, set the `yAxisLabelTextColor` property to a color string.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelTextColor="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets color of labels on the Y-axis
            *
            * To change the color of y-axis labels, set the `yAxisLabelTextColor` property to a color string.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisLabelTextColor="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n4);
        },
        set: function (v) {
            this.i.n4 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleMargin", {
        /**
         * Gets or sets the margin around a title on the X-axis
        *
        * Use the `xAxisTitleMargin` property to set a margin around the y-axis title.
        */
        get: /**
             * Gets or sets the margin around a title on the X-axis
            *
            * Use the `xAxisTitleMargin` property to set a margin around the y-axis title.
            */
        function () {
            return this.i.j1;
        },
        set: function (v) {
            this.i.j1 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleMargin", {
        /**
         * Gets or sets the margin around a title on the Y-axis
        *
        * Use the `yAxisTitleMargin` property to set a margin around the y-axis title.
        */
        get: /**
             * Gets or sets the margin around a title on the Y-axis
            *
            * Use the `yAxisTitleMargin` property to set a margin around the y-axis title.
            */
        function () {
            return this.i.ki;
        },
        set: function (v) {
            this.i.ki = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleLeftMargin", {
        /**
         * Gets or sets the left margin of a title on the X-axis
        *
        * Use the `xAxisTitleLeftMargin` property to apply a margin left of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleAlignment="left"
        *     xAxisTitleLeftMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the left margin of a title on the X-axis
            *
            * Use the `xAxisTitleLeftMargin` property to apply a margin left of the x-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis"
            *     xAxisTitleAlignment="left"
            *     xAxisTitleLeftMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.j0;
        },
        set: function (v) {
            this.i.j0 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleLeftMargin", {
        /**
         * Gets or sets the left margin of a title on the Y-axis
        *
        * Use the `yAxisTitleLeftMargin` property to apply a margin left of the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleLeftMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the left margin of a title on the Y-axis
            *
            * Use the `yAxisTitleLeftMargin` property to apply a margin left of the y-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTitle="y axis"
            *     yAxisTitleLeftMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.kh;
        },
        set: function (v) {
            this.i.kh = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleTopMargin", {
        /**
         * Gets or sets the top margin of a title on the X-axis
        *
        * Use the `xAxisTitleTopMargin` property to apply a margin above the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleTopMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the top margin of a title on the X-axis
            *
            * Use the `xAxisTitleTopMargin` property to apply a margin above the x-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis"
            *     xAxisTitleTopMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.j3;
        },
        set: function (v) {
            this.i.j3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleTopMargin", {
        /**
         * Gets or sets the top margin of a title on the Y-axis
        *
        * Use the `yAxisTitleTopMargin` property to apply a margin above the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleAlignment="top"
        *     yAxisTitleTopMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the top margin of a title on the Y-axis
            *
            * Use the `yAxisTitleTopMargin` property to apply a margin above the y-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTitle="y axis"
            *     yAxisTitleAlignment="top"
            *     yAxisTitleTopMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.kk;
        },
        set: function (v) {
            this.i.kk = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleRightMargin", {
        /**
         * Gets or sets the right margin of a title on the X-axis
        *
        * Use the `xAxisTitleRightMargin` property to apply a margin right of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleAlignment="right"
        *     xAxisTitleRightMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the right margin of a title on the X-axis
            *
            * Use the `xAxisTitleRightMargin` property to apply a margin right of the x-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis"
            *     xAxisTitleAlignment="right"
            *     xAxisTitleRightMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.j2;
        },
        set: function (v) {
            this.i.j2 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleRightMargin", {
        /**
         * Gets or sets the right margin of a title on the Y-axis
        *
        * Use the `yAxisTitleRightMargin` property to apply a margin right of the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleRightMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the right margin of a title on the Y-axis
            *
            * Use the `yAxisTitleRightMargin` property to apply a margin right of the y-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTitle="y axis"
            *     yAxisTitleRightMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.kj;
        },
        set: function (v) {
            this.i.kj = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleBottomMargin", {
        /**
         * Gets or sets the bottom margin of a title on the X-axis
        *
        * Use the `xAxisTitleBottomMargin` property to apply a margin below the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleBottomMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the bottom margin of a title on the X-axis
            *
            * Use the `xAxisTitleBottomMargin` property to apply a margin below the x-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis"
            *     xAxisTitleBottomMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jz;
        },
        set: function (v) {
            this.i.jz = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleBottomMargin", {
        /**
         * Gets or sets the bottom margin of a title on the Y-axis
        *
        * Use the `yAxisTitleBottomMargin` property to apply a margin below the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleAlignment="bottom"
        *     yAxisTitleBottomMargin="100">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the bottom margin of a title on the Y-axis
            *
            * Use the `yAxisTitleBottomMargin` property to apply a margin below the y-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTitle="y axis"
            *     yAxisTitleAlignment="bottom"
            *     yAxisTitleBottomMargin="100">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.kg;
        },
        set: function (v) {
            this.i.kg = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleTextColor", {
        /**
         * Gets or sets color of title on the X-axis
        *
        * To change the color of the x-axis title, set the `xAxisTitleTextColor` property to a color string.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleTextColor="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets color of title on the X-axis
            *
            * To change the color of the x-axis title, set the `xAxisTitleTextColor` property to a color string.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis"
            *     xAxisTitleTextColor="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n3);
        },
        set: function (v) {
            this.i.n3 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleTextColor", {
        /**
         * Gets or sets color of title on the Y-axis
        *
        * To change the color of the y-axis title, set the `yAxisTitleTextColor` property to a color string.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleTextColor="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets color of title on the Y-axis
            *
            * To change the color of the y-axis title, set the `yAxisTitleTextColor` property to a color string.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTitle="y axis"
            *     yAxisTitleTextColor="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.oa);
        },
        set: function (v) {
            this.i.oa = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelTextStyle", {
        /**
         * Gets or sets CSS font property for labels on X-axis
        *
        * To change the font of x-axis labels, set the `xAxisLabelTextStyle` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelTextStyle="italic 15px arial, sans-serif">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets CSS font property for labels on X-axis
            *
            * To change the font of x-axis labels, set the `xAxisLabelTextStyle` property.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisLabelTextStyle="italic 15px arial, sans-serif">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.k6;
        },
        set: function (v) {
            this.i.k6 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelTextStyle", {
        /**
         * Gets or sets CSS font property for labels on Y-axis
        *
        * To change the font of x-axis labels, set the `yAxisLabelTextStyle` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelTextStyle="italic 15px arial, sans-serif">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets CSS font property for labels on Y-axis
            *
            * To change the font of x-axis labels, set the `yAxisLabelTextStyle` property.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisLabelTextStyle="italic 15px arial, sans-serif">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.l8;
        },
        set: function (v) {
            this.i.l8 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleTextStyle", {
        /**
         * Gets or sets CSS font property for title on X-axis
        *
        * To change the font of the x-axis title, set the `xAxisTitleTextStyle` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleTextStyle="italic 15px arial, sans-serif">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets CSS font property for title on X-axis
            *
            * To change the font of the x-axis title, set the `xAxisTitleTextStyle` property.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis"
            *     xAxisTitleTextStyle="italic 15px arial, sans-serif">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.lu;
        },
        set: function (v) {
            this.i.lu = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleTextStyle", {
        /**
         * Gets or sets CSS font property for title on Y-axis
        *
        * To change the font of the x-axis title, set the `yAxisTitleTextStyle` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="y axis"
        *     yAxisTitleTextStyle="italic 15px arial, sans-serif">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets CSS font property for title on Y-axis
            *
            * To change the font of the x-axis title, set the `yAxisTitleTextStyle` property.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="y axis"
            *     yAxisTitleTextStyle="italic 15px arial, sans-serif">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.mw;
        },
        set: function (v) {
            this.i.mw = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabel", {
        /**
         * Gets or sets the format for labels along the X-axis.
        */
        get: /**
             * Gets or sets the format for labels along the X-axis.
            */
        function () {
            return this.i.kn;
        },
        set: function (v) {
            this.i.kn = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabel", {
        /**
         * Gets or sets the property or string from which the labels are derived.
        */
        get: /**
             * Gets or sets the property or string from which the labels are derived.
            */
        function () {
            return this.i.ko;
        },
        set: function (v) {
            this.i.ko = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisMajorStroke", {
        /**
         * Gets or sets the color to apply to major gridlines along the X-axis.
        *
        * Set `xAxisMajorStroke` to control the color of major gridlines extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisMajorStroke="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to major gridlines along the X-axis.
            *
            * Set `xAxisMajorStroke` to control the color of major gridlines extending vertically from the x-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisMajorStroke="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.ny);
        },
        set: function (v) {
            this.i.ny = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisMajorStroke", {
        /**
         * Gets or sets the color to apply to major gridlines along the Y-axis.
        *
        * Set `yAxisMajorStroke` to control the color of major gridlines extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisMajorStroke="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to major gridlines along the Y-axis.
            *
            * Set `yAxisMajorStroke` to control the color of major gridlines extending horizontally from the y-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisMajorStroke="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n5);
        },
        set: function (v) {
            this.i.n5 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisMajorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to major gridlines along the X-axis.
        *
        * Set `xAxisMajorStrokeThickness` to control the thickness of major gridlines extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisMajorStroke="green"
        *     xAxisMajorStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the thickness to apply to major gridlines along the X-axis.
            *
            * Set `xAxisMajorStrokeThickness` to control the thickness of major gridlines extending vertically from the x-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisMajorStroke="green"
            *     xAxisMajorStrokeThickness="3">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jt;
        },
        set: function (v) {
            this.i.jt = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisMajorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to major gridlines along the Y-axis.
        *
        * Set `yAxisMajorStrokeThickness` to control the thickness of major gridlines extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisMajorStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the thickness to apply to major gridlines along the Y-axis.
            *
            * Set `yAxisMajorStrokeThickness` to control the thickness of major gridlines extending horizontally from the y-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisMajorStrokeThickness="3">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.ka;
        },
        set: function (v) {
            this.i.ka = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisMinorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to minor gridlines along the X-axis.
        *
        * Set `xAxisMinorStrokeThickness` to control the thickness of minor gridlines extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisMinorStroke="green"
        *     xAxisMinorStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the thickness to apply to minor gridlines along the X-axis.
            *
            * Set `xAxisMinorStrokeThickness` to control the thickness of minor gridlines extending vertically from the x-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisMinorStroke="green"
            *     xAxisMinorStrokeThickness="3">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.ju;
        },
        set: function (v) {
            this.i.ju = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisMinorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to minor gridlines along the Y-axis.
        *
        * Set `yAxisMinorStrokeThickness` to control the thickness of minor gridlines extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisMinorStroke="green"
        *     yAxisMinorStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the thickness to apply to minor gridlines along the Y-axis.
            *
            * Set `yAxisMinorStrokeThickness` to control the thickness of minor gridlines extending horizontally from the y-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisMinorStroke="green"
            *     yAxisMinorStrokeThickness="3">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.kb;
        },
        set: function (v) {
            this.i.kb = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisStrip", {
        /**
         * Gets or sets the color to apply to stripes along the X-axis.
        *
        * Set `xAxisStrip` to control the alternating color of stripes extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisStrip="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to stripes along the X-axis.
            *
            * Set `xAxisStrip` to control the alternating color of stripes extending vertically from the x-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisStrip="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n0);
        },
        set: function (v) {
            this.i.n0 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisStrip", {
        /**
         * Gets or sets the color to apply to stripes along the Y-axis.
        *
        * Set `yAxisStrip` to control the alternating color of stripes extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisStrip="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to stripes along the Y-axis.
            *
            * Set `yAxisStrip` to control the alternating color of stripes extending horizontally from the y-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisStrip="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n7);
        },
        set: function (v) {
            this.i.n7 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisStroke", {
        /**
         * Gets or sets the color to apply to the X-axis line.
        *
        * Set `xAxisStroke` to control the color of the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisStroke="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to the X-axis line.
            *
            * Set `xAxisStroke` to control the color of the x-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisStroke="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n1);
        },
        set: function (v) {
            this.i.n1 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisStroke", {
        /**
         * Gets or sets the color to apply to the Y-axis line.
        *
        * Set `yAxisStroke` to control the color of the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisStroke="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to the Y-axis line.
            *
            * Set `yAxisStroke` to control the color of the y-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisStroke="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n8);
        },
        set: function (v) {
            this.i.n8 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to the X-axis line.
        *
        * Set `xAxisStrokeThickness` to control the thickness of the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the thickness to apply to the X-axis line.
            *
            * Set `xAxisStrokeThickness` to control the thickness of the x-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisStrokeThickness="3">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jv;
        },
        set: function (v) {
            this.i.jv = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to the Y-axis line.
        *
        * Set `yAxisStrokeThickness` to control the thickness of the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisStroke="green"
        *     yAxisStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the thickness to apply to the Y-axis line.
            *
            * Set `yAxisStrokeThickness` to control the thickness of the y-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisStroke="green"
            *     yAxisStrokeThickness="3">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.kc;
        },
        set: function (v) {
            this.i.kc = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTickLength", {
        /**
         * Gets or sets the length of tickmarks along the X-axis.
        *
        * Set `xAxisTickLength` to control the length of tickmarks extending vertically from the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTickLength="23">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the length of tickmarks along the X-axis.
            *
            * Set `xAxisTickLength` to control the length of tickmarks extending vertically from the x-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTickLength="23">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jw;
        },
        set: function (v) {
            this.i.jw = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTickLength", {
        /**
         * Gets or sets the length of tickmarks along the Y-axis.
        *
        * Set `yAxisTickLength` to control the length of tickmarks extending horizontally from the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTickLength="23">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the length of tickmarks along the Y-axis.
            *
            * Set `yAxisTickLength` to control the length of tickmarks extending horizontally from the y-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTickLength="23">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.kd;
        },
        set: function (v) {
            this.i.kd = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTickStroke", {
        /**
         * Gets or sets the color to apply to tickmarks along the X-axis.
        *
        * Set `xAxisTickStroke` to control the color of tickmarks extending vertically from the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTickStroke="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to tickmarks along the X-axis.
            *
            * Set `xAxisTickStroke` to control the color of tickmarks extending vertically from the x-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTickStroke="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n2);
        },
        set: function (v) {
            this.i.n2 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTickStroke", {
        /**
         * Gets or sets the color to apply to tickmarks along the Y-axis.
        *
        * Set `yAxisTickStroke` to control the color of tickmarks extending horizontally from the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTickLength="5"
        *     yAxisTickStroke="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to tickmarks along the Y-axis.
            *
            * Set `yAxisTickStroke` to control the color of tickmarks extending horizontally from the y-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTickLength="5"
            *     yAxisTickStroke="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n9);
        },
        set: function (v) {
            this.i.n9 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTickStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to tickmarks along the X-axis.
        *
        * Set `xAxisTickStrokeThickness` to control the thickness of tickmarks extending vertically from the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTickStrokeThickness="10">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the thickness to apply to tickmarks along the X-axis.
            *
            * Set `xAxisTickStrokeThickness` to control the thickness of tickmarks extending vertically from the x-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTickStrokeThickness="10">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jx;
        },
        set: function (v) {
            this.i.jx = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTickStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to tickmarks along the Y-axis.
        *
        * Set `yAxisTickStrokeThickness` to control the thickness of tickmarks extending vertically from the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTickLength="5"
        *     yAxisTickStrokeThickness="10">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the thickness to apply to tickmarks along the Y-axis.
            *
            * Set `yAxisTickStrokeThickness` to control the thickness of tickmarks extending vertically from the y-axis line.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTickLength="5"
            *     yAxisTickStrokeThickness="10">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.ke;
        },
        set: function (v) {
            this.i.ke = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitle", {
        /**
         * Gets or sets the Text to display below the X-axis.
        *
        * Set `xAxisTitle` to display a label adjacent to the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the Text to display below the X-axis.
            *
            * Set `xAxisTitle` to display a label adjacent to the x-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.ll;
        },
        set: function (v) {
            this.i.ll = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitle", {
        /**
         * Gets or sets the Text to display to the left of the Y-axis.
        *
        * Set `yAxisTitle` to display a label adjacent to the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the Text to display to the left of the Y-axis.
            *
            * Set `yAxisTitle` to display a label adjacent to the y-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTitle="y axis">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.mn;
        },
        set: function (v) {
            this.i.mn = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisMinorStroke", {
        /**
         * Gets or sets the color to apply to minor gridlines along the X-axis.
        *
        * Set `xAxisMinorStroke` to control the color of minor gridlines extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisMinorStroke="green">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to minor gridlines along the X-axis.
            *
            * Set `xAxisMinorStroke` to control the color of minor gridlines extending vertically from the x-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisMinorStroke="green">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.nz);
        },
        set: function (v) {
            this.i.nz = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisMinorStroke", {
        /**
         * Gets or sets the color to apply to minor gridlines along the Y-axis.
        *
        * Set `yAxisMinorStroke` to control the color of minor gridlines extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisMinorStroke="green"
        *     yAxisMinorStrokeThickness="1">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the color to apply to minor gridlines along the Y-axis.
            *
            * Set `yAxisMinorStroke` to control the color of minor gridlines extending horizontally from the y-axis.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisMinorStroke="green"
            *     yAxisMinorStrokeThickness="1">
            * </igx-category-chart>
            * ```
            */
        function () {
            return brushToString(this.i.n6);
        },
        set: function (v) {
            this.i.n6 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelAngle", {
        /**
         * Gets or sets the angle of rotation for labels along the X-axis.
        *
        * To control the rotation of labels on the x-axis, set the `xAxisLabelAngle` property to a number of rotational degrees.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelAngle="45">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the angle of rotation for labels along the X-axis.
            *
            * To control the rotation of labels on the x-axis, set the `xAxisLabelAngle` property to a number of rotational degrees.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisLabelAngle="45">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jo;
        },
        set: function (v) {
            this.i.jo = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelAngle", {
        /**
         * Gets or sets the angle of rotation for labels along the Y-axis.
        *
        * To control the rotation of labels on the y-axis, set the `yAxisLabelAngle` property to a number of rotational degrees.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelAngle="45">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the angle of rotation for labels along the Y-axis.
            *
            * To control the rotation of labels on the y-axis, set the `yAxisLabelAngle` property to a number of rotational degrees.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisLabelAngle="45">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.j5;
        },
        set: function (v) {
            this.i.j5 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisExtent", {
        /**
         * Gets or sets the distance between the X-axis and the bottom of the chart.
        *
        * To allocate space between the x-axis and the edge of the chart, set the `xAxisExtent` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisExtent="250">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the distance between the X-axis and the bottom of the chart.
            *
            * To allocate space between the x-axis and the edge of the chart, set the `xAxisExtent` property.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisExtent="250">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jn;
        },
        set: function (v) {
            this.i.jn = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisExtent", {
        /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        *
        * To allocate space between the x-axis and the edge of the chart, set the `xAxisExtent` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisExtent="250">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the distance between the Y-axis and the left edge of the chart.
            *
            * To allocate space between the x-axis and the edge of the chart, set the `xAxisExtent` property.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisExtent="250">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.j4;
        },
        set: function (v) {
            this.i.j4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleAngle", {
        /**
         * Gets or sets the angle of rotation for the X-axis title.
        *
        * Set `xAxisTitleAngle` to control the rotation of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleAngle="45">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the angle of rotation for the X-axis title.
            *
            * Set `xAxisTitleAngle` to control the rotation of the x-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis"
            *     xAxisTitleAngle="45">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.jy;
        },
        set: function (v) {
            this.i.jy = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleAngle", {
        /**
         * Gets or sets the angle of rotation for the Y-axis title.
        *
        * Set `yAxisTitleAngle` to control the rotation of the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleAngle="45">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets the angle of rotation for the Y-axis title.
            *
            * Set `yAxisTitleAngle` to control the rotation of the y-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTitle="y axis"
            *     yAxisTitleAngle="45">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.kf;
        },
        set: function (v) {
            this.i.kf = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisInverted", {
        /**
         * Gets or sets whether to invert the direction of the X-axis by placing the first data items on the right side of the chart.
        *
        * To reverse the direction of items along the x-axis, set the `xAxisInverted` property to true.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisInverted="true">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets whether to invert the direction of the X-axis by placing the first data items on the right side of the chart.
            *
            * To reverse the direction of items along the x-axis, set the `xAxisInverted` property to true.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisInverted="true">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.ii;
        },
        set: function (v) {
            this.i.ii = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisInverted", {
        /**
         * Gets or sets whether to invert the direction of the Y-axis by placing the minimum numeric value at the top of the chart.
        *
        * You can use `yAxisInverted` to invert the scale of the y axis like this:
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisInverted="true"
        * >
        *
        * </igx-category-chart>
        * ```
        *
        * The default value of `yAxisInverted` is false.
        */
        get: /**
             * Gets or sets whether to invert the direction of the Y-axis by placing the minimum numeric value at the top of the chart.
            *
            * You can use `yAxisInverted` to invert the scale of the y axis like this:
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisInverted="true"
            * >
            *
            * </igx-category-chart>
            * ```
            *
            * The default value of `yAxisInverted` is false.
            */
        function () {
            return this.i.ij;
        },
        set: function (v) {
            this.i.ij = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisTitleAlignment", {
        /**
         * Gets or sets Horizontal alignment of the X-axis title.
        *
        * Set `xAxisTitleAlignment` to control the horizontal alignment of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleAlignment="right">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets Horizontal alignment of the X-axis title.
            *
            * Set `xAxisTitleAlignment` to control the horizontal alignment of the x-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisTitle="x axis"
            *     xAxisTitleAlignment="right">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.nh;
        },
        set: function (v) {
            this.i.nh = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisTitleAlignment", {
        /**
         * Gets or sets Vertical alignment of the Y-axis title.
        *
        * Set `yAxisTitleAlignment` to control the vertical alignment of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleAlignment="bottom">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets Vertical alignment of the Y-axis title.
            *
            * Set `yAxisTitleAlignment` to control the vertical alignment of the x-axis title.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisTitle="y axis"
            *     yAxisTitleAlignment="bottom">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.og;
        },
        set: function (v) {
            this.i.og = ensureEnum(VerticalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelHorizontalAlignment", {
        /**
         * Gets or sets Horizontal alignment of X-axis labels.
        */
        get: /**
             * Gets or sets Horizontal alignment of X-axis labels.
            */
        function () {
            return this.i.ng;
        },
        set: function (v) {
            this.i.ng = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelHorizontalAlignment", {
        /**
         * Gets or sets Horizontal alignment of Y-axis labels.
        *
        * Set the `yAxisLabelHorizontalAlignment` property to change the horizontal alignment of y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisExtent="250"
        *     yAxisLabelHorizontalAlignment="left">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets Horizontal alignment of Y-axis labels.
            *
            * Set the `yAxisLabelHorizontalAlignment` property to change the horizontal alignment of y-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisExtent="250"
            *     yAxisLabelHorizontalAlignment="left">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.ni;
        },
        set: function (v) {
            this.i.ni = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelVerticalAlignment", {
        /**
         * Gets or sets Vertical alignment of X-axis labels.
        *
        * Use the `xAxisLabelVerticalAlignment` property to change the vertical position of x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisExtent="250"
        *     xAxisLabelVerticalAlignment="bottom">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets Vertical alignment of X-axis labels.
            *
            * Use the `xAxisLabelVerticalAlignment` property to change the vertical position of x-axis labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisExtent="250"
            *     xAxisLabelVerticalAlignment="bottom">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.oe;
        },
        set: function (v) {
            this.i.oe = ensureEnum(VerticalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelVerticalAlignment", {
        /**
         * Gets or sets Vertical alignment of Y-axis labels.
        */
        get: /**
             * Gets or sets Vertical alignment of Y-axis labels.
            */
        function () {
            return this.i.of;
        },
        set: function (v) {
            this.i.of = ensureEnum(VerticalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "xAxisLabelVisibility", {
        /**
         * Gets or sets Visibility of X-axis labels.
        *
        * To hide the x-axis labels, set `xAxisLabelVisibility` to collapsed.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelVisibility="collapsed">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets Visibility of X-axis labels.
            *
            * To hide the x-axis labels, set `xAxisLabelVisibility` to collapsed.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     xAxisLabelVisibility="collapsed">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.oj;
        },
        set: function (v) {
            this.i.oj = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelVisibility", {
        /**
         * Gets or sets Visibility of Y-axis labels.
        *
        * To hide the y-axis labels, set `yAxisLabelVisibility` to collapsed.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelVisibility="collapsed">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * Gets or sets Visibility of Y-axis labels.
            *
            * To hide the y-axis labels, set `yAxisLabelVisibility` to collapsed.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisLabelVisibility="collapsed">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.ok;
        },
        set: function (v) {
            this.i.ok = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxXYChartComponent.prototype, "yAxisLabelLocation", {
        /**
         * The location of Y-axis labels, relative to the plot area.
        *
        * Set the `yAxisLabelLocation` property to change the location of the y-axis and its labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelLocation="outsideRight">
        * </igx-category-chart>
        * ```
        */
        get: /**
             * The location of Y-axis labels, relative to the plot area.
            *
            * Set the `yAxisLabelLocation` property to change the location of the y-axis and its labels.
            *
            * ```html
            * <igx-category-chart
            *     [dataSource]="data"
            *     yAxisLabelLocation="outsideRight">
            * </igx-category-chart>
            * ```
            */
        function () {
            return this.i.ie;
        },
        set: function (v) {
            this.i.ie = ensureEnum(AxisLabelsLocation_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Called by the UI framework to provide a UI container for rendering this control.
    
    * @param container  * The UI container element.
    */
    /**
         * Called by the UI framework to provide a UI container for rendering this control.
        
        * @param container  * The UI container element.
        */
    IgxXYChartComponent.prototype.provideContainer = /**
         * Called by the UI framework to provide a UI container for rendering this control.
        
        * @param container  * The UI container element.
        */
    function (container) {
        this.i.provideContainer(container);
    };
    /**
     * Converts the given visual location to a data value.
    
    * @param unscaledValue  * The x-coordinate of the location to scale.
    */
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
    IgxXYChartComponent.prototype.getScaledValueX = /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
    function (unscaledValue) {
        var iv = this.i.jj(unscaledValue);
        return (iv);
    };
    /**
     * Converts the given data value to a visual location.
    
    * @param scaledValue  * The data value to un-scale.
    */
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    IgxXYChartComponent.prototype.getUnscaledValueX = /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    function (scaledValue) {
        var iv = this.i.jl(scaledValue);
        return (iv);
    };
    /**
     * Converts the given visual location to a data value.
    
    * @param unscaledValue  * The y-coordinate of the location to scale.
    */
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
    IgxXYChartComponent.prototype.getScaledValueY = /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
    function (unscaledValue) {
        var iv = this.i.jk(unscaledValue);
        return (iv);
    };
    /**
     * Converts the given data value to a visual location.
    
    * @param scaledValue  * The data value to un-scale.
    */
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    IgxXYChartComponent.prototype.getUnscaledValueY = /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    function (scaledValue) {
        var iv = this.i.jm(scaledValue);
        return (iv);
    };
    IgxXYChartComponent.propDecorators = {
        "xAxisFormatLabel": [{ type: Input },],
        "yAxisFormatLabel": [{ type: Input },],
        "xAxisLabelLeftMargin": [{ type: Input },],
        "xAxisLabelTopMargin": [{ type: Input },],
        "xAxisLabelRightMargin": [{ type: Input },],
        "xAxisLabelBottomMargin": [{ type: Input },],
        "yAxisLabelLeftMargin": [{ type: Input },],
        "yAxisLabelTopMargin": [{ type: Input },],
        "yAxisLabelRightMargin": [{ type: Input },],
        "yAxisLabelBottomMargin": [{ type: Input },],
        "xAxisLabelTextColor": [{ type: Input },],
        "yAxisLabelTextColor": [{ type: Input },],
        "xAxisTitleMargin": [{ type: Input },],
        "yAxisTitleMargin": [{ type: Input },],
        "xAxisTitleLeftMargin": [{ type: Input },],
        "yAxisTitleLeftMargin": [{ type: Input },],
        "xAxisTitleTopMargin": [{ type: Input },],
        "yAxisTitleTopMargin": [{ type: Input },],
        "xAxisTitleRightMargin": [{ type: Input },],
        "yAxisTitleRightMargin": [{ type: Input },],
        "xAxisTitleBottomMargin": [{ type: Input },],
        "yAxisTitleBottomMargin": [{ type: Input },],
        "xAxisTitleTextColor": [{ type: Input },],
        "yAxisTitleTextColor": [{ type: Input },],
        "xAxisLabelTextStyle": [{ type: Input },],
        "yAxisLabelTextStyle": [{ type: Input },],
        "xAxisTitleTextStyle": [{ type: Input },],
        "yAxisTitleTextStyle": [{ type: Input },],
        "xAxisLabel": [{ type: Input },],
        "yAxisLabel": [{ type: Input },],
        "xAxisMajorStroke": [{ type: Input },],
        "yAxisMajorStroke": [{ type: Input },],
        "xAxisMajorStrokeThickness": [{ type: Input },],
        "yAxisMajorStrokeThickness": [{ type: Input },],
        "xAxisMinorStrokeThickness": [{ type: Input },],
        "yAxisMinorStrokeThickness": [{ type: Input },],
        "xAxisStrip": [{ type: Input },],
        "yAxisStrip": [{ type: Input },],
        "xAxisStroke": [{ type: Input },],
        "yAxisStroke": [{ type: Input },],
        "xAxisStrokeThickness": [{ type: Input },],
        "yAxisStrokeThickness": [{ type: Input },],
        "xAxisTickLength": [{ type: Input },],
        "yAxisTickLength": [{ type: Input },],
        "xAxisTickStroke": [{ type: Input },],
        "yAxisTickStroke": [{ type: Input },],
        "xAxisTickStrokeThickness": [{ type: Input },],
        "yAxisTickStrokeThickness": [{ type: Input },],
        "xAxisTitle": [{ type: Input },],
        "yAxisTitle": [{ type: Input },],
        "xAxisMinorStroke": [{ type: Input },],
        "yAxisMinorStroke": [{ type: Input },],
        "xAxisLabelAngle": [{ type: Input },],
        "yAxisLabelAngle": [{ type: Input },],
        "xAxisExtent": [{ type: Input },],
        "yAxisExtent": [{ type: Input },],
        "xAxisTitleAngle": [{ type: Input },],
        "yAxisTitleAngle": [{ type: Input },],
        "xAxisInverted": [{ type: Input },],
        "yAxisInverted": [{ type: Input },],
        "xAxisTitleAlignment": [{ type: Input },],
        "yAxisTitleAlignment": [{ type: Input },],
        "xAxisLabelHorizontalAlignment": [{ type: Input },],
        "yAxisLabelHorizontalAlignment": [{ type: Input },],
        "xAxisLabelVerticalAlignment": [{ type: Input },],
        "yAxisLabelVerticalAlignment": [{ type: Input },],
        "xAxisLabelVisibility": [{ type: Input },],
        "yAxisLabelVisibility": [{ type: Input },],
        "yAxisLabelLocation": [{ type: Input },],
    };
    return IgxXYChartComponent;
}(IgxDomainChartComponent));
export { IgxXYChartComponent };
//# sourceMappingURL=igx-xy-chart-component.js.map